Class: Google::Apis::HealthcareV1beta1::ApplyAdminConsentsErrorDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Contains the error details of the unsupported admin Consent resources for when the ApplyAdminConsents method fails to apply one or more Consent resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApplyAdminConsentsErrorDetail

Returns a new instance of ApplyAdminConsentsErrorDetail.



277
278
279
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The list of Consent resources that are unsupported or cannot be applied and the error associated with each of them. Corresponds to the JSON property consentErrors



269
270
271
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 269

def consent_errors
  @consent_errors
end

#existing_operation_idFixnum

The currently in progress non-validate-only ApplyAdminConsents operation ID if exist. Corresponds to the JSON property existingOperationId

Returns:

  • (Fixnum)


275
276
277
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 275

def existing_operation_id
  @existing_operation_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



282
283
284
285
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 282

def update!(**args)
  @consent_errors = args[:consent_errors] if args.key?(:consent_errors)
  @existing_operation_id = args[:existing_operation_id] if args.key?(:existing_operation_id)
end