Class: Google::Apis::HealthcareV1beta1::ApplyAdminConsentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Response when all admin Consent resources in scope were processed and all affected resources were reindexed successfully. This structure will be included in the response when the operation finishes successfully.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApplyAdminConsentsResponse

Returns a new instance of ApplyAdminConsentsResponse.



348
349
350
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_resourcesFixnum

The number of resources (including the Consent resources) that may have consent access change. Corresponds to the JSON property affectedResources

Returns:

  • (Fixnum)


333
334
335
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 333

def affected_resources
  @affected_resources
end

If validate_only=false in ApplyAdminConsentsRequest, this counter contains the number of Consent resources that were successfully applied. Otherwise, it is the number of Consent resources that are supported. Corresponds to the JSON property consentApplySuccess

Returns:

  • (Fixnum)


340
341
342
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 340

def consent_apply_success
  @consent_apply_success
end

#failed_resourcesFixnum

The number of resources (including the Consent resources) that ApplyAdminConsents failed to re-index. Corresponds to the JSON property failedResources

Returns:

  • (Fixnum)


346
347
348
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 346

def failed_resources
  @failed_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



353
354
355
356
357
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 353

def update!(**args)
  @affected_resources = args[:affected_resources] if args.key?(:affected_resources)
  @consent_apply_success = args[:consent_apply_success] if args.key?(:consent_apply_success)
  @failed_resources = args[:failed_resources] if args.key?(:failed_resources)
end