Class: Google::Apis::HealthcareV1beta1::ApplyConsentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Request to apply the Consent resources for the specified FHIR store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApplyConsentsRequest

Returns a new instance of ApplyConsentsRequest.



390
391
392
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#patient_scopeGoogle::Apis::HealthcareV1beta1::PatientScope

Apply consents given by a list of patients. Corresponds to the JSON property patientScope



367
368
369
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 367

def patient_scope
  @patient_scope
end

#time_rangeGoogle::Apis::HealthcareV1beta1::TimeRange

Apply consents given by patients whose most recent consent changes are in the time range. Note that after identifying these patients, the server applies all Consent resources given by those patients, not just the Consent resources within the timestamp in the range. Corresponds to the JSON property timeRange



375
376
377
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 375

def time_range
  @time_range
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If true, the method only validates Consent resources to make sure they are supported. When the operation completes, ApplyConsentsResponse is returned where consent_apply_success and consent_apply_failure indicate supported and unsupported (or invalid) Consent resources, respectively. Otherwise, the method propagates the aggregate consensual information to the patient's resources. Upon success, affected_resources in the ApplyConsentsResponse indicates the number of resources that may have consensual access changed. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


387
388
389
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 387

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



395
396
397
398
399
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 395

def update!(**args)
  @patient_scope = args[:patient_scope] if args.key?(:patient_scope)
  @time_range = args[:time_range] if args.key?(:time_range)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end