Class: Google::Apis::HealthcareV1beta1::ApplyConsentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Response when all Consent resources in scope were processed and all affected resources were reindexed successfully. This structure is included in the response when the operation finishes successfully.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApplyConsentsResponse

Returns a new instance of ApplyConsentsResponse.



434
435
436
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_resourcesFixnum

The number of resources (including the Consent resources) that may have consensual access change. Corresponds to the JSON property affectedResources

Returns:

  • (Fixnum)


412
413
414
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 412

def affected_resources
  @affected_resources
end

If validate_only = false in ApplyConsentsRequest, this counter is the number of Consent resources that were failed to apply. Otherwise, it is the number of Consent resources that are not supported or invalid. Corresponds to the JSON property consentApplyFailure

Returns:

  • (Fixnum)


419
420
421
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 419

def consent_apply_failure
  @consent_apply_failure
end

If validate_only = false in ApplyConsentsRequest, this counter is the number of Consent resources that were successfully applied. Otherwise, it is the number of Consent resources that are supported. Corresponds to the JSON property consentApplySuccess

Returns:

  • (Fixnum)


426
427
428
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 426

def consent_apply_success
  @consent_apply_success
end

#failed_resourcesFixnum

The number of resources (including the Consent resources) that ApplyConsents failed to re-index. Corresponds to the JSON property failedResources

Returns:

  • (Fixnum)


432
433
434
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 432

def failed_resources
  @failed_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



439
440
441
442
443
444
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 439

def update!(**args)
  @affected_resources = args[:affected_resources] if args.key?(:affected_resources)
  @consent_apply_failure = args[:consent_apply_failure] if args.key?(:consent_apply_failure)
  @consent_apply_success = args[:consent_apply_success] if args.key?(:consent_apply_success)
  @failed_resources = args[:failed_resources] if args.key?(:failed_resources)
end