Class: Google::Apis::HealthcareV1beta1::BlobStorageInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

BlobStorageInfo contains details about the data stored in Blob Storage for the referenced resource. Note: Storage class is only valid for DICOM and hence will only be populated for DICOM resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BlobStorageInfo

Returns a new instance of BlobStorageInfo.



774
775
776
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#size_bytesFixnum

Size in bytes of data stored in Blob Storage. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


761
762
763
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 761

def size_bytes
  @size_bytes
end

#storage_classString

The storage class in which the Blob data is stored. Corresponds to the JSON property storageClass

Returns:

  • (String)


766
767
768
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 766

def storage_class
  @storage_class
end

#storage_class_update_timeString

The time at which the storage class was updated. This is used to compute early deletion fees of the resource. Corresponds to the JSON property storageClassUpdateTime

Returns:

  • (String)


772
773
774
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 772

def storage_class_update_time
  @storage_class_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



779
780
781
782
783
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 779

def update!(**args)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @storage_class = args[:storage_class] if args.key?(:storage_class)
  @storage_class_update_time = args[:storage_class_update_time] if args.key?(:storage_class_update_time)
end