Class: Google::Apis::HealthcareV1beta1::BulkDeleteResourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Request to bulk delete FHIR resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkDeleteResourcesRequest

Returns a new instance of BulkDeleteResourcesRequest.



847
848
849
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_destinationGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsDestination

The configuration for exporting to Cloud Storage. Corresponds to the JSON property gcsDestination



812
813
814
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 812

def gcs_destination
  @gcs_destination
end

#gcs_sourceGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsSource

Specifies the configuration for importing data from Cloud Storage. Corresponds to the JSON property gcsSource



817
818
819
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 817

def gcs_source
  @gcs_source
end

#typeString

Optional. String of comma-delimited FHIR resource types. If provided, only resources of the specified resource type(s) will be deleted. Corresponds to the JSON property type

Returns:

  • (String)


823
824
825
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 823

def type
  @type
end

#untilString

Optional. If provided, only resources updated before or atthis time are deleted. The time uses the format YYYY-MM-DDThh:mm:ss.sss+zz:zz. For example, 2015-02-07T13:28:17.239+02:00 or 2017-01-01T00:00:00Z. The time must be specified to the second and include a time zone. Corresponds to the JSON property until

Returns:

  • (String)


831
832
833
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 831

def until
  @until
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set to true, the request will only perform a dry run. By default ( once the behavior change is fully rolled out), this will default to true. During the transition period, the default depends on the Mendel flag status for the project. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


839
840
841
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 839

def validate_only
  @validate_only
end

#version_configString

Optional. Specifies which version of the resources to delete. Corresponds to the JSON property versionConfig

Returns:

  • (String)


845
846
847
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 845

def version_config
  @version_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



852
853
854
855
856
857
858
859
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 852

def update!(**args)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @type = args[:type] if args.key?(:type)
  @until = args[:until] if args.key?(:until)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
  @version_config = args[:version_config] if args.key?(:version_config)
end