Class: Google::Apis::HealthcareV1beta1::BulkExportGcsDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The configuration for exporting to Cloud Storage using the bulk export API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkExportGcsDestination

Returns a new instance of BulkExportGcsDestination.



818
819
820
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#uri_prefixString

Optional. URI for a Cloud Storage directory where the server writes result files, in the format gs://bucket-id/path/to/destination/dir`. If there is no trailing slash, the service appends one when composing the object path. The user is responsible for creating the Cloud Storage bucket referenced in uri_prefix. Corresponds to the JSON propertyuriPrefix`

Returns:

  • (String)


816
817
818
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 816

def uri_prefix
  @uri_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



823
824
825
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 823

def update!(**args)
  @uri_prefix = args[:uri_prefix] if args.key?(:uri_prefix)
end