Class: Google::Apis::HealthcareV1beta1::Consent
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::Consent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Represents a user's consent.
Instance Attribute Summary collapse
-
#consent_artifact ⇒ String
Required.
-
#expire_time ⇒ String
Timestamp in UTC of when this Consent is considered expired.
-
#metadata ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#policies ⇒ Array<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1ConsentPolicy>
Optional.
-
#revision_create_time ⇒ String
Output only.
-
#revision_id ⇒ String
Output only.
-
#state ⇒ String
Required.
-
#ttl ⇒ String
Input only.
-
#user_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Consent
constructor
A new instance of Consent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Consent
Returns a new instance of Consent.
1150 1151 1152 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent_artifact ⇒ String
Required. The resource name of the Consent artifact that contains proof of the
end user's consent, of the form projects/project_id/locations/location_id/
datasets/dataset_id/consentStores/consent_store_id/consentArtifacts/
consent_artifact_id`.
Corresponds to the JSON propertyconsentArtifact`
1091 1092 1093 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1091 def @consent_artifact end |
#expire_time ⇒ String
Timestamp in UTC of when this Consent is considered expired.
Corresponds to the JSON property expireTime
1096 1097 1098 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1096 def expire_time @expire_time end |
#metadata ⇒ Hash<String,String>
Optional. User-supplied key-value pairs used to organize Consent resources.
Metadata keys must: - be between 1 and 63 characters long - have a UTF-8
encoding of maximum 128 bytes - begin with a letter - consist of up to 63
characters including lowercase letters, numeric characters, underscores, and
dashes Metadata values must be: - be between 1 and 63 characters long - have a
UTF-8 encoding of maximum 128 bytes - consist of up to 63 characters including
lowercase letters, numeric characters, underscores, and dashes No more than 64
metadata entries can be associated with a given consent.
Corresponds to the JSON property metadata
1108 1109 1110 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1108 def @metadata end |
#name ⇒ String
Identifier. Resource name of the Consent, of the form projects/project_id/
locations/location_id/datasets/dataset_id/consentStores/consent_store_id/
consents/consent_id`. Cannot be changed after creation.
Corresponds to the JSON propertyname`
1115 1116 1117 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1115 def name @name end |
#policies ⇒ Array<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1ConsentPolicy>
Optional. Represents a user's consent in terms of the resources that can be
accessed and under what conditions.
Corresponds to the JSON property policies
1121 1122 1123 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1121 def policies @policies end |
#revision_create_time ⇒ String
Output only. The timestamp that the revision was created.
Corresponds to the JSON property revisionCreateTime
1126 1127 1128 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1126 def revision_create_time @revision_create_time end |
#revision_id ⇒ String
Output only. The revision ID of the Consent. The format is an 8-character
hexadecimal string. Refer to a specific revision of a Consent by appending @
revision_id`to the Consent's resource name.
Corresponds to the JSON propertyrevisionId`
1133 1134 1135 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1133 def revision_id @revision_id end |
#state ⇒ String
Required. Indicates the current state of this Consent.
Corresponds to the JSON property state
1138 1139 1140 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1138 def state @state end |
#ttl ⇒ String
Input only. The time to live for this Consent from when it is created.
Corresponds to the JSON property ttl
1143 1144 1145 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1143 def ttl @ttl end |
#user_id ⇒ String
Required. User's UUID provided by the client.
Corresponds to the JSON property userId
1148 1149 1150 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1148 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1155 def update!(**args) @consent_artifact = args[:consent_artifact] if args.key?(:consent_artifact) @expire_time = args[:expire_time] if args.key?(:expire_time) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @policies = args[:policies] if args.key?(:policies) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @user_id = args[:user_id] if args.key?(:user_id) end |