Class: Google::Apis::HealthcareV1beta1::ConsentArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Documentation of a user's consent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsentArtifact

Returns a new instance of ConsentArtifact.



1239
1240
1241
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Optional. Screenshots, PDFs, or other binary information documenting the user' s consent. Corresponds to the JSON property consentContentScreenshots



1197
1198
1199
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1197

def consent_content_screenshots
  @consent_content_screenshots
end

Optional. An string indicating the version of the consent information shown to the user. Corresponds to the JSON property consentContentVersion

Returns:

  • (String)


1203
1204
1205
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1203

def consent_content_version
  @consent_content_version
end

#guardian_signatureGoogle::Apis::HealthcareV1beta1::Signature

User signature. Corresponds to the JSON property guardianSignature



1208
1209
1210
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1208

def guardian_signature
  @guardian_signature
end

#metadataHash<String,String>

Optional. Metadata associated with the Consent artifact. For example, the consent locale or user agent version. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


1214
1215
1216
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1214

def 
  @metadata
end

#nameString

Identifier. Resource name of the Consent artifact, of the form projects/ project_id/locations/location_id/datasets/dataset_id/consentStores/ consent_store_id/consentArtifacts/consent_artifact_id`. Cannot be changed after creation. Corresponds to the JSON propertyname`

Returns:

  • (String)


1222
1223
1224
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1222

def name
  @name
end

#user_idString

Required. User's UUID provided by the client. Corresponds to the JSON property userId

Returns:

  • (String)


1227
1228
1229
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1227

def user_id
  @user_id
end

#user_signatureGoogle::Apis::HealthcareV1beta1::Signature

User signature. Corresponds to the JSON property userSignature



1232
1233
1234
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1232

def user_signature
  @user_signature
end

#witness_signatureGoogle::Apis::HealthcareV1beta1::Signature

User signature. Corresponds to the JSON property witnessSignature



1237
1238
1239
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1237

def witness_signature
  @witness_signature
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1244

def update!(**args)
  @consent_content_screenshots = args[:consent_content_screenshots] if args.key?(:consent_content_screenshots)
  @consent_content_version = args[:consent_content_version] if args.key?(:consent_content_version)
  @guardian_signature = args[:guardian_signature] if args.key?(:guardian_signature)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @user_id = args[:user_id] if args.key?(:user_id)
  @user_signature = args[:user_signature] if args.key?(:user_signature)
  @witness_signature = args[:witness_signature] if args.key?(:witness_signature)
end