Class: Google::Apis::HealthcareV1beta1::ConsentStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Represents a consent store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsentStore

Returns a new instance of ConsentStore.



1457
1458
1459
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Optional. Default time to live for Consents created in this store. Must be at least 24 hours. Updating this field will not affect the expiration time of existing consents. Corresponds to the JSON property defaultConsentTtl

Returns:

  • (String)


1429
1430
1431
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1429

def default_consent_ttl
  @default_consent_ttl
end

Optional. If true, UpdateConsent creates the Consent if it does not already exist. If unspecified, defaults to false. Corresponds to the JSON property enableConsentCreateOnUpdate

Returns:

  • (Boolean)


1435
1436
1437
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1435

def enable_consent_create_on_update
  @enable_consent_create_on_update
end

#labelsHash<String,String>

Optional. User-supplied key-value pairs used to organize consent stores. Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: \ pLl\pLo0,62. Label values must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: [\pLl\pLo\pN_-]0,63. No more than 64 labels can be associated with a given store. For more information: https://cloud.google.com/ healthcare/docs/how-tos/labeling-resources Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1448
1449
1450
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1448

def labels
  @labels
end

#nameString

Resource name of the consent store, of the form projects/project_id/ locations/location_id/datasets/dataset_id/consentStores/consent_store_id` . Cannot be changed after creation. Corresponds to the JSON propertyname`

Returns:

  • (String)


1455
1456
1457
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1455

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1462
1463
1464
1465
1466
1467
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1462

def update!(**args)
  @default_consent_ttl = args[:default_consent_ttl] if args.key?(:default_consent_ttl)
  @enable_consent_create_on_update = args[:enable_consent_create_on_update] if args.key?(:enable_consent_create_on_update)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
end