Class: Google::Apis::HealthcareV1beta1::Dataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

A message representing a health dataset. A health dataset represents a collection of healthcare data pertaining to one or more patients. This may include multiple modalities of healthcare data, such as electronic medical records or medical imaging data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Dataset

Returns a new instance of Dataset.



1628
1629
1630
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryption_specGoogle::Apis::HealthcareV1beta1::EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a resource. Corresponds to the JSON property encryptionSpec



1600
1601
1602
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1600

def encryption_spec
  @encryption_spec
end

#nameString

Identifier. Resource name of the dataset, of the form projects/project_id/ locations/location_id/datasets/dataset_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1606
1607
1608
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1606

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Whether the dataset satisfies zone isolation. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


1611
1612
1613
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1611

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Whether the dataset satisfies zone separation. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1617
1618
1619
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1617

def satisfies_pzs
  @satisfies_pzs
end

#time_zoneString

The default timezone used by this dataset. Must be a either a valid IANA time zone name such as "America/New_York" or empty, which defaults to UTC. This is used for parsing times in resources, such as HL7 messages, where no explicit timezone is specified. Corresponds to the JSON property timeZone

Returns:

  • (String)


1626
1627
1628
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1626

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1633
1634
1635
1636
1637
1638
1639
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1633

def update!(**args)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end