Class: Google::Apis::HealthcareV1beta1::DeidentifiedStoreDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Contains configuration for streaming de-identified FHIR export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeidentifiedStoreDestination

Returns a new instance of DeidentifiedStoreDestination.



1670
1671
1672
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::HealthcareV1beta1::DeidentifyConfig

Configures de-id options specific to different types of content. Each submessage customizes the handling of an https://tools.ietf.org/html/rfc6838 media type or subtype. Configs are applied in a nested manner at runtime. Corresponds to the JSON property config



1661
1662
1663
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1661

def config
  @config
end

#storeString

The full resource name of a Cloud Healthcare FHIR store, for example, projects/project_id/locations/location_id/datasets/dataset_id/fhirStores/ fhir_store_id`. Corresponds to the JSON propertystore`

Returns:

  • (String)


1668
1669
1670
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1668

def store
  @store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1675
1676
1677
1678
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1675

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @store = args[:store] if args.key?(:store)
end