Class: Google::Apis::HealthcareV1beta1::DeidentifyConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Configures de-id options specific to different types of content. Each submessage customizes the handling of an https://tools.ietf.org/html/rfc6838 media type or subtype. Configs are applied in a nested manner at runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeidentifyConfig

Returns a new instance of DeidentifyConfig.



1774
1775
1776
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dicomGoogle::Apis::HealthcareV1beta1::DicomConfig

Specifies the parameters needed for de-identification of DICOM stores. Corresponds to the JSON property dicom



1731
1732
1733
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1731

def dicom
  @dicom
end

#dicom_tag_configGoogle::Apis::HealthcareV1beta1::DicomTagConfig

Specifies the parameters needed for the de-identification of DICOM stores. Corresponds to the JSON property dicomTagConfig



1736
1737
1738
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1736

def dicom_tag_config
  @dicom_tag_config
end

#fhirGoogle::Apis::HealthcareV1beta1::FhirConfig

Specifies how to handle de-identification of a FHIR store. Corresponds to the JSON property fhir



1741
1742
1743
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1741

def fhir
  @fhir
end

#fhir_field_configGoogle::Apis::HealthcareV1beta1::FhirFieldConfig

Specifies how to handle the de-identification of a FHIR store. Corresponds to the JSON property fhirFieldConfig



1746
1747
1748
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1746

def fhir_field_config
  @fhir_field_config
end

#imageGoogle::Apis::HealthcareV1beta1::ImageConfig

Specifies how to handle de-identification of image pixels. Corresponds to the JSON property image



1751
1752
1753
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1751

def image
  @image
end

#operation_metadataGoogle::Apis::HealthcareV1beta1::DeidentifyOperationMetadata

Details about the work the de-identify operation performed. Corresponds to the JSON property operationMetadata



1756
1757
1758
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1756

def 
  @operation_metadata
end

#textGoogle::Apis::HealthcareV1beta1::TextConfig

Configures how to transform sensitive text InfoTypes. Corresponds to the JSON property text



1761
1762
1763
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1761

def text
  @text
end

#use_regional_data_processingBoolean Also known as: use_regional_data_processing?

Ensures in-flight data remains in the region of origin during de- identification. The default value is false. Using this option results in a significant reduction of throughput, and is not compatible with LOCATION or ORGANIZATION_NAME infoTypes. If the deprecated DicomConfig or FhirConfig are used, then LOCATION must be excluded within TextConfig, and must also be excluded within ImageConfig if image redaction is required. Corresponds to the JSON property useRegionalDataProcessing

Returns:

  • (Boolean)


1771
1772
1773
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1771

def use_regional_data_processing
  @use_regional_data_processing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1779

def update!(**args)
  @dicom = args[:dicom] if args.key?(:dicom)
  @dicom_tag_config = args[:dicom_tag_config] if args.key?(:dicom_tag_config)
  @fhir = args[:fhir] if args.key?(:fhir)
  @fhir_field_config = args[:fhir_field_config] if args.key?(:fhir_field_config)
  @image = args[:image] if args.key?(:image)
  @operation_metadata = args[:operation_metadata] if args.key?(:operation_metadata)
  @text = args[:text] if args.key?(:text)
  @use_regional_data_processing = args[:use_regional_data_processing] if args.key?(:use_regional_data_processing)
end