Class: Google::Apis::HealthcareV1beta1::DeidentifyDatasetRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::DeidentifyDatasetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Redacts identifying information from the specified dataset.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::HealthcareV1beta1::DeidentifyConfig
Configures de-id options specific to different types of content.
-
#destination_dataset ⇒ String
Required.
-
#gcs_config_uri ⇒ String
Cloud Storage location to read the JSON cloud.healthcare.deidentify.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeidentifyDatasetRequest
constructor
A new instance of DeidentifyDatasetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeidentifyDatasetRequest
Returns a new instance of DeidentifyDatasetRequest.
1738 1739 1740 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1738 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::HealthcareV1beta1::DeidentifyConfig
Configures de-id options specific to different types of content. Each
submessage customizes the handling of an https://tools.ietf.org/html/rfc6838
media type or subtype. Configs are applied in a nested manner at runtime.
Corresponds to the JSON property config
1718 1719 1720 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1718 def config @config end |
#destination_dataset ⇒ String
Required. The name of the dataset resource to create and write the redacted
data to. * The destination dataset must not exist. * The destination dataset
must be in the same location as the source dataset. De-identifying data across
multiple locations is not supported.
Corresponds to the JSON property destinationDataset
1726 1727 1728 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1726 def destination_dataset @destination_dataset end |
#gcs_config_uri ⇒ String
Cloud Storage location to read the JSON cloud.healthcare.deidentify.
DeidentifyConfig from, overriding the default config. Must be of the form gs:/
/bucket_id/path/to/object. The Cloud Storage location must grant the Cloud
IAM role roles/storage.objectViewer to the project's Cloud Healthcare
Service Agent service account. Only one of config and gcs_config_uri can
be specified.
Corresponds to the JSON property gcsConfigUri
1736 1737 1738 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1736 def gcs_config_uri @gcs_config_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1743 1744 1745 1746 1747 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1743 def update!(**args) @config = args[:config] if args.key?(:config) @destination_dataset = args[:destination_dataset] if args.key?(:destination_dataset) @gcs_config_uri = args[:gcs_config_uri] if args.key?(:gcs_config_uri) end |