Class: Google::Apis::HealthcareV1beta1::DeidentifyFhirStoreRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Creates a new FHIR store with sensitive information de-identified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeidentifyFhirStoreRequest

Returns a new instance of DeidentifyFhirStoreRequest.



1885
1886
1887
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::HealthcareV1beta1::DeidentifyConfig

Configures de-id options specific to different types of content. Each submessage customizes the handling of an https://tools.ietf.org/html/rfc6838 media type or subtype. Configs are applied in a nested manner at runtime. Corresponds to the JSON property config



1850
1851
1852
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1850

def config
  @config
end

#destination_storeString

Required. The name of the FHIR store to write the redacted data to. For example, projects/project_id/locations/location_id/datasets/dataset_id/ fhirStores/fhir_store_id``. * The destination dataset and FHIR store must exist. * The source dataset and destination dataset must both reside in the same location. De-identifying data across multiple locations is not supported.

  • The caller must have the healthcare.fhirResources.update permission to write to the destination FHIR store. Corresponds to the JSON property destinationStore

Returns:

  • (String)


1861
1862
1863
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1861

def destination_store
  @destination_store
end

#gcs_config_uriString

Cloud Storage location to read the JSON cloud.healthcare.deidentify. DeidentifyConfig from, overriding the default config. Must be of the form gs:/ /bucket_id/path/to/object. The Cloud Storage location must grant the Cloud IAM role roles/storage.objectViewer to the project's Cloud Healthcare Service Agent service account. Only one of config and gcs_config_uri can be specified. Corresponds to the JSON property gcsConfigUri

Returns:

  • (String)


1871
1872
1873
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1871

def gcs_config_uri
  @gcs_config_uri
end

#resource_filterGoogle::Apis::HealthcareV1beta1::FhirFilter

Filter configuration. Corresponds to the JSON property resourceFilter



1876
1877
1878
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1876

def resource_filter
  @resource_filter
end

#skip_modified_resourcesBoolean Also known as: skip_modified_resources?

If true, skips resources that are created or modified after the de-identify operation is created. Corresponds to the JSON property skipModifiedResources

Returns:

  • (Boolean)


1882
1883
1884
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1882

def skip_modified_resources
  @skip_modified_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1890
1891
1892
1893
1894
1895
1896
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1890

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @destination_store = args[:destination_store] if args.key?(:destination_store)
  @gcs_config_uri = args[:gcs_config_uri] if args.key?(:gcs_config_uri)
  @resource_filter = args[:resource_filter] if args.key?(:resource_filter)
  @skip_modified_resources = args[:skip_modified_resources] if args.key?(:skip_modified_resources)
end