Class: Google::Apis::HealthcareV1beta1::DicomNotificationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Contains the configuration for DICOM notifications.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DicomNotificationConfig

Returns a new instance of DicomNotificationConfig.



2013
2014
2015
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pubsub_topicString

Required. The Pub/Sub topic that notifications of changes are published on. Supplied by the client. The notification is a PubsubMessage with the following fields: * PubsubMessage. Data contains the resource name. * PubsubMessage.MessageId is the ID of this notification. It is guaranteed to be unique within the topic. * PubsubMessage.PublishTime is the time when the message was published. * PubsubMessage.Attributes contains the following attributes: * action: The name of the endpoint that generated the notification. Possible values are StoreInstances, SetBlobSettings, ImportDicomData, etc. * lastUpdatedTime : The latest timestamp when the DICOM instance was updated. * storeName: The resource name of the DICOM store, of the form projects/project_id/locations/ location_id/datasets/dataset_id/dicomStores/dicom_store_id`. * studyInstanceUID: The study UID of the DICOM instance that was changed. * seriesInstanceUID: The series UID of the DICOM instance that was changed. * sopInstanceUID: The instance UID of the DICOM instance that was changed. * versionId: The version ID of the DICOM instance that was changed. *modality : The modality tag of the DICOM instance that was changed. * previousStorageClass: The storage class where the DICOM instance was previously stored if the storage class was changed. *storageClass: The storage class where the DICOM instance is currently stored. Note that notifications are only sent if the topic is non-empty. [Topic names](https:// cloud.google.com/pubsub/docs/overview#names) must be scoped to a project. The Cloud Healthcare API service account, service-@gcp-sa-healthcare.iam. gserviceaccount.com, must have thepubsub.topics.publishpermission (which is typically included inroles/pubsub.publisherrole) on the given Pub/Sub topic. Not having adequate permissions causes the calls that send notifications to fail (https://cloud.google.com/healthcare-api/docs/ permissions-healthcare-api-gcp-products# dicom_fhir_and_hl7v2_store_cloud_pubsub_permissions). If a notification can't be published to Pub/Sub, errors are logged to Cloud Logging. For more information, see [Viewing error logs in Cloud Logging](https://cloud.google. com/healthcare-api/docs/how-tos/logging). Corresponds to the JSON propertypubsubTopic`

Returns:

  • (String)


2011
2012
2013
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2011

def pubsub_topic
  @pubsub_topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2018
2019
2020
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2018

def update!(**args)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
end