Class: Google::Apis::HealthcareV1beta1::DicomStoreMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

DicomStoreMetrics contains metrics describing a DICOM store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DicomStoreMetrics

Returns a new instance of DicomStoreMetrics.



2197
2198
2199
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_size_bytesFixnum

Total blob storage bytes for all instances in the store. Corresponds to the JSON property blobStorageSizeBytes

Returns:

  • (Fixnum)


2169
2170
2171
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2169

def blob_storage_size_bytes
  @blob_storage_size_bytes
end

#instance_countFixnum

Number of instances in the store. Corresponds to the JSON property instanceCount

Returns:

  • (Fixnum)


2174
2175
2176
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2174

def instance_count
  @instance_count
end

#nameString

Resource name of the DICOM store, of the form projects/project_id/locations/ location_id/datasets/dataset_id/dicomStores/dicom_store_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2180
2181
2182
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2180

def name
  @name
end

#series_countFixnum

Number of series in the store. Corresponds to the JSON property seriesCount

Returns:

  • (Fixnum)


2185
2186
2187
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2185

def series_count
  @series_count
end

#structured_storage_size_bytesFixnum

Total structured storage bytes for all instances in the store. Corresponds to the JSON property structuredStorageSizeBytes

Returns:

  • (Fixnum)


2190
2191
2192
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2190

def structured_storage_size_bytes
  @structured_storage_size_bytes
end

#study_countFixnum

Number of studies in the store. Corresponds to the JSON property studyCount

Returns:

  • (Fixnum)


2195
2196
2197
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2195

def study_count
  @study_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2202
2203
2204
2205
2206
2207
2208
2209
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2202

def update!(**args)
  @blob_storage_size_bytes = args[:blob_storage_size_bytes] if args.key?(:blob_storage_size_bytes)
  @instance_count = args[:instance_count] if args.key?(:instance_count)
  @name = args[:name] if args.key?(:name)
  @series_count = args[:series_count] if args.key?(:series_count)
  @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes)
  @study_count = args[:study_count] if args.key?(:study_count)
end