Class: Google::Apis::HealthcareV1beta1::EntityMention

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

An entity mention in the document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EntityMention

Returns a new instance of EntityMention.



2378
2379
2380
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_infoArray<Google::Apis::HealthcareV1beta1::Feature>

Additional information about the entity mention. For example, for an entity mention of type DATE this can be its more specific date types from the following list: ADMISSION_DATE, CONSULTATION_DATE, DISCHARGE_DATE, SERVICE_DATE, VISIT_DATE, DIAGNOSIS_DATE, MED_STARTED_DATE, MED_ENDED_DATE, NOTE_DATE, PROCEDURE_DATE, RADIATION_STARTED_DATE, RADIATION_ENDED_DATE, STAGE_DATE Corresponds to the JSON property additionalInfo



2327
2328
2329
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2327

def additional_info
  @additional_info
end

#certainty_assessmentGoogle::Apis::HealthcareV1beta1::Feature

A feature of an entity mention. Corresponds to the JSON property certaintyAssessment



2332
2333
2334
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2332

def certainty_assessment
  @certainty_assessment
end

#confidenceFloat

The model's confidence in this entity mention annotation. A number between 0 and 1. Corresponds to the JSON property confidence

Returns:

  • (Float)


2338
2339
2340
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2338

def confidence
  @confidence
end

#linked_entitiesArray<Google::Apis::HealthcareV1beta1::LinkedEntity>

linked_entities are candidate ontological concepts that this entity mention may refer to. They are sorted by decreasing confidence. Corresponds to the JSON property linkedEntities



2344
2345
2346
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2344

def linked_entities
  @linked_entities
end

#mention_idString

mention_id uniquely identifies each entity mention in a single response. Corresponds to the JSON property mentionId

Returns:

  • (String)


2349
2350
2351
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2349

def mention_id
  @mention_id
end

#subjectGoogle::Apis::HealthcareV1beta1::Feature

A feature of an entity mention. Corresponds to the JSON property subject



2354
2355
2356
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2354

def subject
  @subject
end

#temporal_assessmentGoogle::Apis::HealthcareV1beta1::Feature

A feature of an entity mention. Corresponds to the JSON property temporalAssessment



2359
2360
2361
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2359

def temporal_assessment
  @temporal_assessment
end

#textGoogle::Apis::HealthcareV1beta1::TextSpan

A span of text in the provided document. Corresponds to the JSON property text



2364
2365
2366
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2364

def text
  @text
end

#typeString

The semantic type of the entity: UNKNOWN_ENTITY_TYPE, ALONE, ANATOMICAL_STRUCTURE, ASSISTED_LIVING, BF_RESULT, BM_RESULT, BM_UNIT, BM_VALUE, BODY_FUNCTION, BODY_MEASUREMENT, COMPLIANT, DOESNOT_FOLLOWUP, FAMILY, FOLLOWSUP, LABORATORY_DATA, LAB_RESULT, LAB_UNIT, LAB_VALUE, MEDICAL_DEVICE, MEDICINE, MED_DOSE, MED_DURATION, MED_FORM, MED_FREQUENCY, MED_ROUTE, MED_STATUS, MED_STRENGTH, MED_TOTALDOSE, MED_UNIT, NON_COMPLIANT, OTHER_LIVINGSTATUS, PROBLEM, PROCEDURE, PROCEDURE_RESULT, PROC_METHOD, REASON_FOR_NONCOMPLIANCE, SEVERITY, SUBSTANCE_ABUSE, UNCLEAR_FOLLOWUP. Corresponds to the JSON property type

Returns:

  • (String)


2376
2377
2378
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2376

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2383

def update!(**args)
  @additional_info = args[:additional_info] if args.key?(:additional_info)
  @certainty_assessment = args[:certainty_assessment] if args.key?(:certainty_assessment)
  @confidence = args[:confidence] if args.key?(:confidence)
  @linked_entities = args[:linked_entities] if args.key?(:linked_entities)
  @mention_id = args[:mention_id] if args.key?(:mention_id)
  @subject = args[:subject] if args.key?(:subject)
  @temporal_assessment = args[:temporal_assessment] if args.key?(:temporal_assessment)
  @text = args[:text] if args.key?(:text)
  @type = args[:type] if args.key?(:type)
end