Class: Google::Apis::HealthcareV1beta1::EvaluateUserConsentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvaluateUserConsentsResponse

Returns a new instance of EvaluateUserConsentsResponse.



2510
2511
2512
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. This token is valid for 72 hours after it is created. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2503
2504
2505
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2503

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::HealthcareV1beta1::Result>

The consent evaluation result for each data_id. Corresponds to the JSON property results



2508
2509
2510
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2508

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2515
2516
2517
2518
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2515

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
end