Class: Google::Apis::HealthcareV1beta1::ExportResourcesRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ExportResourcesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Request to export resources.
Instance Attribute Summary collapse
-
#_since ⇒ String
If provided, only resources updated after this time are exported.
-
#_type ⇒ String
String of comma-delimited FHIR resource types.
-
#bigquery_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirBigQueryDestination
The configuration for exporting to BigQuery.
-
#gcs_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsDestination
The configuration for exporting to Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportResourcesRequest
constructor
A new instance of ExportResourcesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportResourcesRequest
Returns a new instance of ExportResourcesRequest.
2839 2840 2841 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#_since ⇒ String
If provided, only resources updated after this time are exported. The time
uses the format YYYY-MM-DDThh:mm:ss.sss+zz:zz. For example, 2015-02-07T13:28:
17.239+02:00 or 2017-01-01T00:00:00Z. The time must be specified to the
second and include a time zone.
Corresponds to the JSON property _since
2821 2822 2823 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2821 def _since @_since end |
#_type ⇒ String
String of comma-delimited FHIR resource types. If provided, only resources of
the specified resource type(s) are exported.
Corresponds to the JSON property _type
2827 2828 2829 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2827 def _type @_type end |
#bigquery_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirBigQueryDestination
The configuration for exporting to BigQuery.
Corresponds to the JSON property bigqueryDestination
2832 2833 2834 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2832 def bigquery_destination @bigquery_destination end |
#gcs_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsDestination
The configuration for exporting to Cloud Storage.
Corresponds to the JSON property gcsDestination
2837 2838 2839 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2837 def gcs_destination @gcs_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2844 2845 2846 2847 2848 2849 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2844 def update!(**args) @_since = args[:_since] if args.key?(:_since) @_type = args[:_type] if args.key?(:_type) @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) end |