Class: Google::Apis::HealthcareV1beta1::FhirFieldConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Specifies how to handle the de-identification of a FHIR store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FhirFieldConfig

Returns a new instance of FhirFieldConfig.



3024
3025
3026
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_metadata_listArray<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata>

Specifies FHIR paths to match and how to transform them. Any field that is not matched by a FieldMetadata action is passed through to the output dataset unmodified. All extensions will be processed according to keep_extensions. If a field can be matched by more than one FieldMetadata action, the first action option is applied. Overrides options and the union field profile in FhirFieldConfig. Corresponds to the JSON property fieldMetadataList



3012
3013
3014
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3012

def 
  @field_metadata_list
end

#optionsGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyOptions

Specifies additional options to apply to the base ProfileType. Corresponds to the JSON property options



3017
3018
3019
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3017

def options
  @options
end

#profile_typeString

Base profile type for handling FHIR fields. Corresponds to the JSON property profileType

Returns:

  • (String)


3022
3023
3024
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3022

def profile_type
  @profile_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3029
3030
3031
3032
3033
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3029

def update!(**args)
  @field_metadata_list = args[:field_metadata_list] if args.key?(:field_metadata_list)
  @options = args[:options] if args.key?(:options)
  @profile_type = args[:profile_type] if args.key?(:profile_type)
end