Class: Google::Apis::HealthcareV1beta1::FhirOutput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Details about the FHIR store to write the output to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FhirOutput

Returns a new instance of FhirOutput.



3056
3057
3058
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fhir_storeString

Name of the output FHIR store, which must already exist. You must grant the healthcare.fhirResources.update permission on the destination store to your project's Cloud Healthcare Service Agent service account. The destination store must set enableUpdateCreate to true. The destination store must use FHIR version R4. Writing these resources will consume FHIR operations quota from the project containing the source data. De-identify operation metadata is only generated for DICOM de-identification operations. Corresponds to the JSON property fhirStore

Returns:

  • (String)


3054
3055
3056
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3054

def fhir_store
  @fhir_store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3061
3062
3063
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3061

def update!(**args)
  @fhir_store = args[:fhir_store] if args.key?(:fhir_store)
end