Class: Google::Apis::HealthcareV1beta1::FhirStoreMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Count of resources and total storage size by type for a given FHIR store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FhirStoreMetric

Returns a new instance of FhirStoreMetric.



3341
3342
3343
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The total count of FHIR resources in the store of this resource type. Corresponds to the JSON property count

Returns:

  • (Fixnum)


3322
3323
3324
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3322

def count
  @count
end

#resource_typeString

The FHIR resource type this metric applies to. Corresponds to the JSON property resourceType

Returns:

  • (String)


3327
3328
3329
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3327

def resource_type
  @resource_type
end

#structured_storage_size_bytesFixnum

The total amount of structured storage used by FHIR resources of this resource type in the store. Corresponds to the JSON property structuredStorageSizeBytes

Returns:

  • (Fixnum)


3333
3334
3335
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3333

def structured_storage_size_bytes
  @structured_storage_size_bytes
end

#versioned_storage_size_bytesFixnum

The total amount of versioned storage used by versioned FHIR resources of this resource type in the store. Corresponds to the JSON property versionedStorageSizeBytes

Returns:

  • (Fixnum)


3339
3340
3341
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3339

def versioned_storage_size_bytes
  @versioned_storage_size_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3346
3347
3348
3349
3350
3351
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3346

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes)
  @versioned_storage_size_bytes = args[:versioned_storage_size_bytes] if args.key?(:versioned_storage_size_bytes)
end