Class: Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Specifies additional options to apply to the base ProfileType.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1DeidentifyOptions

Returns a new instance of GoogleCloudHealthcareV1beta1DeidentifyOptions.



3665
3666
3667
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#character_mask_configGoogle::Apis::HealthcareV1beta1::CharacterMaskConfig

Mask a string by replacing its characters with a fixed character. Corresponds to the JSON property characterMaskConfig



3632
3633
3634
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3632

def character_mask_config
  @character_mask_config
end

#contextual_deidGoogle::Apis::HealthcareV1beta1::ContextualDeidConfig

Fields that don't match a KeepField or CleanTextField action in the BASIC profile are collected into a contextual phrase list. For fields that match a CleanTextField action in FieldMetadata or ProfileType, the process attempts to transform phrases matching these contextual entries. These contextual phrases are replaced with the token "[CTX]". This feature uses an additional InfoType during inspection. Corresponds to the JSON property contextualDeid



3642
3643
3644
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3642

def contextual_deid
  @contextual_deid
end

#crypto_hash_configGoogle::Apis::HealthcareV1beta1::CryptoHashConfig

Pseudonymization method that generates surrogates via cryptographic hashing. Uses SHA-256. Outputs a base64-encoded representation of the hashed output. For example, L7k0BHmF1ha5U3NfGykjro4xWi1MPVQPjhMAZbSV9mM=. Corresponds to the JSON property cryptoHashConfig



3649
3650
3651
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3649

def crypto_hash_config
  @crypto_hash_config
end

#date_shift_configGoogle::Apis::HealthcareV1beta1::DateShiftConfig

Shift a date forward or backward in time by a random amount which is consistent for a given patient and crypto key combination. Corresponds to the JSON property dateShiftConfig



3655
3656
3657
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3655

def date_shift_config
  @date_shift_config
end

#keep_extensionsGoogle::Apis::HealthcareV1beta1::KeepExtensionsConfig

The behavior for handling FHIR extensions that aren't otherwise specified for de-identification. If provided, all extensions are preserved during de- identification by default. If unspecified, all extensions are removed during de-identification by default. Corresponds to the JSON property keepExtensions



3663
3664
3665
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3663

def keep_extensions
  @keep_extensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3670
3671
3672
3673
3674
3675
3676
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3670

def update!(**args)
  @character_mask_config = args[:character_mask_config] if args.key?(:character_mask_config)
  @contextual_deid = args[:contextual_deid] if args.key?(:contextual_deid)
  @crypto_hash_config = args[:crypto_hash_config] if args.key?(:crypto_hash_config)
  @date_shift_config = args[:date_shift_config] if args.key?(:date_shift_config)
  @keep_extensions = args[:keep_extensions] if args.key?(:keep_extensions)
end