Class: Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomBigQueryDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The BigQuery table where the server writes output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1DicomBigQueryDestination

Returns a new instance of GoogleCloudHealthcareV1beta1DicomBigQueryDestination.



3784
3785
3786
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_data_capture_configGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomChangeDataCaptureConfig

BigQuery Change Data Capture configuration. Corresponds to the JSON property changeDataCaptureConfig



3727
3728
3729
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3727

def change_data_capture_config
  @change_data_capture_config
end

#forceBoolean Also known as: force?

Use write_disposition instead. If write_disposition is specified, this parameter is ignored. force=false is equivalent to write_disposition= WRITE_EMPTY and force=true is equivalent to write_disposition=WRITE_TRUNCATE. Corresponds to the JSON property force

Returns:

  • (Boolean)


3734
3735
3736
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3734

def force
  @force
end

#include_source_storeBoolean Also known as: include_source_store?

Optional. If true, the source store name will be included as a column in the BigQuery schema. Corresponds to the JSON property includeSourceStore

Returns:

  • (Boolean)


3741
3742
3743
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3741

def include_source_store
  @include_source_store
end

#schema_flattenedGoogle::Apis::HealthcareV1beta1::SchemaFlattened

Using this field will flatten the DICOM instances into a BigQuery table. The table will have one column for each DICOM tag. The column name will be the DICOM tag's textual representation. Corresponds to the JSON property schemaFlattened



3749
3750
3751
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3749

def schema_flattened
  @schema_flattened
end

#schema_jsonGoogle::Apis::HealthcareV1beta1::SchemaJson

Using this field will set the schema such that all DICOM tags will be included in the BigQuery table as a single JSON type column. The BigQuery table schema will include the following columns: * StudyInstanceUID (Type: STRING): DICOM Tag 0020000D. * SeriesInstanceUID (Type: STRING): DICOM Tag 0020000E. * SOPInstanceUID (Type: STRING): DICOM Tag 00080018. * SourceDicomStore (Type: STRING): The name of the source DICOM store. This field is only included if the include_source_store option is set to true. * Metadata (Type: JSON): All DICOM tags for the instance, stored in a single JSON object. * StructuredStorageSize (Type: INTEGER): Size of the structured storage in bytes. * DroppedTags (Type: STRING, Repeated: Yes): List of tags that were dropped during the conversion. * StorageClass (Type: STRING): The storage class of the instance. * LastUpdated (Type: TIMESTAMP): Timestamp of the last update to the instance. * BlobStorageSize (Type: INTEGER): Size of the blob storage in bytes. * Type (Type: STRING): Indicates the type of operation (e.g., INSERT, DELETE). This field is omitted if ChangeDataCaptureConfig is enabled. Corresponds to the JSON property schemaJson



3769
3770
3771
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3769

def schema_json
  @schema_json
end

#table_uriString

BigQuery URI to a table, up to 2000 characters long, in the format bq:// projectId.bqDatasetId.tableId Corresponds to the JSON property tableUri

Returns:

  • (String)


3775
3776
3777
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3775

def table_uri
  @table_uri
end

#write_dispositionString

Determines whether the existing table in the destination is to be overwritten or appended to. If a write_disposition is specified, the force parameter is ignored. Corresponds to the JSON property writeDisposition

Returns:

  • (String)


3782
3783
3784
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3782

def write_disposition
  @write_disposition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3789
3790
3791
3792
3793
3794
3795
3796
3797
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3789

def update!(**args)
  @change_data_capture_config = args[:change_data_capture_config] if args.key?(:change_data_capture_config)
  @force = args[:force] if args.key?(:force)
  @include_source_store = args[:include_source_store] if args.key?(:include_source_store)
  @schema_flattened = args[:schema_flattened] if args.key?(:schema_flattened)
  @schema_json = args[:schema_json] if args.key?(:schema_json)
  @table_uri = args[:table_uri] if args.key?(:table_uri)
  @write_disposition = args[:write_disposition] if args.key?(:write_disposition)
end