Class: Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirBigQueryDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The configuration for exporting to BigQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1FhirBigQueryDestination

Returns a new instance of GoogleCloudHealthcareV1beta1FhirBigQueryDestination.



3966
3967
3968
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_data_capture_configGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirChangeDataCaptureConfig

BigQuery Change Data Capture configuration. Corresponds to the JSON property changeDataCaptureConfig



3937
3938
3939
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3937

def change_data_capture_config
  @change_data_capture_config
end

#dataset_uriString

BigQuery URI to an existing dataset, up to 2000 characters long, in the format bq://projectId.bqDatasetId. Corresponds to the JSON property datasetUri

Returns:

  • (String)


3943
3944
3945
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3943

def dataset_uri
  @dataset_uri
end

#forceBoolean Also known as: force?

Use write_disposition instead. If write_disposition is specified, this parameter is ignored. force=false is equivalent to write_disposition= WRITE_EMPTY and force=true is equivalent to write_disposition=WRITE_TRUNCATE. Corresponds to the JSON property force

Returns:

  • (Boolean)


3950
3951
3952
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3950

def force
  @force
end

#schema_configGoogle::Apis::HealthcareV1beta1::SchemaConfig

Configuration for the FHIR BigQuery schema. Determines how the server generates the schema. Corresponds to the JSON property schemaConfig



3957
3958
3959
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3957

def schema_config
  @schema_config
end

#write_dispositionString

Determines if existing data in the destination dataset is overwritten, appended to, or not written if the tables contain data. If a write_disposition is specified, the force parameter is ignored. Corresponds to the JSON property writeDisposition

Returns:

  • (String)


3964
3965
3966
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3964

def write_disposition
  @write_disposition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3971
3972
3973
3974
3975
3976
3977
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3971

def update!(**args)
  @change_data_capture_config = args[:change_data_capture_config] if args.key?(:change_data_capture_config)
  @dataset_uri = args[:dataset_uri] if args.key?(:dataset_uri)
  @force = args[:force] if args.key?(:force)
  @schema_config = args[:schema_config] if args.key?(:schema_config)
  @write_disposition = args[:write_disposition] if args.key?(:write_disposition)
end