Class: Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirExportResourcesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Response when all resources export successfully. This structure is included in the response to describe the detailed outcome after the operation finishes successfully.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1FhirExportResourcesResponse

Returns a new instance of GoogleCloudHealthcareV1beta1FhirExportResourcesResponse.



4007
4008
4009
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4007

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4012
4013
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4012

def update!(**args)
end