Class: Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Specifies the configuration for importing data from Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1FhirGcsSource

Returns a new instance of GoogleCloudHealthcareV1beta1FhirGcsSource.



4098
4099
4100
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#uriString

Required. Points to a Cloud Storage URI containing file(s) to import. The URI must be in the following format: gs://bucket_id/object_id`. The URI can include wildcards inobject_idand thus identify multiple files. Supported wildcards: *to match 0 or more non-separator characters *to match 0 or more characters (including separators). Must be used at the end of a path and with no other wildcards in the path. Can also be used with a file extension (such as .ndjson), which imports all files with the extension in the specified directory and its sub-directories. For example,gs://my-bucket/my- directory/*.ndjsonimports all files with.ndjsonextensions inmy- directory/and its sub-directories. *?to match 1 character Files matching the wildcard are expected to contain content only, no metadata. Corresponds to the JSON propertyuri`

Returns:

  • (String)


4096
4097
4098
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4096

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4103
4104
4105
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4103

def update!(**args)
  @uri = args[:uri] if args.key?(:uri)
end