Class: Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirImportResourcesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Final response of importing resources. This structure is included in the response to describe the detailed outcome after the operation finishes successfully.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1FhirImportResourcesResponse

Returns a new instance of GoogleCloudHealthcareV1beta1FhirImportResourcesResponse.



4011
4012
4013
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4011

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4016
4017
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4016

def update!(**args)
end