Class: Google::Apis::HealthcareV1beta1::Hl7V2StoreMetric
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::Hl7V2StoreMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Count of messages and total storage size by type for a given HL7 store.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
The total count of HL7v2 messages in the store for the given message type.
-
#message_type ⇒ String
The Hl7v2 message type this metric applies to, such as
ADTorORU. -
#structured_storage_size_bytes ⇒ Fixnum
The total amount of structured storage used by HL7v2 messages of this message type in the store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Hl7V2StoreMetric
constructor
A new instance of Hl7V2StoreMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Hl7V2StoreMetric
Returns a new instance of Hl7V2StoreMetric.
4264 4265 4266 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
The total count of HL7v2 messages in the store for the given message type.
Corresponds to the JSON property count
4251 4252 4253 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4251 def count @count end |
#message_type ⇒ String
The Hl7v2 message type this metric applies to, such as ADT or ORU.
Corresponds to the JSON property messageType
4256 4257 4258 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4256 def @message_type end |
#structured_storage_size_bytes ⇒ Fixnum
The total amount of structured storage used by HL7v2 messages of this message
type in the store.
Corresponds to the JSON property structuredStorageSizeBytes
4262 4263 4264 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4262 def structured_storage_size_bytes @structured_storage_size_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4269 4270 4271 4272 4273 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4269 def update!(**args) @count = args[:count] if args.key?(:count) @message_type = args[:message_type] if args.key?(:message_type) @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes) end |