Class: Google::Apis::HealthcareV1beta1::Image

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Raw bytes representing consent artifact content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Image

Returns a new instance of Image.



4470
4471
4472
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_uriString

Input only. Points to a Cloud Storage URI containing the consent artifact content. The URI must be in the following format: gs://bucket_id/object_id . The Cloud Healthcare API service account must have the roles/storage. objectViewer Cloud IAM role for this Cloud Storage location. The consent artifact content at this URI is copied to a Cloud Storage location managed by the Cloud Healthcare API. Responses to fetching requests return the consent artifact content in raw_bytes. Corresponds to the JSON property gcsUri

Returns:

  • (String)


4460
4461
4462
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4460

def gcs_uri
  @gcs_uri
end

#raw_bytesString

Consent artifact content represented as a stream of bytes. This field is populated when returned in GetConsentArtifact response, but not included in CreateConsentArtifact and ListConsentArtifact response. Corresponds to the JSON property rawBytes NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4468
4469
4470
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4468

def raw_bytes
  @raw_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4475
4476
4477
4478
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4475

def update!(**args)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @raw_bytes = args[:raw_bytes] if args.key?(:raw_bytes)
end