Class: Google::Apis::HealthcareV1beta1::ImageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Specifies how to handle de-identification of image pixels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageConfig

Returns a new instance of ImageConfig.



4510
4511
4512
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_info_typesArray<String>

Additional InfoTypes to redact in the images in addition to those used by text_redaction_mode. Can only be used when text_redaction_mode is set to REDACT_SENSITIVE_TEXT, REDACT_SENSITIVE_TEXT_CLEAN_DESCRIPTORS or TEXT_REDACTION_MODE_UNSPECIFIED. Corresponds to the JSON property additionalInfoTypes

Returns:

  • (Array<String>)


4491
4492
4493
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4491

def additional_info_types
  @additional_info_types
end

#custom_regexesArray<Google::Apis::HealthcareV1beta1::CustomRegex>

Optional. Custom regex patterns to redact from the image. Corresponds to the JSON property customRegexes



4496
4497
4498
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4496

def custom_regexes
  @custom_regexes
end

#exclude_info_typesArray<String>

InfoTypes to skip redacting, overriding those used by text_redaction_mode. Can only be used when text_redaction_mode is set to REDACT_SENSITIVE_TEXT or REDACT_SENSITIVE_TEXT_CLEAN_DESCRIPTORS. Corresponds to the JSON property excludeInfoTypes

Returns:

  • (Array<String>)


4503
4504
4505
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4503

def exclude_info_types
  @exclude_info_types
end

#text_redaction_modeString

Determines how to redact text from image. Corresponds to the JSON property textRedactionMode

Returns:

  • (String)


4508
4509
4510
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4508

def text_redaction_mode
  @text_redaction_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4515
4516
4517
4518
4519
4520
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4515

def update!(**args)
  @additional_info_types = args[:additional_info_types] if args.key?(:additional_info_types)
  @custom_regexes = args[:custom_regexes] if args.key?(:custom_regexes)
  @exclude_info_types = args[:exclude_info_types] if args.key?(:exclude_info_types)
  @text_redaction_mode = args[:text_redaction_mode] if args.key?(:text_redaction_mode)
end