Class: Google::Apis::HealthcareV1beta1::ImportDicomDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Imports data into the specified DICOM store. Returns an error if any of the files to import are not DICOM files. This API accepts duplicate DICOM instances by ignoring the newly-pushed instance. It does not overwrite.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportDicomDataRequest

Returns a new instance of ImportDicomDataRequest.



4545
4546
4547
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_settingsGoogle::Apis::HealthcareV1beta1::BlobStorageSettings

Settings for data stored in Blob storage. Corresponds to the JSON property blobStorageSettings



4538
4539
4540
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4538

def blob_storage_settings
  @blob_storage_settings
end

#gcs_sourceGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomGcsSource

Specifies the configuration for importing data from Cloud Storage. Corresponds to the JSON property gcsSource



4543
4544
4545
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4543

def gcs_source
  @gcs_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4550
4551
4552
4553
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4550

def update!(**args)
  @blob_storage_settings = args[:blob_storage_settings] if args.key?(:blob_storage_settings)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
end