Class: Google::Apis::HealthcareV1beta1::ListConsentStoresResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListConsentStoresResponse

Returns a new instance of ListConsentStoresResponse.



4853
4854
4855
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The returned consent stores. The maximum number of stores returned is determined by the value of page_size in the ListConsentStoresRequest. Corresponds to the JSON property consentStores



4845
4846
4847
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4845

def consent_stores
  @consent_stores
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4851
4852
4853
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4851

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4858
4859
4860
4861
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4858

def update!(**args)
  @consent_stores = args[:consent_stores] if args.key?(:consent_stores)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end