Class: Google::Apis::HealthcareV1beta1::ListDatasetsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Lists the available datasets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDatasetsResponse

Returns a new instance of ListDatasetsResponse.



5009
5010
5011
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetsArray<Google::Apis::HealthcareV1beta1::Dataset>

The first page of datasets. Corresponds to the JSON property datasets



5001
5002
5003
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5001

def datasets
  @datasets
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5007
5008
5009
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5007

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5014
5015
5016
5017
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5014

def update!(**args)
  @datasets = args[:datasets] if args.key?(:datasets)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end