Class: Google::Apis::HealthcareV1beta1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



5072
5073
5074
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5057
5058
5059
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5057

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::HealthcareV1beta1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



5062
5063
5064
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5062

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


5070
5071
5072
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5070

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5077
5078
5079
5080
5081
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5077

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end