Class: Google::Apis::HealthcareV1beta1::Message

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

A complete HL7v2 message. See Introduction to HL7 Standards for details on the standard.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Message

Returns a new instance of Message.



5224
5225
5226
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The datetime when the message was created. Set by the server. Corresponds to the JSON property createTime

Returns:

  • (String)


5167
5168
5169
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5167

def create_time
  @create_time
end

#dataString

Required. Raw message bytes. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5173
5174
5175
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5173

def data
  @data
end

#labelsHash<String,String>

User-supplied key-value pairs used to organize HL7v2 stores. Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: \pLl\pLo 0,62 Label values are optional, must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be associated with a given store. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5184
5185
5186
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5184

def labels
  @labels
end

#message_typeString

The message type for this message. MSH-9.1. Corresponds to the JSON property messageType

Returns:

  • (String)


5189
5190
5191
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5189

def message_type
  @message_type
end

#nameString

Output only. Resource name of the Message, of the form projects/project_id/ locations/location_id/datasets/dataset_id/hl7V2Stores/hl7_v2_store_id/ messages/message_id`. Assigned by the server. Corresponds to the JSON propertyname`

Returns:

  • (String)


5196
5197
5198
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5196

def name
  @name
end

#parsed_dataGoogle::Apis::HealthcareV1beta1::ParsedData

The content of an HL7v2 message in a structured format. Corresponds to the JSON property parsedData



5201
5202
5203
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5201

def parsed_data
  @parsed_data
end

#patient_idsArray<Google::Apis::HealthcareV1beta1::PatientId>

All patient IDs listed in the PID-2, PID-3, and PID-4 segments of this message. Corresponds to the JSON property patientIds



5206
5207
5208
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5206

def patient_ids
  @patient_ids
end

#schematized_dataGoogle::Apis::HealthcareV1beta1::SchematizedData

The content of an HL7v2 message in a structured format as specified by a schema. Corresponds to the JSON property schematizedData



5212
5213
5214
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5212

def schematized_data
  @schematized_data
end

#send_facilityString

The hospital that this message came from. MSH-4. Corresponds to the JSON property sendFacility

Returns:

  • (String)


5217
5218
5219
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5217

def send_facility
  @send_facility
end

#send_timeString

The datetime the sending application sent this message. MSH-7. Corresponds to the JSON property sendTime

Returns:

  • (String)


5222
5223
5224
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5222

def send_time
  @send_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5229

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data = args[:data] if args.key?(:data)
  @labels = args[:labels] if args.key?(:labels)
  @message_type = args[:message_type] if args.key?(:message_type)
  @name = args[:name] if args.key?(:name)
  @parsed_data = args[:parsed_data] if args.key?(:parsed_data)
  @patient_ids = args[:patient_ids] if args.key?(:patient_ids)
  @schematized_data = args[:schematized_data] if args.key?(:schematized_data)
  @send_facility = args[:send_facility] if args.key?(:send_facility)
  @send_time = args[:send_time] if args.key?(:send_time)
end