Class: Google::Apis::HealthcareV1beta1::NotificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::NotificationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies where to send notifications upon changes to a data store.
Instance Attribute Summary collapse
-
#pubsub_topic ⇒ String
The Pub/Sub topic that notifications of changes are published on.
-
#send_for_bulk_import ⇒ Boolean
(also: #send_for_bulk_import?)
Indicates whether or not to send Pub/Sub notifications on bulk import.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationConfig
constructor
A new instance of NotificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationConfig
Returns a new instance of NotificationConfig.
5335 5336 5337 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pubsub_topic ⇒ String
The Pub/Sub topic that notifications
of changes are published on. Supplied by the client. PubsubMessage.Data
contains the resource name. PubsubMessage.MessageId is the ID of this message.
It is guaranteed to be unique within the topic. PubsubMessage.PublishTime is
the time at which the message was published. Notifications are only sent if
the topic is non-empty. Topic names must be scoped to a project. Cloud Healthcare API service
account must have publisher permissions on the given Pub/Sub topic. Not having
adequate permissions causes the calls that send notifications to fail. If a
notification can't be published to Pub/Sub, errors are logged to Cloud Logging
(see Viewing error logs in Cloud Logging). If the number of errors exceeds a certain rate, some
aren't submitted. Note that not all operations trigger notifications, see
Configuring Pub/Sub notifications for specific details.
Corresponds to the JSON property pubsubTopic
5326 5327 5328 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5326 def pubsub_topic @pubsub_topic end |
#send_for_bulk_import ⇒ Boolean Also known as: send_for_bulk_import?
Indicates whether or not to send Pub/Sub notifications on bulk import. Only
supported for DICOM imports.
Corresponds to the JSON property sendForBulkImport
5332 5333 5334 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5332 def send_for_bulk_import @send_for_bulk_import end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5340 5341 5342 5343 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5340 def update!(**args) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @send_for_bulk_import = args[:send_for_bulk_import] if args.key?(:send_for_bulk_import) end |