Class: Google::Apis::HealthcareV1beta1::QueryAccessibleDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Queries all data_ids that are consented for a given use in the given consent store and writes them to a specified destination. The returned Operation includes a progress counter for the number of User data mappings processed. Errors are logged to Cloud Logging (see Viewing error logs in Cloud Logging and [ QueryAccessibleData] for a sample log entry).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryAccessibleDataRequest

Returns a new instance of QueryAccessibleDataRequest.



5853
5854
5855
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_destinationGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1ConsentGcsDestination

The Cloud Storage location for export. Corresponds to the JSON property gcsDestination



5839
5840
5841
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5839

def gcs_destination
  @gcs_destination
end

#request_attributesHash<String,String>

The values of request attributes associated with this access request. Corresponds to the JSON property requestAttributes

Returns:

  • (Hash<String,String>)


5844
5845
5846
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5844

def request_attributes
  @request_attributes
end

#resource_attributesHash<String,String>

Optional. The values of resource attributes associated with the type of resources being requested. If no values are specified, then all resource types are included in the output. Corresponds to the JSON property resourceAttributes

Returns:

  • (Hash<String,String>)


5851
5852
5853
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5851

def resource_attributes
  @resource_attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5858
5859
5860
5861
5862
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5858

def update!(**args)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @request_attributes = args[:request_attributes] if args.key?(:request_attributes)
  @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes)
end