Class: Google::Apis::HealthcareV1beta1::Result

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The consent evaluation result for a single data_id.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Result

Returns a new instance of Result.



6042
6043
6044
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The resource names of all evaluated Consents mapped to their evaluation. Corresponds to the JSON property consentDetails



6029
6030
6031
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6029

def consent_details
  @consent_details
end

#consentedBoolean Also known as: consented?

Whether the resource is consented for the given use. Corresponds to the JSON property consented

Returns:

  • (Boolean)


6034
6035
6036
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6034

def consented
  @consented
end

#data_idString

The unique identifier of the evaluated resource. Corresponds to the JSON property dataId

Returns:

  • (String)


6040
6041
6042
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6040

def data_id
  @data_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6047
6048
6049
6050
6051
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6047

def update!(**args)
  @consent_details = args[:consent_details] if args.key?(:consent_details)
  @consented = args[:consented] if args.key?(:consented)
  @data_id = args[:data_id] if args.key?(:data_id)
end