Class: Google::Apis::HealthcareV1beta1::RevokeConsentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Revokes the latest revision of the specified Consent by committing a new revision with state updated to REVOKED. If the latest revision of the given Consent is in the REVOKED state, no new revision is committed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevokeConsentRequest

Returns a new instance of RevokeConsentRequest.



6074
6075
6076
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Optional. The resource name of the Consent artifact that contains proof of the user's revocation of the Consent, of the form projects/project_id/locations/ location_id/datasets/dataset_id/consentStores/consent_store_id/ consentArtifacts/consent_artifact_id`. Corresponds to the JSON propertyconsentArtifact`

Returns:

  • (String)


6072
6073
6074
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6072

def consent_artifact
  @consent_artifact
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6079
6080
6081
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6079

def update!(**args)
  @consent_artifact = args[:consent_artifact] if args.key?(:consent_artifact)
end