Class: Google::Apis::HealthcareV1beta1::RollbackFhirResourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Request to roll back resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackFhirResourcesRequest

Returns a new instance of RollbackFhirResourcesRequest.



6115
6116
6117
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_typeString

Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type. Corresponds to the JSON property changeType

Returns:

  • (String)


6075
6076
6077
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6075

def change_type
  @change_type
end

#exclude_rollbacksBoolean Also known as: exclude_rollbacks?

Optional. Specifies whether to exclude earlier rollbacks. Corresponds to the JSON property excludeRollbacks

Returns:

  • (Boolean)


6080
6081
6082
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6080

def exclude_rollbacks
  @exclude_rollbacks
end

#filtering_fieldsGoogle::Apis::HealthcareV1beta1::RollbackFhirResourceFilteringFields

Filters to select resources that need to be rolled back. Corresponds to the JSON property filteringFields



6086
6087
6088
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6086

def filtering_fields
  @filtering_fields
end

#forceBoolean Also known as: force?

Optional. When enabled, changes will be reverted without explicit confirmation Corresponds to the JSON property force

Returns:

  • (Boolean)


6091
6092
6093
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6091

def force
  @force
end

#input_gcs_objectString

Optional. Cloud Storage object containing list of resourceType/resourceId lines, identifying resources to be reverted Corresponds to the JSON property inputGcsObject

Returns:

  • (String)


6098
6099
6100
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6098

def input_gcs_object
  @input_gcs_object
end

#result_gcs_bucketString

Required. Bucket to deposit result Corresponds to the JSON property resultGcsBucket

Returns:

  • (String)


6103
6104
6105
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6103

def result_gcs_bucket
  @result_gcs_bucket
end

#rollback_timeString

Required. Time point to rollback to. Corresponds to the JSON property rollbackTime

Returns:

  • (String)


6108
6109
6110
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6108

def rollback_time
  @rollback_time
end

#typeArray<String>

Optional. If specified, revert only resources of these types Corresponds to the JSON property type

Returns:

  • (Array<String>)


6113
6114
6115
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6113

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6120

def update!(**args)
  @change_type = args[:change_type] if args.key?(:change_type)
  @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks)
  @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields)
  @force = args[:force] if args.key?(:force)
  @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object)
  @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket)
  @rollback_time = args[:rollback_time] if args.key?(:rollback_time)
  @type = args[:type] if args.key?(:type)
end