Class: Google::Apis::HealthcareV1beta1::RollbackHl7V2MessagesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Point in time recovery rollback request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackHl7V2MessagesRequest

Returns a new instance of RollbackHl7V2MessagesRequest.



6262
6263
6264
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_typeString

Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type. Corresponds to the JSON property changeType

Returns:

  • (String)


6226
6227
6228
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6226

def change_type
  @change_type
end

#exclude_rollbacksBoolean Also known as: exclude_rollbacks?

Optional. Specifies whether to exclude earlier rollbacks. Corresponds to the JSON property excludeRollbacks

Returns:

  • (Boolean)


6231
6232
6233
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6231

def exclude_rollbacks
  @exclude_rollbacks
end

#filtering_fieldsGoogle::Apis::HealthcareV1beta1::RollbackHl7MessagesFilteringFields

Filtering fields for an HL7v2 rollback. Currently only supports a list of operation ids to roll back. Corresponds to the JSON property filteringFields



6238
6239
6240
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6238

def filtering_fields
  @filtering_fields
end

#forceBoolean Also known as: force?

Optional. When enabled, changes will be reverted without explicit confirmation. Corresponds to the JSON property force

Returns:

  • (Boolean)


6243
6244
6245
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6243

def force
  @force
end

#input_gcs_objectString

Optional. Cloud storage object containing list of resourceId lines, identifying resources to be reverted Corresponds to the JSON property inputGcsObject

Returns:

  • (String)


6250
6251
6252
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6250

def input_gcs_object
  @input_gcs_object
end

#result_gcs_bucketString

Required. Bucket to deposit result Corresponds to the JSON property resultGcsBucket

Returns:

  • (String)


6255
6256
6257
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6255

def result_gcs_bucket
  @result_gcs_bucket
end

#rollback_timeString

Required. Times point to rollback to. Corresponds to the JSON property rollbackTime

Returns:

  • (String)


6260
6261
6262
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6260

def rollback_time
  @rollback_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6267
6268
6269
6270
6271
6272
6273
6274
6275
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6267

def update!(**args)
  @change_type = args[:change_type] if args.key?(:change_type)
  @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks)
  @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields)
  @force = args[:force] if args.key?(:force)
  @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object)
  @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket)
  @rollback_time = args[:rollback_time] if args.key?(:rollback_time)
end