Class: Google::Apis::HealthcareV1beta1::SchemaConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::SchemaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Configuration for the FHIR BigQuery schema. Determines how the server generates the schema.
Instance Attribute Summary collapse
-
#last_updated_partition_config ⇒ Google::Apis::HealthcareV1beta1::TimePartitioning
Configuration for FHIR BigQuery time-partitioned tables.
-
#recursive_structure_depth ⇒ Fixnum
The depth for all recursive structures in the output analytics schema.
-
#schema_type ⇒ String
Specifies the output schema type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchemaConfig
constructor
A new instance of SchemaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchemaConfig
Returns a new instance of SchemaConfig.
6323 6324 6325 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_updated_partition_config ⇒ Google::Apis::HealthcareV1beta1::TimePartitioning
Configuration for FHIR BigQuery time-partitioned tables.
Corresponds to the JSON property lastUpdatedPartitionConfig
6307 6308 6309 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6307 def last_updated_partition_config @last_updated_partition_config end |
#recursive_structure_depth ⇒ Fixnum
The depth for all recursive structures in the output analytics schema. For
example, concept in the CodeSystem resource is a recursive structure; when
the depth is 2, the CodeSystem table will have a column called concept.
concept but not concept.concept.concept. If not specified or set to 0, the
server will use the default value 2. The maximum depth allowed is 5.
Corresponds to the JSON property recursiveStructureDepth
6316 6317 6318 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6316 def recursive_structure_depth @recursive_structure_depth end |
#schema_type ⇒ String
Specifies the output schema type. Schema type is required.
Corresponds to the JSON property schemaType
6321 6322 6323 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6321 def schema_type @schema_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6328 6329 6330 6331 6332 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6328 def update!(**args) @last_updated_partition_config = args[:last_updated_partition_config] if args.key?(:last_updated_partition_config) @recursive_structure_depth = args[:recursive_structure_depth] if args.key?(:recursive_structure_depth) @schema_type = args[:schema_type] if args.key?(:schema_type) end |