Class: Google::Apis::HealthcareV1beta1::SchemaGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

An HL7v2 logical group construct.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaGroup

Returns a new instance of SchemaGroup.



6382
6383
6384
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#choiceBoolean Also known as: choice?

True indicates that this is a choice group, meaning that only one of its segments can exist in a given message. Corresponds to the JSON property choice

Returns:

  • (Boolean)


6358
6359
6360
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6358

def choice
  @choice
end

#max_occursFixnum

The maximum number of times this group can be repeated. 0 or -1 means unbounded. Corresponds to the JSON property maxOccurs

Returns:

  • (Fixnum)


6365
6366
6367
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6365

def max_occurs
  @max_occurs
end

#membersArray<Google::Apis::HealthcareV1beta1::GroupOrSegment>

Nested groups and/or segments. Corresponds to the JSON property members



6370
6371
6372
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6370

def members
  @members
end

#min_occursFixnum

The minimum number of times this group must be present/repeated. Corresponds to the JSON property minOccurs

Returns:

  • (Fixnum)


6375
6376
6377
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6375

def min_occurs
  @min_occurs
end

#nameString

The name of this group. For example, "ORDER_DETAIL". Corresponds to the JSON property name

Returns:

  • (String)


6380
6381
6382
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6380

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6387
6388
6389
6390
6391
6392
6393
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6387

def update!(**args)
  @choice = args[:choice] if args.key?(:choice)
  @max_occurs = args[:max_occurs] if args.key?(:max_occurs)
  @members = args[:members] if args.key?(:members)
  @min_occurs = args[:min_occurs] if args.key?(:min_occurs)
  @name = args[:name] if args.key?(:name)
end