Class: Google::Apis::HealthcareV1beta1::SchemaJson

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Using this field will set the schema such that all DICOM tags will be included in the BigQuery table as a single JSON type column. The BigQuery table schema will include the following columns: * StudyInstanceUID (Type: STRING): DICOM Tag 0020000D. * SeriesInstanceUID (Type: STRING): DICOM Tag 0020000E. * SOPInstanceUID (Type: STRING): DICOM Tag 00080018. * SourceDicomStore (Type: STRING): The name of the source DICOM store. This field is only included if the include_source_store option is set to true. * Metadata (Type: JSON): All DICOM tags for the instance, stored in a single JSON object. * StructuredStorageSize (Type: INTEGER): Size of the structured storage in bytes. * DroppedTags (Type: STRING, Repeated: Yes): List of tags that were dropped during the conversion. * StorageClass (Type: STRING): The storage class of the instance. * LastUpdated (Type: TIMESTAMP): Timestamp of the last update to the instance. * BlobStorageSize (Type: INTEGER): Size of the blob storage in bytes. * Type (Type: STRING): Indicates the type of operation (e.g., INSERT, DELETE). This field is omitted if ChangeDataCaptureConfig is enabled.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaJson

Returns a new instance of SchemaJson.



6306
6307
6308
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6306

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6311
6312
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6311

def update!(**args)
end