Class: Google::Apis::HealthcareV1beta1::SchemaSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

An HL7v2 Segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaSegment

Returns a new instance of SchemaSegment.



6450
6451
6452
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_occursFixnum

The maximum number of times this segment can be present in this group. 0 or -1 means unbounded. Corresponds to the JSON property maxOccurs

Returns:

  • (Fixnum)


6438
6439
6440
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6438

def max_occurs
  @max_occurs
end

#min_occursFixnum

The minimum number of times this segment can be present in this group. Corresponds to the JSON property minOccurs

Returns:

  • (Fixnum)


6443
6444
6445
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6443

def min_occurs
  @min_occurs
end

#typeString

The Segment type. For example, "PID". Corresponds to the JSON property type

Returns:

  • (String)


6448
6449
6450
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6448

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6455
6456
6457
6458
6459
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6455

def update!(**args)
  @max_occurs = args[:max_occurs] if args.key?(:max_occurs)
  @min_occurs = args[:min_occurs] if args.key?(:min_occurs)
  @type = args[:type] if args.key?(:type)
end