Class: Google::Apis::HealthcareV1beta1::StorageInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

StorageInfo encapsulates all the storage info of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageInfo

Returns a new instance of StorageInfo.



6857
6858
6859
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_infoGoogle::Apis::HealthcareV1beta1::BlobStorageInfo

BlobStorageInfo contains details about the data stored in Blob Storage for the referenced resource. Note: Storage class is only valid for DICOM and hence will only be populated for DICOM resources. Corresponds to the JSON property blobStorageInfo



6842
6843
6844
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6842

def blob_storage_info
  @blob_storage_info
end

#referenced_resourceString

The resource whose storage info is returned. For example: projects/projectID /locations/locationID/datasets/datasetID/dicomStores/dicomStoreID/ dicomWeb/studies/studyUID/series/seriesUID/instances/instanceUID` Corresponds to the JSON propertyreferencedResource`

Returns:

  • (String)


6849
6850
6851
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6849

def referenced_resource
  @referenced_resource
end

#structured_storage_infoGoogle::Apis::HealthcareV1beta1::StructuredStorageInfo

StructuredStorageInfo contains details about the data stored in Structured Storage for the referenced resource. Corresponds to the JSON property structuredStorageInfo



6855
6856
6857
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6855

def structured_storage_info
  @structured_storage_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6862
6863
6864
6865
6866
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6862

def update!(**args)
  @blob_storage_info = args[:blob_storage_info] if args.key?(:blob_storage_info)
  @referenced_resource = args[:referenced_resource] if args.key?(:referenced_resource)
  @structured_storage_info = args[:structured_storage_info] if args.key?(:structured_storage_info)
end