Class: Google::Apis::HealthcareV1beta1::StreamConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Contains configuration for streaming FHIR export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamConfig

Returns a new instance of StreamConfig.



6891
6892
6893
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirBigQueryDestination

The configuration for exporting to BigQuery. Corresponds to the JSON property bigqueryDestination



6876
6877
6878
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6876

def bigquery_destination
  @bigquery_destination
end

#deidentified_store_destinationGoogle::Apis::HealthcareV1beta1::DeidentifiedStoreDestination

Contains configuration for streaming de-identified FHIR export. Corresponds to the JSON property deidentifiedStoreDestination



6881
6882
6883
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6881

def deidentified_store_destination
  @deidentified_store_destination
end

#resource_typesArray<String>

Supply a FHIR resource type (such as "Patient" or "Observation"). See https:// www.hl7.org/fhir/valueset-resource-types.html for a list of all FHIR resource types. The server treats an empty list as an intent to stream all the supported resource types in this FHIR store. Corresponds to the JSON property resourceTypes

Returns:

  • (Array<String>)


6889
6890
6891
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6889

def resource_types
  @resource_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6896
6897
6898
6899
6900
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6896

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @deidentified_store_destination = args[:deidentified_store_destination] if args.key?(:deidentified_store_destination)
  @resource_types = args[:resource_types] if args.key?(:resource_types)
end