Class: Google::Apis::HealthcareV1beta1::StudyMetrics
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::StudyMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
StudyMetrics contains metrics describing a DICOM study.
Instance Attribute Summary collapse
-
#blob_storage_size_bytes ⇒ Fixnum
Total blob storage bytes for all instances in the study.
-
#instance_count ⇒ Fixnum
Number of instances in the study.
-
#series_count ⇒ Fixnum
Number of series in the study.
-
#structured_storage_size_bytes ⇒ Fixnum
Total structured storage bytes for all instances in the study.
-
#study ⇒ String
The study resource path.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StudyMetrics
constructor
A new instance of StudyMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StudyMetrics
Returns a new instance of StudyMetrics.
6845 6846 6847 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_storage_size_bytes ⇒ Fixnum
Total blob storage bytes for all instances in the study.
Corresponds to the JSON property blobStorageSizeBytes
6821 6822 6823 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6821 def blob_storage_size_bytes @blob_storage_size_bytes end |
#instance_count ⇒ Fixnum
Number of instances in the study.
Corresponds to the JSON property instanceCount
6826 6827 6828 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6826 def instance_count @instance_count end |
#series_count ⇒ Fixnum
Number of series in the study.
Corresponds to the JSON property seriesCount
6831 6832 6833 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6831 def series_count @series_count end |
#structured_storage_size_bytes ⇒ Fixnum
Total structured storage bytes for all instances in the study.
Corresponds to the JSON property structuredStorageSizeBytes
6836 6837 6838 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6836 def structured_storage_size_bytes @structured_storage_size_bytes end |
#study ⇒ String
The study resource path. For example, projects/project_id/locations/
location_id/datasets/dataset_id/dicomStores/dicom_store_id/dicomWeb/
studies/study_uid`.
Corresponds to the JSON propertystudy`
6843 6844 6845 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6843 def study @study end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6850 6851 6852 6853 6854 6855 6856 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6850 def update!(**args) @blob_storage_size_bytes = args[:blob_storage_size_bytes] if args.key?(:blob_storage_size_bytes) @instance_count = args[:instance_count] if args.key?(:instance_count) @series_count = args[:series_count] if args.key?(:series_count) @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes) @study = args[:study] if args.key?(:study) end |