Class: Google::Apis::HealthcareV1beta1::TextConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::TextConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Configures how to transform sensitive text InfoTypes.
Instance Attribute Summary collapse
-
#additional_transformations ⇒ Array<Google::Apis::HealthcareV1beta1::InfoTypeTransformation>
Additional transformations to apply to the detected data, overriding
profile. -
#exclude_info_types ⇒ Array<String>
InfoTypes to skip transforming, overriding
profile. -
#profile_type ⇒ String
Base profile type for text transformation.
-
#transformations ⇒ Array<Google::Apis::HealthcareV1beta1::InfoTypeTransformation>
The transformations to apply to the detected data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TextConfig
constructor
A new instance of TextConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TextConfig
Returns a new instance of TextConfig.
7049 7050 7051 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_transformations ⇒ Array<Google::Apis::HealthcareV1beta1::InfoTypeTransformation>
Additional transformations to apply to the detected data, overriding profile.
Corresponds to the JSON property additionalTransformations
7031 7032 7033 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7031 def additional_transformations @additional_transformations end |
#exclude_info_types ⇒ Array<String>
InfoTypes to skip transforming, overriding profile.
Corresponds to the JSON property excludeInfoTypes
7036 7037 7038 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7036 def exclude_info_types @exclude_info_types end |
#profile_type ⇒ String
Base profile type for text transformation.
Corresponds to the JSON property profileType
7041 7042 7043 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7041 def profile_type @profile_type end |
#transformations ⇒ Array<Google::Apis::HealthcareV1beta1::InfoTypeTransformation>
The transformations to apply to the detected data. Deprecated. Use
additional_transformations instead.
Corresponds to the JSON property transformations
7047 7048 7049 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7047 def transformations @transformations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7054 7055 7056 7057 7058 7059 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7054 def update!(**args) @additional_transformations = args[:additional_transformations] if args.key?(:additional_transformations) @exclude_info_types = args[:exclude_info_types] if args.key?(:exclude_info_types) @profile_type = args[:profile_type] if args.key?(:profile_type) @transformations = args[:transformations] if args.key?(:transformations) end |