Class: Google::Apis::HealthcareV1beta1::TimeRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Apply consents given by patients whose most recent consent changes are in the time range. Note that after identifying these patients, the server applies all Consent resources given by those patients, not just the Consent resources within the timestamp in the range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeRange

Returns a new instance of TimeRange.



7137
7138
7139
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

Optional. The latest consent change time, in format YYYY-MM-DDThh:mm:ss.sss+zz: zz If not specified, the system uses the time when ApplyConsents was called. Corresponds to the JSON property end

Returns:

  • (String)


7129
7130
7131
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7129

def end
  @end
end

#startString

Optional. The earliest consent change time, in format YYYY-MM-DDThh:mm:ss.sss+ zz:zz If not specified, the system uses the FHIR store creation time. Corresponds to the JSON property start

Returns:

  • (String)


7135
7136
7137
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7135

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7142
7143
7144
7145
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7142

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @start = args[:start] if args.key?(:start)
end