Class: Google::Apis::HealthcareV1beta1::UserDataMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Maps a resource to the associated user and Attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserDataMapping

Returns a new instance of UserDataMapping.



7247
7248
7249
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_timeString

Output only. Indicates the time when this mapping was archived. Corresponds to the JSON property archiveTime

Returns:

  • (String)


7214
7215
7216
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7214

def archive_time
  @archive_time
end

#archivedBoolean Also known as: archived?

Output only. Indicates whether this mapping is archived. Corresponds to the JSON property archived

Returns:

  • (Boolean)


7219
7220
7221
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7219

def archived
  @archived
end

#data_idString

Required. A unique identifier for the mapped resource. Corresponds to the JSON property dataId

Returns:

  • (String)


7225
7226
7227
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7225

def data_id
  @data_id
end

#nameString

Resource name of the User data mapping, of the form projects/project_id/ locations/location_id/datasets/dataset_id/consentStores/consent_store_id/ userDataMappings/user_data_mapping_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


7232
7233
7234
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7232

def name
  @name
end

#resource_attributesArray<Google::Apis::HealthcareV1beta1::Attribute>

Attributes of the resource. Only explicitly set attributes are displayed here. Attribute definitions with defaults set implicitly apply to these User data mappings. Attributes listed here must be single valued, that is, exactly one value is specified for the field "values" in each Attribute. Corresponds to the JSON property resourceAttributes



7240
7241
7242
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7240

def resource_attributes
  @resource_attributes
end

#user_idString

Required. User's UUID provided by the client. Corresponds to the JSON property userId

Returns:

  • (String)


7245
7246
7247
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7245

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7252
7253
7254
7255
7256
7257
7258
7259
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7252

def update!(**args)
  @archive_time = args[:archive_time] if args.key?(:archive_time)
  @archived = args[:archived] if args.key?(:archived)
  @data_id = args[:data_id] if args.key?(:data_id)
  @name = args[:name] if args.key?(:name)
  @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes)
  @user_id = args[:user_id] if args.key?(:user_id)
end