Class: Google::Apis::HealthcareV1beta1::ValidationConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ValidationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Contains the configuration for FHIR profiles and validation.
Instance Attribute Summary collapse
-
#disable_fhirpath_validation ⇒ Boolean
(also: #disable_fhirpath_validation?)
Whether to disable FHIRPath validation for incoming resources.
-
#disable_profile_validation ⇒ Boolean
(also: #disable_profile_validation?)
Whether to disable profile validation for this FHIR store.
-
#disable_reference_type_validation ⇒ Boolean
(also: #disable_reference_type_validation?)
Whether to disable reference type validation for incoming resources.
-
#disable_required_field_validation ⇒ Boolean
(also: #disable_required_field_validation?)
Whether to disable required fields validation for incoming resources.
-
#enable_fhirpath_profile_validation ⇒ Boolean
(also: #enable_fhirpath_profile_validation?)
Optional.
-
#enabled_implementation_guides ⇒ Array<String>
A list of ImplementationGuide URLs in this FHIR store that are used to configure the profiles to use for validation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ValidationConfig
constructor
A new instance of ValidationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ValidationConfig
Returns a new instance of ValidationConfig.
7333 7334 7335 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_fhirpath_validation ⇒ Boolean Also known as: disable_fhirpath_validation?
Whether to disable FHIRPath validation for incoming resources. The default
value is false. Set this to true to disable checking incoming resources for
conformance against FHIRPath requirement defined in the FHIR specification.
This property only affects resource types that do not have profiles configured
for them, any rules in enabled implementation guides will still be enforced.
Corresponds to the JSON property disableFhirpathValidation
7273 7274 7275 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7273 def disable_fhirpath_validation @disable_fhirpath_validation end |
#disable_profile_validation ⇒ Boolean Also known as: disable_profile_validation?
Whether to disable profile validation for this FHIR store. The default value
is false. Set this to true to disable checking incoming resources for
conformance against StructureDefinitions in this FHIR store.
Corresponds to the JSON property disableProfileValidation
7281 7282 7283 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7281 def disable_profile_validation @disable_profile_validation end |
#disable_reference_type_validation ⇒ Boolean Also known as: disable_reference_type_validation?
Whether to disable reference type validation for incoming resources. The
default value is false. Set this to true to disable checking incoming
resources for conformance against reference type requirement defined in the
FHIR specification. This property only affects resource types that do not have
profiles configured for them, any rules in enabled implementation guides will
still be enforced.
Corresponds to the JSON property disableReferenceTypeValidation
7292 7293 7294 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7292 def disable_reference_type_validation @disable_reference_type_validation end |
#disable_required_field_validation ⇒ Boolean Also known as: disable_required_field_validation?
Whether to disable required fields validation for incoming resources. The
default value is false. Set this to true to disable checking incoming
resources for conformance against required fields requirement defined in the
FHIR specification. This property only affects resource types that do not have
profiles configured for them, any rules in enabled implementation guides will
still be enforced.
Corresponds to the JSON property disableRequiredFieldValidation
7303 7304 7305 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7303 def disable_required_field_validation @disable_required_field_validation end |
#enable_fhirpath_profile_validation ⇒ Boolean Also known as: enable_fhirpath_profile_validation?
Optional. Whether to enable FHIRPath validation for incoming resource types
that have profiles configured for them in the enabled_implementation_guides
list. Set this to true to enable checking incoming resources for conformance
against FHIRPath requirements defined in the configured profiles.
Corresponds to the JSON property enableFhirpathProfileValidation
7312 7313 7314 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7312 def enable_fhirpath_profile_validation @enable_fhirpath_profile_validation end |
#enabled_implementation_guides ⇒ Array<String>
A list of ImplementationGuide URLs in this FHIR store that are used to
configure the profiles to use for validation. For example, to use the US Core
profiles for validation, set enabled_implementation_guides to ["http://hl7.
org/fhir/us/core/ImplementationGuide/ig"]. If enabled_implementation_guides
is empty or omitted, then incoming resources are only required to conform to
the base FHIR profiles. Otherwise, a resource must conform to at least one
profile listed in the global property of one of the enabled
ImplementationGuides. The Cloud Healthcare API does not currently enforce all
of the rules in a StructureDefinition. The following rules are supported: -
min/max - minValue/maxValue - maxLength - type - fixed[x] - pattern[x] on
simple types - slicing, when using "value" as the discriminator type -
FHIRPath constraints (only when enable_fhirpath_profile_validation is true)
When a URL cannot be resolved (for example, in a type assertion), the server
does not return an error.
Corresponds to the JSON property enabledImplementationGuides
7331 7332 7333 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7331 def enabled_implementation_guides @enabled_implementation_guides end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7338 7339 7340 7341 7342 7343 7344 7345 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7338 def update!(**args) @disable_fhirpath_validation = args[:disable_fhirpath_validation] if args.key?(:disable_fhirpath_validation) @disable_profile_validation = args[:disable_profile_validation] if args.key?(:disable_profile_validation) @disable_reference_type_validation = args[:disable_reference_type_validation] if args.key?(:disable_reference_type_validation) @disable_required_field_validation = args[:disable_required_field_validation] if args.key?(:disable_required_field_validation) @enable_fhirpath_profile_validation = args[:enable_fhirpath_profile_validation] if args.key?(:enable_fhirpath_profile_validation) @enabled_implementation_guides = args[:enabled_implementation_guides] if args.key?(:enabled_implementation_guides) end |