Class: Google::Apis::HealthcareV1beta1::AttributeDefinition
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::AttributeDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
A client-defined consent attribute.
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<String>
Required.
-
#category ⇒ String
Required.
-
#consent_default_values ⇒ Array<String>
Optional.
-
#data_mapping_default_value ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttributeDefinition
constructor
A new instance of AttributeDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttributeDefinition
Returns a new instance of AttributeDefinition.
546 547 548 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_values ⇒ Array<String>
Required. Possible values for the attribute. The number of allowed values must
not exceed 500. An empty list is invalid. The list can only be expanded after
creation.
Corresponds to the JSON property allowedValues
512 513 514 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 512 def allowed_values @allowed_values end |
#category ⇒ String
Required. The category of the attribute. The value of this field cannot be
changed after creation.
Corresponds to the JSON property category
518 519 520 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 518 def category @category end |
#consent_default_values ⇒ Array<String>
Optional. Default values of the attribute in Consents. If no default values
are specified, it defaults to an empty value.
Corresponds to the JSON property consentDefaultValues
524 525 526 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 524 def @consent_default_values end |
#data_mapping_default_value ⇒ String
Optional. Default value of the attribute in User data mappings. If no default
value is specified, it defaults to an empty value. This field is only
applicable to attributes of the category RESOURCE.
Corresponds to the JSON property dataMappingDefaultValue
531 532 533 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 531 def data_mapping_default_value @data_mapping_default_value end |
#description ⇒ String
Optional. A description of the attribute.
Corresponds to the JSON property description
536 537 538 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 536 def description @description end |
#name ⇒ String
Identifier. Resource name of the Attribute definition, of the form projects/
project_id/locations/location_id/datasets/dataset_id/consentStores/
consent_store_id/attributeDefinitions/attribute_definition_id`. Cannot be
changed after creation.
Corresponds to the JSON propertyname`
544 545 546 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 544 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
551 552 553 554 555 556 557 558 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 551 def update!(**args) @allowed_values = args[:allowed_values] if args.key?(:allowed_values) @category = args[:category] if args.key?(:category) @consent_default_values = args[:consent_default_values] if args.key?(:consent_default_values) @data_mapping_default_value = args[:data_mapping_default_value] if args.key?(:data_mapping_default_value) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) end |