Class: Google::Apis::HealthcareV1beta1::BulkDeleteResourcesRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::BulkDeleteResourcesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Request to bulk delete FHIR resources.
Instance Attribute Summary collapse
-
#gcs_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsDestination
The configuration for exporting to Cloud Storage.
-
#type ⇒ String
Optional.
-
#until ⇒ String
Optional.
-
#version_config ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkDeleteResourcesRequest
constructor
A new instance of BulkDeleteResourcesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkDeleteResourcesRequest
Returns a new instance of BulkDeleteResourcesRequest.
833 834 835 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsDestination
The configuration for exporting to Cloud Storage.
Corresponds to the JSON property gcsDestination
812 813 814 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 812 def gcs_destination @gcs_destination end |
#type ⇒ String
Optional. String of comma-delimited FHIR resource types. If provided, only
resources of the specified resource type(s) will be deleted.
Corresponds to the JSON property type
818 819 820 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 818 def type @type end |
#until ⇒ String
Optional. If provided, only resources updated before or atthis time are
deleted. The time uses the format YYYY-MM-DDThh:mm:ss.sss+zz:zz. For example,
2015-02-07T13:28:17.239+02:00 or 2017-01-01T00:00:00Z. The time must be
specified to the second and include a time zone.
Corresponds to the JSON property until
826 827 828 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 826 def until @until end |
#version_config ⇒ String
Optional. Specifies which version of the resources to delete.
Corresponds to the JSON property versionConfig
831 832 833 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 831 def version_config @version_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
838 839 840 841 842 843 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 838 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @type = args[:type] if args.key?(:type) @until = args[:until] if args.key?(:until) @version_config = args[:version_config] if args.key?(:version_config) end |