Class: Google::Apis::HealthcareV1beta1::ConfigureSearchRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ConfigureSearchRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Request to configure the search parameters for the specified FHIR store.
Instance Attribute Summary collapse
-
#canonical_urls ⇒ Array<String>
The canonical URLs of the search parameters that are intended to be used for the FHIR store.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If
validate_onlyis set to true, the method will compile all the search parameters without actually setting the search config for the store and triggering the reindex.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigureSearchRequest
constructor
A new instance of ConfigureSearchRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigureSearchRequest
Returns a new instance of ConfigureSearchRequest.
1013 1014 1015 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_urls ⇒ Array<String>
The canonical URLs of the search parameters that are intended to be used for
the FHIR store. See https://www.hl7.org/fhir/references.html#canonical for
explanation on FHIR canonical urls
Corresponds to the JSON property canonicalUrls
1003 1004 1005 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1003 def canonical_urls @canonical_urls end |
#validate_only ⇒ Boolean Also known as: validate_only?
If validate_only is set to true, the method will compile all the search
parameters without actually setting the search config for the store and
triggering the reindex.
Corresponds to the JSON property validateOnly
1010 1011 1012 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1010 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1018 1019 1020 1021 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1018 def update!(**args) @canonical_urls = args[:canonical_urls] if args.key?(:canonical_urls) @validate_only = args[:validate_only] if args.key?(:validate_only) end |