Class: Google::Apis::HealthcareV1beta1::ConsentAccessorScope
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ConsentAccessorScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
The accessor scope that describes who can access, for what purpose, in which environment.
Instance Attribute Summary collapse
-
#actor ⇒ String
An individual, group, or access role that identifies the accessor or a characteristic of the accessor.
-
#environment ⇒ String
An abstract identifier that describes the environment or conditions under which the accessor is acting.
-
#purpose ⇒ String
The intent of data use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsentAccessorScope
constructor
A new instance of ConsentAccessorScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsentAccessorScope
Returns a new instance of ConsentAccessorScope.
1187 1188 1189 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actor ⇒ String
An individual, group, or access role that identifies the accessor or a
characteristic of the accessor. This can be a resource ID (such as
resourceType`/`id) or an external URI. This value must be present.
Corresponds to the JSON property actor
1173 1174 1175 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1173 def actor @actor end |
#environment ⇒ String
An abstract identifier that describes the environment or conditions under
which the accessor is acting. If it's not specified, it applies to all
environments.
Corresponds to the JSON property environment
1180 1181 1182 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1180 def environment @environment end |
#purpose ⇒ String
The intent of data use. If it's not specified, it applies to all purposes.
Corresponds to the JSON property purpose
1185 1186 1187 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1185 def purpose @purpose end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1192 1193 1194 1195 1196 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1192 def update!(**args) @actor = args[:actor] if args.key?(:actor) @environment = args[:environment] if args.key?(:environment) @purpose = args[:purpose] if args.key?(:purpose) end |