Class: Google::Apis::HealthcareV1beta1::ConsentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Configures whether to enforce consent for the FHIR store and which consent enforcement version is being used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsentConfig

Returns a new instance of ConsentConfig.



1311
1312
1313
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_determination_log_configGoogle::Apis::HealthcareV1beta1::AccessDeterminationLogConfig

Configures consent audit log config for FHIR create, read, update, and delete ( CRUD) operations. Cloud audit log for healthcare API must be enabled. The consent-related logs are included as part of protoPayload. metadata. Corresponds to the JSON property accessDeterminationLogConfig



1278
1279
1280
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1278

def access_determination_log_config
  @access_determination_log_config
end

#access_enforcedBoolean Also known as: access_enforced?

Optional. The default value is false. If set to true, when accessing FHIR resources, the consent headers will be verified against consents given by patients. See the ConsentEnforcementVersion for the supported consent headers. Corresponds to the JSON property accessEnforced

Returns:

  • (Boolean)


1285
1286
1287
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1285

def access_enforced
  @access_enforced
end

How the server handles the consent header. Corresponds to the JSON property consentHeaderHandling



1291
1292
1293
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1291

def consent_header_handling
  @consent_header_handling
end

#enforced_admin_consentsArray<String>

Output only. The versioned names of the enforced admin Consent resource(s), in the format projects/project_id/locations/location/datasets/dataset_id/ fhirStores/fhir_store_id/fhir/Consent/resource_id/_history/version_id. For FHIR stores with `disable_resource_versioning=true`, the format is ` projects/`project_id`/locations/`location`/datasets/`dataset_id`/fhirStores/` fhir_store_id`/fhir/Consent/`resource_id. This field can only be updated using ApplyAdminConsents. Corresponds to the JSON property enforcedAdminConsents

Returns:

  • (Array<String>)


1302
1303
1304
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1302

def enforced_admin_consents
  @enforced_admin_consents
end

#versionString

Required. Specifies which consent enforcement version is being used for this FHIR store. This field can only be set once by either CreateFhirStore or UpdateFhirStore. After that, you must call ApplyConsents to change the version. Corresponds to the JSON property version

Returns:

  • (String)


1309
1310
1311
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1309

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1316
1317
1318
1319
1320
1321
1322
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1316

def update!(**args)
  @access_determination_log_config = args[:access_determination_log_config] if args.key?(:access_determination_log_config)
  @access_enforced = args[:access_enforced] if args.key?(:access_enforced)
  @consent_header_handling = args[:consent_header_handling] if args.key?(:consent_header_handling)
  @enforced_admin_consents = args[:enforced_admin_consents] if args.key?(:enforced_admin_consents)
  @version = args[:version] if args.key?(:version)
end