Class: Google::Apis::HealthcareV1beta1::ConsentConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ConsentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Configures whether to enforce consent for the FHIR store and which consent enforcement version is being used.
Instance Attribute Summary collapse
-
#access_determination_log_config ⇒ Google::Apis::HealthcareV1beta1::AccessDeterminationLogConfig
Configures consent audit log config for FHIR create, read, update, and delete ( CRUD) operations.
-
#access_enforced ⇒ Boolean
(also: #access_enforced?)
Optional.
-
#consent_header_handling ⇒ Google::Apis::HealthcareV1beta1::ConsentHeaderHandling
How the server handles the consent header.
-
#enforced_admin_consents ⇒ Array<String>
Output only.
-
#version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsentConfig
constructor
A new instance of ConsentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsentConfig
Returns a new instance of ConsentConfig.
1260 1261 1262 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_determination_log_config ⇒ Google::Apis::HealthcareV1beta1::AccessDeterminationLogConfig
Configures consent audit log config for FHIR create, read, update, and delete (
CRUD) operations. Cloud audit log for healthcare API must be enabled. The consent-related logs are included as part of protoPayload.
metadata.
Corresponds to the JSON property accessDeterminationLogConfig
1227 1228 1229 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1227 def access_determination_log_config @access_determination_log_config end |
#access_enforced ⇒ Boolean Also known as: access_enforced?
Optional. The default value is false. If set to true, when accessing FHIR
resources, the consent headers will be verified against consents given by
patients. See the ConsentEnforcementVersion for the supported consent headers.
Corresponds to the JSON property accessEnforced
1234 1235 1236 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1234 def access_enforced @access_enforced end |
#consent_header_handling ⇒ Google::Apis::HealthcareV1beta1::ConsentHeaderHandling
How the server handles the consent header.
Corresponds to the JSON property consentHeaderHandling
1240 1241 1242 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1240 def @consent_header_handling end |
#enforced_admin_consents ⇒ Array<String>
Output only. The versioned names of the enforced admin Consent resource(s), in
the format projects/project_id/locations/location/datasets/dataset_id/
fhirStores/fhir_store_id/fhir/Consent/resource_id/_history/version_id.
For FHIR stores with `disable_resource_versioning=true`, the format is `
projects/`project_id`/locations/`location`/datasets/`dataset_id`/fhirStores/`
fhir_store_id`/fhir/Consent/`resource_id. This field can only be updated
using ApplyAdminConsents.
Corresponds to the JSON property enforcedAdminConsents
1251 1252 1253 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1251 def @enforced_admin_consents end |
#version ⇒ String
Required. Specifies which consent enforcement version is being used for this
FHIR store. This field can only be set once by either CreateFhirStore or
UpdateFhirStore. After that, you must call ApplyConsents to change the version.
Corresponds to the JSON property version
1258 1259 1260 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1258 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1265 def update!(**args) @access_determination_log_config = args[:access_determination_log_config] if args.key?(:access_determination_log_config) @access_enforced = args[:access_enforced] if args.key?(:access_enforced) @consent_header_handling = args[:consent_header_handling] if args.key?(:consent_header_handling) @enforced_admin_consents = args[:enforced_admin_consents] if args.key?(:enforced_admin_consents) @version = args[:version] if args.key?(:version) end |