Class: Google::Apis::HealthcareV1beta1::ConsentErrors
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ConsentErrors
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
The Consent resource name and error.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::HealthcareV1beta1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#name ⇒ String
The versioned name of the admin Consent resource, in the format
projects/project_id/locations/location/datasets/dataset_id/fhirStores/fhir_store_id/fhir/Consent/resource_id/_history/version_id``.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsentErrors
constructor
A new instance of ConsentErrors.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsentErrors
Returns a new instance of ConsentErrors.
1339 1340 1341 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::HealthcareV1beta1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1327 1328 1329 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1327 def error @error end |
#name ⇒ String
The versioned name of the admin Consent resource, in the format projects/
project_id/locations/location/datasets/dataset_id/fhirStores/
fhir_store_id/fhir/Consent/resource_id/_history/version_id. For FHIR
stores with `disable_resource_versioning=true`, the format is `projects/`
project_id`/locations/`location`/datasets/`dataset_id`/fhirStores/`
fhir_store_id`/fhir/Consent/`resource_id.
Corresponds to the JSON property name
1337 1338 1339 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1337 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1344 1345 1346 1347 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1344 def update!(**args) @error = args[:error] if args.key?(:error) @name = args[:name] if args.key?(:name) end |