Class: Google::Apis::HealthcareV1beta1::ConsentStore
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ConsentStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Represents a consent store.
Instance Attribute Summary collapse
-
#default_consent_ttl ⇒ String
Optional.
-
#enable_consent_create_on_update ⇒ Boolean
(also: #enable_consent_create_on_update?)
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Resource name of the consent store, of the form
projects/project_id/ locations/location_id/datasets/dataset_id/consentStores/consent_store_id`` .
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsentStore
constructor
A new instance of ConsentStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsentStore
Returns a new instance of ConsentStore.
1447 1448 1449 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_consent_ttl ⇒ String
Optional. Default time to live for Consents created in this store. Must be at
least 24 hours. Updating this field will not affect the expiration time of
existing consents.
Corresponds to the JSON property defaultConsentTtl
1419 1420 1421 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1419 def @default_consent_ttl end |
#enable_consent_create_on_update ⇒ Boolean Also known as: enable_consent_create_on_update?
Optional. If true, UpdateConsent creates the Consent if it does not already
exist. If unspecified, defaults to false.
Corresponds to the JSON property enableConsentCreateOnUpdate
1425 1426 1427 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1425 def @enable_consent_create_on_update end |
#labels ⇒ Hash<String,String>
Optional. User-supplied key-value pairs used to organize consent stores. Label
keys must be between 1 and 63 characters long, have a UTF-8 encoding of
maximum 128 bytes, and must conform to the following PCRE regular expression: \
pLl\pLo0,62. Label values must be between 1 and 63 characters long, have
a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE
regular expression: [\pLl\pLo\pN_-]0,63. No more than 64 labels can be
associated with a given store. For more information: https://cloud.google.com/
healthcare/docs/how-tos/labeling-resources
Corresponds to the JSON property labels
1438 1439 1440 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1438 def labels @labels end |
#name ⇒ String
Resource name of the consent store, of the form projects/project_id/
locations/location_id/datasets/dataset_id/consentStores/consent_store_id`
. Cannot be changed after creation.
Corresponds to the JSON propertyname`
1445 1446 1447 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1445 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1452 1453 1454 1455 1456 1457 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1452 def update!(**args) @default_consent_ttl = args[:default_consent_ttl] if args.key?(:default_consent_ttl) @enable_consent_create_on_update = args[:enable_consent_create_on_update] if args.key?(:enable_consent_create_on_update) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) end |