Class: Google::Apis::HealthcareV1beta1::Dataset
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::Dataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
A message representing a health dataset. A health dataset represents a collection of healthcare data pertaining to one or more patients. This may include multiple modalities of healthcare data, such as electronic medical records or medical imaging data.
Instance Attribute Summary collapse
-
#encryption_spec ⇒ Google::Apis::HealthcareV1beta1::EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a resource.
-
#name ⇒ String
Identifier.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#time_zone ⇒ String
The default timezone used by this dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Dataset
constructor
A new instance of Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Dataset
Returns a new instance of Dataset.
1622 1623 1624 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_spec ⇒ Google::Apis::HealthcareV1beta1::EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a
resource.
Corresponds to the JSON property encryptionSpec
1594 1595 1596 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1594 def encryption_spec @encryption_spec end |
#name ⇒ String
Identifier. Resource name of the dataset, of the form projects/project_id/
locations/location_id/datasets/dataset_id`.
Corresponds to the JSON propertyname`
1600 1601 1602 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1600 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Whether the dataset satisfies zone isolation.
Corresponds to the JSON property satisfiesPzi
1605 1606 1607 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1605 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Whether the dataset satisfies zone separation.
Corresponds to the JSON property satisfiesPzs
1611 1612 1613 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1611 def satisfies_pzs @satisfies_pzs end |
#time_zone ⇒ String
The default timezone used by this dataset. Must be a either a valid IANA time
zone name such as "America/New_York" or empty, which defaults to UTC. This is
used for parsing times in resources, such as HL7 messages, where no explicit
timezone is specified.
Corresponds to the JSON property timeZone
1620 1621 1622 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1620 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1627 def update!(**args) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @time_zone = args[:time_zone] if args.key?(:time_zone) end |