Class: Google::Apis::HealthcareV1beta1::DeidentifyConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::DeidentifyConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Configures de-id options specific to different types of content. Each submessage customizes the handling of an https://tools.ietf.org/html/rfc6838 media type or subtype. Configs are applied in a nested manner at runtime.
Instance Attribute Summary collapse
-
#dicom ⇒ Google::Apis::HealthcareV1beta1::DicomConfig
Specifies the parameters needed for de-identification of DICOM stores.
-
#dicom_tag_config ⇒ Google::Apis::HealthcareV1beta1::DicomTagConfig
Specifies the parameters needed for the de-identification of DICOM stores.
-
#fhir ⇒ Google::Apis::HealthcareV1beta1::FhirConfig
Specifies how to handle de-identification of a FHIR store.
-
#fhir_field_config ⇒ Google::Apis::HealthcareV1beta1::FhirFieldConfig
Specifies how to handle the de-identification of a FHIR store.
-
#image ⇒ Google::Apis::HealthcareV1beta1::ImageConfig
Specifies how to handle de-identification of image pixels.
-
#operation_metadata ⇒ Google::Apis::HealthcareV1beta1::DeidentifyOperationMetadata
Details about the work the de-identify operation performed.
-
#text ⇒ Google::Apis::HealthcareV1beta1::TextConfig
Configures how to transform sensitive text
InfoTypes. -
#use_regional_data_processing ⇒ Boolean
(also: #use_regional_data_processing?)
Ensures in-flight data remains in the region of origin during de- identification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeidentifyConfig
constructor
A new instance of DeidentifyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeidentifyConfig
Returns a new instance of DeidentifyConfig.
1768 1769 1770 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dicom ⇒ Google::Apis::HealthcareV1beta1::DicomConfig
Specifies the parameters needed for de-identification of DICOM stores.
Corresponds to the JSON property dicom
1725 1726 1727 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1725 def dicom @dicom end |
#dicom_tag_config ⇒ Google::Apis::HealthcareV1beta1::DicomTagConfig
Specifies the parameters needed for the de-identification of DICOM stores.
Corresponds to the JSON property dicomTagConfig
1730 1731 1732 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1730 def dicom_tag_config @dicom_tag_config end |
#fhir ⇒ Google::Apis::HealthcareV1beta1::FhirConfig
Specifies how to handle de-identification of a FHIR store.
Corresponds to the JSON property fhir
1735 1736 1737 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1735 def fhir @fhir end |
#fhir_field_config ⇒ Google::Apis::HealthcareV1beta1::FhirFieldConfig
Specifies how to handle the de-identification of a FHIR store.
Corresponds to the JSON property fhirFieldConfig
1740 1741 1742 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1740 def fhir_field_config @fhir_field_config end |
#image ⇒ Google::Apis::HealthcareV1beta1::ImageConfig
Specifies how to handle de-identification of image pixels.
Corresponds to the JSON property image
1745 1746 1747 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1745 def image @image end |
#operation_metadata ⇒ Google::Apis::HealthcareV1beta1::DeidentifyOperationMetadata
Details about the work the de-identify operation performed.
Corresponds to the JSON property operationMetadata
1750 1751 1752 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1750 def @operation_metadata end |
#text ⇒ Google::Apis::HealthcareV1beta1::TextConfig
Configures how to transform sensitive text InfoTypes.
Corresponds to the JSON property text
1755 1756 1757 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1755 def text @text end |
#use_regional_data_processing ⇒ Boolean Also known as: use_regional_data_processing?
Ensures in-flight data remains in the region of origin during de-
identification. The default value is false. Using this option results in a
significant reduction of throughput, and is not compatible with LOCATION or
ORGANIZATION_NAME infoTypes. If the deprecated DicomConfig or FhirConfig are
used, then LOCATION must be excluded within TextConfig, and must also be
excluded within ImageConfig if image redaction is required.
Corresponds to the JSON property useRegionalDataProcessing
1765 1766 1767 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1765 def use_regional_data_processing @use_regional_data_processing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 1773 def update!(**args) @dicom = args[:dicom] if args.key?(:dicom) @dicom_tag_config = args[:dicom_tag_config] if args.key?(:dicom_tag_config) @fhir = args[:fhir] if args.key?(:fhir) @fhir_field_config = args[:fhir_field_config] if args.key?(:fhir_field_config) @image = args[:image] if args.key?(:image) @operation_metadata = args[:operation_metadata] if args.key?(:operation_metadata) @text = args[:text] if args.key?(:text) @use_regional_data_processing = args[:use_regional_data_processing] if args.key?(:use_regional_data_processing) end |