Class: Google::Apis::HealthcareV1beta1::DicomStore
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::DicomStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Represents a DICOM store.
Instance Attribute Summary collapse
-
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize DICOM stores.
-
#name ⇒ String
Identifier.
-
#notification_config ⇒ Google::Apis::HealthcareV1beta1::NotificationConfig
Specifies where to send notifications upon changes to a data store.
-
#notification_configs ⇒ Array<Google::Apis::HealthcareV1beta1::DicomNotificationConfig>
Optional.
-
#stream_configs ⇒ Array<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomStreamConfig>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DicomStore
constructor
A new instance of DicomStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DicomStore
Returns a new instance of DicomStore.
2066 2067 2068 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize DICOM stores. Label keys must
be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128
bytes, and must conform to the following PCRE regular expression: \pLl\pLo
0,62 Label values are optional, must be between 1 and 63 characters long,
have a UTF-8 encoding of maximum 128 bytes, and must conform to the following
PCRE regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels
can be associated with a given store.
Corresponds to the JSON property labels
2036 2037 2038 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2036 def labels @labels end |
#name ⇒ String
Identifier. Resource name of the DICOM store, of the form projects/
project_id/locations/location_id/datasets/dataset_id/dicomStores/
dicom_store_id`.
Corresponds to the JSON propertyname`
2043 2044 2045 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2043 def name @name end |
#notification_config ⇒ Google::Apis::HealthcareV1beta1::NotificationConfig
Specifies where to send notifications upon changes to a data store.
Corresponds to the JSON property notificationConfig
2048 2049 2050 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2048 def notification_config @notification_config end |
#notification_configs ⇒ Array<Google::Apis::HealthcareV1beta1::DicomNotificationConfig>
Optional. Specifies where and whether to send notifications upon changes to a
DICOM store.
Corresponds to the JSON property notificationConfigs
2054 2055 2056 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2054 def notification_configs @notification_configs end |
#stream_configs ⇒ Array<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomStreamConfig>
Optional. A list of streaming configs used to configure the destination of
streaming exports for every DICOM instance insertion in this DICOM store.
After a new config is added to stream_configs, DICOM instance insertions are
streamed to the new destination. When a config is removed from stream_configs
, the server stops streaming to that destination. Each config must contain a
unique destination.
Corresponds to the JSON property streamConfigs
2064 2065 2066 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2064 def stream_configs @stream_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2071 2072 2073 2074 2075 2076 2077 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2071 def update!(**args) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @notification_config = args[:notification_config] if args.key?(:notification_config) @notification_configs = args[:notification_configs] if args.key?(:notification_configs) @stream_configs = args[:stream_configs] if args.key?(:stream_configs) end |