Class: Google::Apis::HealthcareV1beta1::DicomStoreMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

DicomStoreMetrics contains metrics describing a DICOM store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DicomStoreMetrics

Returns a new instance of DicomStoreMetrics.



2156
2157
2158
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_size_bytesFixnum

Total blob storage bytes for all instances in the store. Corresponds to the JSON property blobStorageSizeBytes

Returns:

  • (Fixnum)


2128
2129
2130
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2128

def blob_storage_size_bytes
  @blob_storage_size_bytes
end

#instance_countFixnum

Number of instances in the store. Corresponds to the JSON property instanceCount

Returns:

  • (Fixnum)


2133
2134
2135
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2133

def instance_count
  @instance_count
end

#nameString

Resource name of the DICOM store, of the form projects/project_id/locations/ location_id/datasets/dataset_id/dicomStores/dicom_store_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2139
2140
2141
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2139

def name
  @name
end

#series_countFixnum

Number of series in the store. Corresponds to the JSON property seriesCount

Returns:

  • (Fixnum)


2144
2145
2146
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2144

def series_count
  @series_count
end

#structured_storage_size_bytesFixnum

Total structured storage bytes for all instances in the store. Corresponds to the JSON property structuredStorageSizeBytes

Returns:

  • (Fixnum)


2149
2150
2151
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2149

def structured_storage_size_bytes
  @structured_storage_size_bytes
end

#study_countFixnum

Number of studies in the store. Corresponds to the JSON property studyCount

Returns:

  • (Fixnum)


2154
2155
2156
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2154

def study_count
  @study_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2161
2162
2163
2164
2165
2166
2167
2168
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2161

def update!(**args)
  @blob_storage_size_bytes = args[:blob_storage_size_bytes] if args.key?(:blob_storage_size_bytes)
  @instance_count = args[:instance_count] if args.key?(:instance_count)
  @name = args[:name] if args.key?(:name)
  @series_count = args[:series_count] if args.key?(:series_count)
  @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes)
  @study_count = args[:study_count] if args.key?(:study_count)
end