Class: Google::Apis::HealthcareV1beta1::DicomStoreMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

DicomStoreMetrics contains metrics describing a DICOM store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DicomStoreMetrics

Returns a new instance of DicomStoreMetrics.



2115
2116
2117
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_size_bytesFixnum

Total blob storage bytes for all instances in the store. Corresponds to the JSON property blobStorageSizeBytes

Returns:

  • (Fixnum)


2087
2088
2089
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2087

def blob_storage_size_bytes
  @blob_storage_size_bytes
end

#instance_countFixnum

Number of instances in the store. Corresponds to the JSON property instanceCount

Returns:

  • (Fixnum)


2092
2093
2094
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2092

def instance_count
  @instance_count
end

#nameString

Resource name of the DICOM store, of the form projects/project_id/locations/ location_id/datasets/dataset_id/dicomStores/dicom_store_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2098
2099
2100
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2098

def name
  @name
end

#series_countFixnum

Number of series in the store. Corresponds to the JSON property seriesCount

Returns:

  • (Fixnum)


2103
2104
2105
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2103

def series_count
  @series_count
end

#structured_storage_size_bytesFixnum

Total structured storage bytes for all instances in the store. Corresponds to the JSON property structuredStorageSizeBytes

Returns:

  • (Fixnum)


2108
2109
2110
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2108

def structured_storage_size_bytes
  @structured_storage_size_bytes
end

#study_countFixnum

Number of studies in the store. Corresponds to the JSON property studyCount

Returns:

  • (Fixnum)


2113
2114
2115
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2113

def study_count
  @study_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2120
2121
2122
2123
2124
2125
2126
2127
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2120

def update!(**args)
  @blob_storage_size_bytes = args[:blob_storage_size_bytes] if args.key?(:blob_storage_size_bytes)
  @instance_count = args[:instance_count] if args.key?(:instance_count)
  @name = args[:name] if args.key?(:name)
  @series_count = args[:series_count] if args.key?(:series_count)
  @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes)
  @study_count = args[:study_count] if args.key?(:study_count)
end