Class: Google::Apis::HealthcareV1beta1::DicomTagConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::DicomTagConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies the parameters needed for the de-identification of DICOM stores.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::HealthcareV1beta1::Action>
Specifies custom tag selections and
Actionsto apply to them. -
#options ⇒ Google::Apis::HealthcareV1beta1::Options
Specifies additional options to apply to the base profile.
-
#profile_type ⇒ String
Base profile type for handling DICOM tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DicomTagConfig
constructor
A new instance of DicomTagConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DicomTagConfig
Returns a new instance of DicomTagConfig.
2226 2227 2228 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::HealthcareV1beta1::Action>
Specifies custom tag selections and Actions to apply to them. Overrides
options and profile. Conflicting Actions are applied in the order given.
Corresponds to the JSON property actions
2214 2215 2216 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2214 def actions @actions end |
#options ⇒ Google::Apis::HealthcareV1beta1::Options
Specifies additional options to apply to the base profile.
Corresponds to the JSON property options
2219 2220 2221 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2219 def @options end |
#profile_type ⇒ String
Base profile type for handling DICOM tags.
Corresponds to the JSON property profileType
2224 2225 2226 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2224 def profile_type @profile_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2231 2232 2233 2234 2235 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2231 def update!(**args) @actions = args[:actions] if args.key?(:actions) @options = args[:options] if args.key?(:options) @profile_type = args[:profile_type] if args.key?(:profile_type) end |