Class: Google::Apis::HealthcareV1beta1::DicomTagConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::DicomTagConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies the parameters needed for the de-identification of DICOM stores.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::HealthcareV1beta1::Action>
Specifies custom tag selections and
Actionsto apply to them. -
#options ⇒ Google::Apis::HealthcareV1beta1::Options
Specifies additional options to apply to the base profile.
-
#profile_type ⇒ String
Base profile type for handling DICOM tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DicomTagConfig
constructor
A new instance of DicomTagConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DicomTagConfig
Returns a new instance of DicomTagConfig.
2191 2192 2193 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::HealthcareV1beta1::Action>
Specifies custom tag selections and Actions to apply to them. Overrides
options and profile. Conflicting Actions are applied in the order given.
Corresponds to the JSON property actions
2179 2180 2181 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2179 def actions @actions end |
#options ⇒ Google::Apis::HealthcareV1beta1::Options
Specifies additional options to apply to the base profile.
Corresponds to the JSON property options
2184 2185 2186 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2184 def @options end |
#profile_type ⇒ String
Base profile type for handling DICOM tags.
Corresponds to the JSON property profileType
2189 2190 2191 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2189 def profile_type @profile_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2196 2197 2198 2199 2200 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2196 def update!(**args) @actions = args[:actions] if args.key?(:actions) @options = args[:options] if args.key?(:options) @profile_type = args[:profile_type] if args.key?(:profile_type) end |