Class: Google::Apis::HealthcareV1beta1::DicomTagConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::DicomTagConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies the parameters needed for the de-identification of DICOM stores.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::HealthcareV1beta1::Action>
Specifies custom tag selections and
Actionsto apply to them. -
#options ⇒ Google::Apis::HealthcareV1beta1::Options
Specifies additional options to apply to the base profile.
-
#profile_type ⇒ String
Base profile type for handling DICOM tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DicomTagConfig
constructor
A new instance of DicomTagConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DicomTagConfig
Returns a new instance of DicomTagConfig.
2150 2151 2152 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::HealthcareV1beta1::Action>
Specifies custom tag selections and Actions to apply to them. Overrides
options and profile. Conflicting Actions are applied in the order given.
Corresponds to the JSON property actions
2138 2139 2140 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2138 def actions @actions end |
#options ⇒ Google::Apis::HealthcareV1beta1::Options
Specifies additional options to apply to the base profile.
Corresponds to the JSON property options
2143 2144 2145 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2143 def @options end |
#profile_type ⇒ String
Base profile type for handling DICOM tags.
Corresponds to the JSON property profileType
2148 2149 2150 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2148 def profile_type @profile_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2155 2156 2157 2158 2159 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2155 def update!(**args) @actions = args[:actions] if args.key?(:actions) @options = args[:options] if args.key?(:options) @profile_type = args[:profile_type] if args.key?(:profile_type) end |