Class: Google::Apis::HealthcareV1beta1::EntityMention
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::EntityMention
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
An entity mention in the document.
Instance Attribute Summary collapse
-
#additional_info ⇒ Array<Google::Apis::HealthcareV1beta1::Feature>
Additional information about the entity mention.
-
#certainty_assessment ⇒ Google::Apis::HealthcareV1beta1::Feature
A feature of an entity mention.
-
#confidence ⇒ Float
The model's confidence in this entity mention annotation.
-
#linked_entities ⇒ Array<Google::Apis::HealthcareV1beta1::LinkedEntity>
linked_entities are candidate ontological concepts that this entity mention may refer to.
-
#mention_id ⇒ String
mention_id uniquely identifies each entity mention in a single response.
-
#subject ⇒ Google::Apis::HealthcareV1beta1::Feature
A feature of an entity mention.
-
#temporal_assessment ⇒ Google::Apis::HealthcareV1beta1::Feature
A feature of an entity mention.
-
#text ⇒ Google::Apis::HealthcareV1beta1::TextSpan
A span of text in the provided document.
-
#type ⇒ String
The semantic type of the entity: UNKNOWN_ENTITY_TYPE, ALONE, ANATOMICAL_STRUCTURE, ASSISTED_LIVING, BF_RESULT, BM_RESULT, BM_UNIT, BM_VALUE, BODY_FUNCTION, BODY_MEASUREMENT, COMPLIANT, DOESNOT_FOLLOWUP, FAMILY, FOLLOWSUP, LABORATORY_DATA, LAB_RESULT, LAB_UNIT, LAB_VALUE, MEDICAL_DEVICE, MEDICINE, MED_DOSE, MED_DURATION, MED_FORM, MED_FREQUENCY, MED_ROUTE, MED_STATUS, MED_STRENGTH, MED_TOTALDOSE, MED_UNIT, NON_COMPLIANT, OTHER_LIVINGSTATUS, PROBLEM, PROCEDURE, PROCEDURE_RESULT, PROC_METHOD, REASON_FOR_NONCOMPLIANCE, SEVERITY, SUBSTANCE_ABUSE, UNCLEAR_FOLLOWUP.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EntityMention
constructor
A new instance of EntityMention.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EntityMention
Returns a new instance of EntityMention.
2302 2303 2304 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_info ⇒ Array<Google::Apis::HealthcareV1beta1::Feature>
Additional information about the entity mention. For example, for an entity
mention of type DATE this can be its more specific date types from the
following list: ADMISSION_DATE, CONSULTATION_DATE, DISCHARGE_DATE,
SERVICE_DATE, VISIT_DATE, DIAGNOSIS_DATE, MED_STARTED_DATE,
MED_ENDED_DATE, NOTE_DATE, PROCEDURE_DATE, RADIATION_STARTED_DATE,
RADIATION_ENDED_DATE, STAGE_DATE
Corresponds to the JSON property additionalInfo
2251 2252 2253 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2251 def additional_info @additional_info end |
#certainty_assessment ⇒ Google::Apis::HealthcareV1beta1::Feature
A feature of an entity mention.
Corresponds to the JSON property certaintyAssessment
2256 2257 2258 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2256 def certainty_assessment @certainty_assessment end |
#confidence ⇒ Float
The model's confidence in this entity mention annotation. A number between 0
and 1.
Corresponds to the JSON property confidence
2262 2263 2264 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2262 def confidence @confidence end |
#linked_entities ⇒ Array<Google::Apis::HealthcareV1beta1::LinkedEntity>
linked_entities are candidate ontological concepts that this entity mention
may refer to. They are sorted by decreasing confidence.
Corresponds to the JSON property linkedEntities
2268 2269 2270 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2268 def linked_entities @linked_entities end |
#mention_id ⇒ String
mention_id uniquely identifies each entity mention in a single response.
Corresponds to the JSON property mentionId
2273 2274 2275 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2273 def mention_id @mention_id end |
#subject ⇒ Google::Apis::HealthcareV1beta1::Feature
A feature of an entity mention.
Corresponds to the JSON property subject
2278 2279 2280 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2278 def subject @subject end |
#temporal_assessment ⇒ Google::Apis::HealthcareV1beta1::Feature
A feature of an entity mention.
Corresponds to the JSON property temporalAssessment
2283 2284 2285 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2283 def temporal_assessment @temporal_assessment end |
#text ⇒ Google::Apis::HealthcareV1beta1::TextSpan
A span of text in the provided document.
Corresponds to the JSON property text
2288 2289 2290 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2288 def text @text end |
#type ⇒ String
The semantic type of the entity: UNKNOWN_ENTITY_TYPE, ALONE,
ANATOMICAL_STRUCTURE, ASSISTED_LIVING, BF_RESULT, BM_RESULT, BM_UNIT, BM_VALUE,
BODY_FUNCTION, BODY_MEASUREMENT, COMPLIANT, DOESNOT_FOLLOWUP, FAMILY,
FOLLOWSUP, LABORATORY_DATA, LAB_RESULT, LAB_UNIT, LAB_VALUE, MEDICAL_DEVICE,
MEDICINE, MED_DOSE, MED_DURATION, MED_FORM, MED_FREQUENCY, MED_ROUTE,
MED_STATUS, MED_STRENGTH, MED_TOTALDOSE, MED_UNIT, NON_COMPLIANT,
OTHER_LIVINGSTATUS, PROBLEM, PROCEDURE, PROCEDURE_RESULT, PROC_METHOD,
REASON_FOR_NONCOMPLIANCE, SEVERITY, SUBSTANCE_ABUSE, UNCLEAR_FOLLOWUP.
Corresponds to the JSON property type
2300 2301 2302 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2300 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2307 def update!(**args) @additional_info = args[:additional_info] if args.key?(:additional_info) @certainty_assessment = args[:certainty_assessment] if args.key?(:certainty_assessment) @confidence = args[:confidence] if args.key?(:confidence) @linked_entities = args[:linked_entities] if args.key?(:linked_entities) @mention_id = args[:mention_id] if args.key?(:mention_id) @subject = args[:subject] if args.key?(:subject) @temporal_assessment = args[:temporal_assessment] if args.key?(:temporal_assessment) @text = args[:text] if args.key?(:text) @type = args[:type] if args.key?(:type) end |