Class: Google::Apis::HealthcareV1beta1::EvaluateUserConsentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Evaluate a user's Consents for all matching User data mappings. Note: User data mappings are indexed asynchronously, causing slight delays between the time mappings are created or updated and when they are included in EvaluateUserConsents results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvaluateUserConsentsRequest

Returns a new instance of EvaluateUserConsentsRequest.



2473
2474
2475
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

List of resource names of Consent resources. Corresponds to the JSON property consentList



2437
2438
2439
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2437

def consent_list
  @consent_list
end

#page_sizeFixnum

Optional. Limit on the number of User data mappings to return in a single response. If not specified, 100 is used. May not be larger than 1000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


2443
2444
2445
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2443

def page_size
  @page_size
end

#page_tokenString

Optional. Token to retrieve the next page of results, or empty to get the first page. Corresponds to the JSON property pageToken

Returns:

  • (String)


2449
2450
2451
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2449

def page_token
  @page_token
end

#request_attributesHash<String,String>

Required. The values of request attributes associated with this access request. Corresponds to the JSON property requestAttributes

Returns:

  • (Hash<String,String>)


2454
2455
2456
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2454

def request_attributes
  @request_attributes
end

#resource_attributesHash<String,String>

Optional. The values of resource attributes associated with the resources being requested. If no values are specified, then all resources are queried. Corresponds to the JSON property resourceAttributes

Returns:

  • (Hash<String,String>)


2460
2461
2462
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2460

def resource_attributes
  @resource_attributes
end

#response_viewString

Optional. The view for EvaluateUserConsentsResponse. If unspecified, defaults to BASIC and returns consented as TRUE or FALSE. Corresponds to the JSON property responseView

Returns:

  • (String)


2466
2467
2468
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2466

def response_view
  @response_view
end

#user_idString

Required. User ID to evaluate consents for. Corresponds to the JSON property userId

Returns:

  • (String)


2471
2472
2473
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2471

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2478
2479
2480
2481
2482
2483
2484
2485
2486
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2478

def update!(**args)
  @consent_list = args[:consent_list] if args.key?(:consent_list)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @request_attributes = args[:request_attributes] if args.key?(:request_attributes)
  @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes)
  @response_view = args[:response_view] if args.key?(:response_view)
  @user_id = args[:user_id] if args.key?(:user_id)
end