Class: Google::Apis::HealthcareV1beta1::EvaluateUserConsentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::EvaluateUserConsentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#results ⇒ Array<Google::Apis::HealthcareV1beta1::Result>
The consent evaluation result for each
data_id.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EvaluateUserConsentsResponse
constructor
A new instance of EvaluateUserConsentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EvaluateUserConsentsResponse
Returns a new instance of EvaluateUserConsentsResponse.
2428 2429 2430 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list. This token is valid for 72 hours after it is created.
Corresponds to the JSON property nextPageToken
2421 2422 2423 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2421 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::HealthcareV1beta1::Result>
The consent evaluation result for each data_id.
Corresponds to the JSON property results
2426 2427 2428 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2426 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2433 2434 2435 2436 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2433 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) end |