Class: Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The enforcing consent's metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainDataAccessConsentInfo

Returns a new instance of ExplainDataAccessConsentInfo.



2487
2488
2489
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cascade_originsArray<String>

The compartment base resources that matched a cascading policy. Each resource has the following format: projects/project_id/locations/location_id/ datasets/dataset_id/fhirStores/fhir_store_id/fhir/resource_type/ resource_id` Corresponds to the JSON propertycascadeOrigins`

Returns:

  • (Array<String>)


2449
2450
2451
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2449

def cascade_origins
  @cascade_origins
end

The resource name of this consent resource, in the format: projects/ project_id/locations/location/datasets/dataset_id/fhirStores/ fhir_store_id/fhir/Consent/resource_id`. Corresponds to the JSON propertyconsentResource`

Returns:

  • (String)


2456
2457
2458
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2456

def consent_resource
  @consent_resource
end

#enforcement_timeString

Last enforcement timestamp of this consent resource. Corresponds to the JSON property enforcementTime

Returns:

  • (String)


2461
2462
2463
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2461

def enforcement_time
  @enforcement_time
end

#matching_accessor_scopesArray<Google::Apis::HealthcareV1beta1::ConsentAccessorScope>

A list of all the matching accessor scopes of this consent policy that enforced ExplainDataAccessConsentScope.accessor_scope. Corresponds to the JSON property matchingAccessorScopes



2467
2468
2469
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2467

def matching_accessor_scopes
  @matching_accessor_scopes
end

The patient owning the consent (only applicable for patient consents), in the format: projects/project_id/locations/location_id/datasets/dataset_id/ fhirStores/fhir_store_id/fhir/Patient/patient_id` Corresponds to the JSON propertypatientConsentOwner`

Returns:

  • (String)


2474
2475
2476
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2474

def patient_consent_owner
  @patient_consent_owner
end

#typeString

The policy type of consent resource (e.g. PATIENT, ADMIN). Corresponds to the JSON property type

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2479

def type
  @type
end

#variantsArray<String>

The consent's variant combinations. A single consent may have multiple variants. Corresponds to the JSON property variants

Returns:

  • (Array<String>)


2485
2486
2487
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2485

def variants
  @variants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2492
2493
2494
2495
2496
2497
2498
2499
2500
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2492

def update!(**args)
  @cascade_origins = args[:cascade_origins] if args.key?(:cascade_origins)
  @consent_resource = args[:consent_resource] if args.key?(:consent_resource)
  @enforcement_time = args[:enforcement_time] if args.key?(:enforcement_time)
  @matching_accessor_scopes = args[:matching_accessor_scopes] if args.key?(:matching_accessor_scopes)
  @patient_consent_owner = args[:patient_consent_owner] if args.key?(:patient_consent_owner)
  @type = args[:type] if args.key?(:type)
  @variants = args[:variants] if args.key?(:variants)
end