Class: Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

A single consent scope that provides info on who has access to the requested resource scope for a particular purpose and environment, enforced by which consent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainDataAccessConsentScope

Returns a new instance of ExplainDataAccessConsentScope.



2572
2573
2574
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessor_scopeGoogle::Apis::HealthcareV1beta1::ConsentAccessorScope

The accessor scope that describes who can access, for what purpose, in which environment. Corresponds to the JSON property accessorScope



2554
2555
2556
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2554

def accessor_scope
  @accessor_scope
end

#decisionString

Whether the current consent scope is permitted or denied access on the requested resource. Corresponds to the JSON property decision

Returns:

  • (String)


2560
2561
2562
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2560

def decision
  @decision
end

#enforcing_consentsArray<Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentInfo>

Metadata of the consent resources that enforce the consent scope's access. Corresponds to the JSON property enforcingConsents



2565
2566
2567
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2565

def enforcing_consents
  @enforcing_consents
end

#exceptionsArray<Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentScope>

Other consent scopes that created exceptions within this scope. Corresponds to the JSON property exceptions



2570
2571
2572
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2570

def exceptions
  @exceptions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2577
2578
2579
2580
2581
2582
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2577

def update!(**args)
  @accessor_scope = args[:accessor_scope] if args.key?(:accessor_scope)
  @decision = args[:decision] if args.key?(:decision)
  @enforcing_consents = args[:enforcing_consents] if args.key?(:enforcing_consents)
  @exceptions = args[:exceptions] if args.key?(:exceptions)
end