Class: Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

A single consent scope that provides info on who has access to the requested resource scope for a particular purpose and environment, enforced by which consent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainDataAccessConsentScope

Returns a new instance of ExplainDataAccessConsentScope.



2531
2532
2533
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessor_scopeGoogle::Apis::HealthcareV1beta1::ConsentAccessorScope

The accessor scope that describes who can access, for what purpose, in which environment. Corresponds to the JSON property accessorScope



2513
2514
2515
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2513

def accessor_scope
  @accessor_scope
end

#decisionString

Whether the current consent scope is permitted or denied access on the requested resource. Corresponds to the JSON property decision

Returns:

  • (String)


2519
2520
2521
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2519

def decision
  @decision
end

#enforcing_consentsArray<Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentInfo>

Metadata of the consent resources that enforce the consent scope's access. Corresponds to the JSON property enforcingConsents



2524
2525
2526
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2524

def enforcing_consents
  @enforcing_consents
end

#exceptionsArray<Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentScope>

Other consent scopes that created exceptions within this scope. Corresponds to the JSON property exceptions



2529
2530
2531
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2529

def exceptions
  @exceptions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2536
2537
2538
2539
2540
2541
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2536

def update!(**args)
  @accessor_scope = args[:accessor_scope] if args.key?(:accessor_scope)
  @decision = args[:decision] if args.key?(:decision)
  @enforcing_consents = args[:enforcing_consents] if args.key?(:enforcing_consents)
  @exceptions = args[:exceptions] if args.key?(:exceptions)
end