Class: Google::Apis::HealthcareV1beta1::ExplainDataAccessResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

List of consent scopes that are applicable to the explained access on a given resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainDataAccessResponse

Returns a new instance of ExplainDataAccessResponse.



2637
2638
2639
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

List of applicable consent scopes. Sorted in order of actor such that scopes belonging to the same actor will be adjacent to each other in the list. Corresponds to the JSON property consentScopes



2629
2630
2631
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2629

def consent_scopes
  @consent_scopes
end

#warningString

Warnings associated with this response. It inform user with exceeded scope limit errors. Corresponds to the JSON property warning

Returns:

  • (String)


2635
2636
2637
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2635

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2642
2643
2644
2645
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2642

def update!(**args)
  @consent_scopes = args[:consent_scopes] if args.key?(:consent_scopes)
  @warning = args[:warning] if args.key?(:warning)
end