Class: Google::Apis::HealthcareV1beta1::ExplainDataAccessResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ExplainDataAccessResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
List of consent scopes that are applicable to the explained access on a given resource.
Instance Attribute Summary collapse
-
#consent_scopes ⇒ Array<Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentScope>
List of applicable consent scopes.
-
#warning ⇒ String
Warnings associated with this response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExplainDataAccessResponse
constructor
A new instance of ExplainDataAccessResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExplainDataAccessResponse
Returns a new instance of ExplainDataAccessResponse.
2561 2562 2563 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2561 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent_scopes ⇒ Array<Google::Apis::HealthcareV1beta1::ExplainDataAccessConsentScope>
List of applicable consent scopes. Sorted in order of actor such that scopes
belonging to the same actor will be adjacent to each other in the list.
Corresponds to the JSON property consentScopes
2553 2554 2555 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2553 def @consent_scopes end |
#warning ⇒ String
Warnings associated with this response. It inform user with exceeded scope
limit errors.
Corresponds to the JSON property warning
2559 2560 2561 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2559 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2566 2567 2568 2569 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2566 def update!(**args) @consent_scopes = args[:consent_scopes] if args.key?(:consent_scopes) @warning = args[:warning] if args.key?(:warning) end |