Class: Google::Apis::HealthcareV1beta1::ExportDicomDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ExportDicomDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Exports data from the specified DICOM store. If a given resource, such as a DICOM object with the same SOPInstance UID, already exists in the output, it is overwritten with the version in the source dataset. Exported DICOM data persists when the DICOM store from which it was exported is deleted.
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomBigQueryDestination
The BigQuery table where the server writes output.
-
#filter_config ⇒ Google::Apis::HealthcareV1beta1::DicomFilterConfig
Specifies the filter configuration for DICOM resources.
-
#gcs_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomGcsDestination
The Cloud Storage location where the server writes the output and the export configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportDicomDataRequest
constructor
A new instance of ExportDicomDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportDicomDataRequest
Returns a new instance of ExportDicomDataRequest.
2671 2672 2673 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomBigQueryDestination
The BigQuery table where the server writes output.
Corresponds to the JSON property bigqueryDestination
2658 2659 2660 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2658 def bigquery_destination @bigquery_destination end |
#filter_config ⇒ Google::Apis::HealthcareV1beta1::DicomFilterConfig
Specifies the filter configuration for DICOM resources.
Corresponds to the JSON property filterConfig
2663 2664 2665 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2663 def filter_config @filter_config end |
#gcs_destination ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomGcsDestination
The Cloud Storage location where the server writes the output and the export
configuration.
Corresponds to the JSON property gcsDestination
2669 2670 2671 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2669 def gcs_destination @gcs_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2676 2677 2678 2679 2680 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2676 def update!(**args) @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination) @filter_config = args[:filter_config] if args.key?(:filter_config) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) end |