Class: Google::Apis::HealthcareV1beta1::ExportDicomDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Exports data from the specified DICOM store. If a given resource, such as a DICOM object with the same SOPInstance UID, already exists in the output, it is overwritten with the version in the source dataset. Exported DICOM data persists when the DICOM store from which it was exported is deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportDicomDataRequest

Returns a new instance of ExportDicomDataRequest.



2595
2596
2597
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomBigQueryDestination

The BigQuery table where the server writes output. Corresponds to the JSON property bigqueryDestination



2582
2583
2584
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2582

def bigquery_destination
  @bigquery_destination
end

#filter_configGoogle::Apis::HealthcareV1beta1::DicomFilterConfig

Specifies the filter configuration for DICOM resources. Corresponds to the JSON property filterConfig



2587
2588
2589
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2587

def filter_config
  @filter_config
end

#gcs_destinationGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomGcsDestination

The Cloud Storage location where the server writes the output and the export configuration. Corresponds to the JSON property gcsDestination



2593
2594
2595
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2593

def gcs_destination
  @gcs_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2600
2601
2602
2603
2604
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2600

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @filter_config = args[:filter_config] if args.key?(:filter_config)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
end