Class: Google::Apis::HealthcareV1beta1::ExportResourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Request to export resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportResourcesRequest

Returns a new instance of ExportResourcesRequest.



2798
2799
2800
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#_sinceString

If provided, only resources updated after this time are exported. The time uses the format YYYY-MM-DDThh:mm:ss.sss+zz:zz. For example, 2015-02-07T13:28: 17.239+02:00 or 2017-01-01T00:00:00Z. The time must be specified to the second and include a time zone. Corresponds to the JSON property _since

Returns:

  • (String)


2780
2781
2782
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2780

def _since
  @_since
end

#_typeString

String of comma-delimited FHIR resource types. If provided, only resources of the specified resource type(s) are exported. Corresponds to the JSON property _type

Returns:

  • (String)


2786
2787
2788
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2786

def _type
  @_type
end

#bigquery_destinationGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirBigQueryDestination

The configuration for exporting to BigQuery. Corresponds to the JSON property bigqueryDestination



2791
2792
2793
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2791

def bigquery_destination
  @bigquery_destination
end

#gcs_destinationGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsDestination

The configuration for exporting to Cloud Storage. Corresponds to the JSON property gcsDestination



2796
2797
2798
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2796

def gcs_destination
  @gcs_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2803
2804
2805
2806
2807
2808
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2803

def update!(**args)
  @_since = args[:_since] if args.key?(:_since)
  @_type = args[:_type] if args.key?(:_type)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
end