Class: Google::Apis::HealthcareV1beta1::FhirFieldConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::FhirFieldConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies how to handle the de-identification of a FHIR store.
Instance Attribute Summary collapse
-
#field_metadata_list ⇒ Array<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata>
Specifies FHIR paths to match and how to transform them.
-
#options ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyOptions
Specifies additional options to apply to the base ProfileType.
-
#profile_type ⇒ String
Base profile type for handling FHIR fields.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FhirFieldConfig
constructor
A new instance of FhirFieldConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FhirFieldConfig
Returns a new instance of FhirFieldConfig.
2989 2990 2991 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_metadata_list ⇒ Array<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata>
Specifies FHIR paths to match and how to transform them. Any field that is not
matched by a FieldMetadata action is passed through to the output dataset
unmodified. All extensions will be processed according to keep_extensions. If
a field can be matched by more than one FieldMetadata action, the first
action option is applied. Overrides options and the union field profile in
FhirFieldConfig.
Corresponds to the JSON property fieldMetadataList
2977 2978 2979 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2977 def @field_metadata_list end |
#options ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyOptions
Specifies additional options to apply to the base ProfileType.
Corresponds to the JSON property options
2982 2983 2984 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2982 def @options end |
#profile_type ⇒ String
Base profile type for handling FHIR fields.
Corresponds to the JSON property profileType
2987 2988 2989 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2987 def profile_type @profile_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2994 2995 2996 2997 2998 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2994 def update!(**args) @field_metadata_list = args[:field_metadata_list] if args.key?(:field_metadata_list) @options = args[:options] if args.key?(:options) @profile_type = args[:profile_type] if args.key?(:profile_type) end |