Class: Google::Apis::HealthcareV1beta1::FhirFieldConfig
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::FhirFieldConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies how to handle the de-identification of a FHIR store.
Instance Attribute Summary collapse
-
#field_metadata_list ⇒ Array<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata>
Specifies FHIR paths to match and how to transform them.
-
#options ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyOptions
Specifies additional options to apply to the base ProfileType.
-
#profile_type ⇒ String
Base profile type for handling FHIR fields.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FhirFieldConfig
constructor
A new instance of FhirFieldConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FhirFieldConfig
Returns a new instance of FhirFieldConfig.
2948 2949 2950 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_metadata_list ⇒ Array<Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata>
Specifies FHIR paths to match and how to transform them. Any field that is not
matched by a FieldMetadata action is passed through to the output dataset
unmodified. All extensions will be processed according to keep_extensions. If
a field can be matched by more than one FieldMetadata action, the first
action option is applied. Overrides options and the union field profile in
FhirFieldConfig.
Corresponds to the JSON property fieldMetadataList
2936 2937 2938 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2936 def @field_metadata_list end |
#options ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyOptions
Specifies additional options to apply to the base ProfileType.
Corresponds to the JSON property options
2941 2942 2943 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2941 def @options end |
#profile_type ⇒ String
Base profile type for handling FHIR fields.
Corresponds to the JSON property profileType
2946 2947 2948 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2946 def profile_type @profile_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2953 2954 2955 2956 2957 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 2953 def update!(**args) @field_metadata_list = args[:field_metadata_list] if args.key?(:field_metadata_list) @options = args[:options] if args.key?(:options) @profile_type = args[:profile_type] if args.key?(:profile_type) end |