Class: Google::Apis::HealthcareV1beta1::FhirStore
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::FhirStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Represents a FHIR store.
Instance Attribute Summary collapse
-
#bulk_export_gcs_destination ⇒ Google::Apis::HealthcareV1beta1::BulkExportGcsDestination
The configuration for exporting to Cloud Storage using the bulk export API.
-
#complex_data_type_reference_parsing ⇒ String
Enable parsing of references within complex FHIR data types such as Extensions.
-
#consent_config ⇒ Google::Apis::HealthcareV1beta1::ConsentConfig
Configures whether to enforce consent for the FHIR store and which consent enforcement version is being used.
-
#default_search_handling_strict ⇒ Boolean
(also: #default_search_handling_strict?)
If true, overrides the default search behavior for this FHIR store to
handling=strictwhich returns an error for unrecognized search parameters. -
#disable_referential_integrity ⇒ Boolean
(also: #disable_referential_integrity?)
Immutable.
-
#disable_resource_versioning ⇒ Boolean
(also: #disable_resource_versioning?)
Immutable.
-
#enable_history_modifications ⇒ Boolean
(also: #enable_history_modifications?)
Optional.
-
#enable_update_create ⇒ Boolean
(also: #enable_update_create?)
Whether this FHIR store has the updateCreate capability.
-
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize FHIR stores.
-
#name ⇒ String
Output only.
-
#notification_config ⇒ Google::Apis::HealthcareV1beta1::NotificationConfig
Specifies where to send notifications upon changes to a data store.
-
#notification_configs ⇒ Array<Google::Apis::HealthcareV1beta1::FhirNotificationConfig>
Specifies where and whether to send notifications upon changes to a Fhir store.
-
#search_config ⇒ Google::Apis::HealthcareV1beta1::SearchConfig
Contains the configuration for FHIR search.
-
#stream_configs ⇒ Array<Google::Apis::HealthcareV1beta1::StreamConfig>
A list of streaming configs that configure the destinations of streaming export for every resource mutation in this FHIR store.
-
#validation_config ⇒ Google::Apis::HealthcareV1beta1::ValidationConfig
Contains the configuration for FHIR profiles and validation.
-
#version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FhirStore
constructor
A new instance of FhirStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FhirStore
Returns a new instance of FhirStore.
3255 3256 3257 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bulk_export_gcs_destination ⇒ Google::Apis::HealthcareV1beta1::BulkExportGcsDestination
The configuration for exporting to Cloud Storage using the bulk export API.
Corresponds to the JSON property bulkExportGcsDestination
3114 3115 3116 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3114 def bulk_export_gcs_destination @bulk_export_gcs_destination end |
#complex_data_type_reference_parsing ⇒ String
Enable parsing of references within complex FHIR data types such as Extensions.
If this value is set to ENABLED, then features like referential integrity and
Bundle reference rewriting apply to all references. If this flag has not been
specified the behavior of the FHIR store will not change, references in
complex data types will not be parsed. New stores will have this value set to
ENABLED after a notification period. Warning: turning on this flag causes
processing existing resources to fail if they contain references to non-
existent resources. Cannot be disabled in R5.
Corresponds to the JSON property complexDataTypeReferenceParsing
3126 3127 3128 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3126 def complex_data_type_reference_parsing @complex_data_type_reference_parsing end |
#consent_config ⇒ Google::Apis::HealthcareV1beta1::ConsentConfig
Configures whether to enforce consent for the FHIR store and which consent
enforcement version is being used.
Corresponds to the JSON property consentConfig
3132 3133 3134 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3132 def @consent_config end |
#default_search_handling_strict ⇒ Boolean Also known as: default_search_handling_strict?
If true, overrides the default search behavior for this FHIR store to
handling=strict which returns an error for unrecognized search parameters. If
false, uses the FHIR specification default handling=lenient which ignores
unrecognized search parameters. The handling can always be changed from the
default on an individual API call by setting the HTTP header Prefer: handling=
strict or Prefer: handling=lenient. Defaults to false.
Corresponds to the JSON property defaultSearchHandlingStrict
3142 3143 3144 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3142 def default_search_handling_strict @default_search_handling_strict end |
#disable_referential_integrity ⇒ Boolean Also known as: disable_referential_integrity?
Immutable. Whether to disable referential integrity in this FHIR store. This
field is immutable after FHIR store creation. The default value is false,
meaning that the API enforces referential integrity and fails the requests
that result in inconsistent state in the FHIR store. When this field is set to
true, the API skips referential integrity checks. Consequently, operations
that rely on references, such as GetPatientEverything, do not return all the
results if broken references exist.
Corresponds to the JSON property disableReferentialIntegrity
3154 3155 3156 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3154 def disable_referential_integrity @disable_referential_integrity end |
#disable_resource_versioning ⇒ Boolean Also known as: disable_resource_versioning?
Immutable. Whether to disable resource versioning for this FHIR store. This
field can not be changed after the creation of FHIR store. If set to false,
all write operations cause historical versions to be recorded automatically.
The historical versions can be fetched through the history APIs, but cannot be
updated. If set to true, no historical versions are kept. The server sends
errors for attempts to read the historical versions. Defaults to false.
Corresponds to the JSON property disableResourceVersioning
3165 3166 3167 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3165 def disable_resource_versioning @disable_resource_versioning end |
#enable_history_modifications ⇒ Boolean Also known as: enable_history_modifications?
Optional. Whether to allow the [ImportResourcesHistory] and [ExecuteBundle]
APIs to accept history bundles, and directly insert and overwrite historical
resource versions into the FHIR store. Changing resource histories creates
resource interactions that have occurred in the past which clients might not
allow. If set to false, [ImportResourcesHistory] and [ExecuteBundle] requests
will return errors.
Corresponds to the JSON property enableHistoryModifications
3176 3177 3178 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3176 def enable_history_modifications @enable_history_modifications end |
#enable_update_create ⇒ Boolean Also known as: enable_update_create?
Whether this FHIR store has the updateCreate capability. This determines if the client can use an Update operation to
create a new resource with a client-specified ID. If false, all IDs are server-
assigned through the Create operation and attempts to update a non-existent
resource return errors. It is strongly advised not to include or encode any
sensitive data such as patient identifiers in client-specified resource IDs.
Those IDs are part of the FHIR resource path recorded in Cloud audit logs and
Pub/Sub notifications. Those IDs can also be contained in reference fields
within other resources. Defaults to false.
Corresponds to the JSON property enableUpdateCreate
3191 3192 3193 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3191 def enable_update_create @enable_update_create end |
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize FHIR stores. Label keys must be
between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes,
and must conform to the following PCRE regular expression: \pLl\pLo0,62
Label values are optional, must be between 1 and 63 characters long, have a
UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE
regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be
associated with a given store.
Corresponds to the JSON property labels
3203 3204 3205 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3203 def labels @labels end |
#name ⇒ String
Output only. Identifier. Resource name of the FHIR store, of the form
projects/project_id/locations/location/datasets/dataset_id/fhirStores/
fhir_store_id`.
Corresponds to the JSON propertyname`
3210 3211 3212 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3210 def name @name end |
#notification_config ⇒ Google::Apis::HealthcareV1beta1::NotificationConfig
Specifies where to send notifications upon changes to a data store.
Corresponds to the JSON property notificationConfig
3215 3216 3217 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3215 def notification_config @notification_config end |
#notification_configs ⇒ Array<Google::Apis::HealthcareV1beta1::FhirNotificationConfig>
Specifies where and whether to send notifications upon changes to a Fhir store.
Corresponds to the JSON property notificationConfigs
3220 3221 3222 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3220 def notification_configs @notification_configs end |
#search_config ⇒ Google::Apis::HealthcareV1beta1::SearchConfig
Contains the configuration for FHIR search.
Corresponds to the JSON property searchConfig
3225 3226 3227 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3225 def search_config @search_config end |
#stream_configs ⇒ Array<Google::Apis::HealthcareV1beta1::StreamConfig>
A list of streaming configs that configure the destinations of streaming
export for every resource mutation in this FHIR store. Each store is allowed
to have up to 10 streaming configs. After a new config is added, the next
resource mutation is streamed to the new location in addition to the existing
ones. When a location is removed from the list, the server stops streaming to
that location. Before adding a new config, you must add the required
bigquery.dataEditor role to your project's Cloud Healthcare Service Agent
service account. Some
lag (typically on the order of dozens of seconds) is expected before the
results show up in the streaming destination.
Corresponds to the JSON property streamConfigs
3240 3241 3242 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3240 def stream_configs @stream_configs end |
#validation_config ⇒ Google::Apis::HealthcareV1beta1::ValidationConfig
Contains the configuration for FHIR profiles and validation.
Corresponds to the JSON property validationConfig
3245 3246 3247 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3245 def validation_config @validation_config end |
#version ⇒ String
Required. Immutable. The FHIR specification version that this FHIR store
supports natively. This field is immutable after store creation. Requests are
rejected if they contain FHIR resources of a different version. Version is
required for every FHIR store.
Corresponds to the JSON property version
3253 3254 3255 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3253 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3260 def update!(**args) @bulk_export_gcs_destination = args[:bulk_export_gcs_destination] if args.key?(:bulk_export_gcs_destination) @complex_data_type_reference_parsing = args[:complex_data_type_reference_parsing] if args.key?(:complex_data_type_reference_parsing) @consent_config = args[:consent_config] if args.key?(:consent_config) @default_search_handling_strict = args[:default_search_handling_strict] if args.key?(:default_search_handling_strict) @disable_referential_integrity = args[:disable_referential_integrity] if args.key?(:disable_referential_integrity) @disable_resource_versioning = args[:disable_resource_versioning] if args.key?(:disable_resource_versioning) @enable_history_modifications = args[:enable_history_modifications] if args.key?(:enable_history_modifications) @enable_update_create = args[:enable_update_create] if args.key?(:enable_update_create) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @notification_config = args[:notification_config] if args.key?(:notification_config) @notification_configs = args[:notification_configs] if args.key?(:notification_configs) @search_config = args[:search_config] if args.key?(:search_config) @stream_configs = args[:stream_configs] if args.key?(:stream_configs) @validation_config = args[:validation_config] if args.key?(:validation_config) @version = args[:version] if args.key?(:version) end |