Class: Google::Apis::HealthcareV1beta1::FhirStoreMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Count of resources and total storage size by type for a given FHIR store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FhirStoreMetric

Returns a new instance of FhirStoreMetric.



3265
3266
3267
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The total count of FHIR resources in the store of this resource type. Corresponds to the JSON property count

Returns:

  • (Fixnum)


3246
3247
3248
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3246

def count
  @count
end

#resource_typeString

The FHIR resource type this metric applies to. Corresponds to the JSON property resourceType

Returns:

  • (String)


3251
3252
3253
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3251

def resource_type
  @resource_type
end

#structured_storage_size_bytesFixnum

The total amount of structured storage used by FHIR resources of this resource type in the store. Corresponds to the JSON property structuredStorageSizeBytes

Returns:

  • (Fixnum)


3257
3258
3259
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3257

def structured_storage_size_bytes
  @structured_storage_size_bytes
end

#versioned_storage_size_bytesFixnum

The total amount of versioned storage used by versioned FHIR resources of this resource type in the store. Corresponds to the JSON property versionedStorageSizeBytes

Returns:

  • (Fixnum)


3263
3264
3265
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3263

def versioned_storage_size_bytes
  @versioned_storage_size_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3270
3271
3272
3273
3274
3275
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3270

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes)
  @versioned_storage_size_bytes = args[:versioned_storage_size_bytes] if args.key?(:versioned_storage_size_bytes)
end