Class: Google::Apis::HealthcareV1beta1::FhirStoreMetric
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::FhirStoreMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Count of resources and total storage size by type for a given FHIR store.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
The total count of FHIR resources in the store of this resource type.
-
#resource_type ⇒ String
The FHIR resource type this metric applies to.
-
#structured_storage_size_bytes ⇒ Fixnum
The total amount of structured storage used by FHIR resources of this resource type in the store.
-
#versioned_storage_size_bytes ⇒ Fixnum
The total amount of versioned storage used by versioned FHIR resources of this resource type in the store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FhirStoreMetric
constructor
A new instance of FhirStoreMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FhirStoreMetric
Returns a new instance of FhirStoreMetric.
3265 3266 3267 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
The total count of FHIR resources in the store of this resource type.
Corresponds to the JSON property count
3246 3247 3248 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3246 def count @count end |
#resource_type ⇒ String
The FHIR resource type this metric applies to.
Corresponds to the JSON property resourceType
3251 3252 3253 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3251 def resource_type @resource_type end |
#structured_storage_size_bytes ⇒ Fixnum
The total amount of structured storage used by FHIR resources of this resource
type in the store.
Corresponds to the JSON property structuredStorageSizeBytes
3257 3258 3259 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3257 def structured_storage_size_bytes @structured_storage_size_bytes end |
#versioned_storage_size_bytes ⇒ Fixnum
The total amount of versioned storage used by versioned FHIR resources of this
resource type in the store.
Corresponds to the JSON property versionedStorageSizeBytes
3263 3264 3265 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3263 def versioned_storage_size_bytes @versioned_storage_size_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3270 3271 3272 3273 3274 3275 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3270 def update!(**args) @count = args[:count] if args.key?(:count) @resource_type = args[:resource_type] if args.key?(:resource_type) @structured_storage_size_bytes = args[:structured_storage_size_bytes] if args.key?(:structured_storage_size_bytes) @versioned_storage_size_bytes = args[:versioned_storage_size_bytes] if args.key?(:versioned_storage_size_bytes) end |