Class: Google::Apis::HealthcareV1beta1::FieldMetadata
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::FieldMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies FHIR paths to match, and how to handle de-identification of matching fields.
Instance Attribute Summary collapse
-
#action ⇒ String
Deidentify action for one field.
-
#paths ⇒ Array<String>
List of paths to FHIR fields to redact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FieldMetadata
constructor
A new instance of FieldMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FieldMetadata
Returns a new instance of FieldMetadata.
3378 3379 3380 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Deidentify action for one field.
Corresponds to the JSON property action
3358 3359 3360 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3358 def action @action end |
#paths ⇒ Array<String>
List of paths to FHIR fields to redact. Each path is a period-separated list
where each component is either a field name or FHIR type name. All types begin
with an upper case letter. For example, the resource field "Patient.Address.
city", which uses a string type, can be matched by "Patient.Address.String".
Path also supports partial matching. For example, "Patient.Address.city" can
be matched by "Address.city" (Patient omitted). Partial matching and type
matching can be combined. For example, "Patient.Address.city" can be matched
by "Address.String". For "choice" types (those defined in the FHIR spec with
the form: field[x]), use two separate components. For example, "deceasedAge.
unit" is matched by "Deceased.Age.unit". Supported types are:
AdministrativeGenderCode, Base64Binary, Boolean, Code, Date, DateTime, Decimal,
HumanName, Id, Instant, Integer, LanguageCode, Markdown, Oid, PositiveInt,
String, UnsignedInt, Uri, Uuid, Xhtml. The sub-type for HumanName(for example
HumanName.given, HumanName.family) can be omitted.
Corresponds to the JSON property paths
3376 3377 3378 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3376 def paths @paths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3383 3384 3385 3386 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3383 def update!(**args) @action = args[:action] if args.key?(:action) @paths = args[:paths] if args.key?(:paths) end |