Class: Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies the FHIR paths to match and how to handle the de-identification of matching fields.
Instance Attribute Summary collapse
-
#character_mask_field ⇒ Google::Apis::HealthcareV1beta1::CharacterMaskField
Replace field value with masking character.
-
#clean_text_field ⇒ Google::Apis::HealthcareV1beta1::CleanTextField
Inspect text and transform sensitive text.
-
#crypto_hash_field ⇒ Google::Apis::HealthcareV1beta1::CryptoHashField
Replace field value with a hash of that value.
-
#date_shift_field ⇒ Google::Apis::HealthcareV1beta1::DateShiftField
Shift the date by a randomized number of days.
-
#keep_field ⇒ Google::Apis::HealthcareV1beta1::KeepField
Keep field unchanged.
-
#paths ⇒ Array<String>
List of paths to FHIR fields to redact.
-
#remove_field ⇒ Google::Apis::HealthcareV1beta1::RemoveField
Remove field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata
constructor
A new instance of GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata
Returns a new instance of GoogleCloudHealthcareV1beta1DeidentifyFieldMetadata.
3685 3686 3687 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#character_mask_field ⇒ Google::Apis::HealthcareV1beta1::CharacterMaskField
Replace field value with masking character. Supported types: Code, Decimal, HumanName, Id, LanguageCode, Markdown,
Oid, String, Uri, Uuid, Xhtml.
Corresponds to the JSON property characterMaskField
3631 3632 3633 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3631 def character_mask_field @character_mask_field end |
#clean_text_field ⇒ Google::Apis::HealthcareV1beta1::CleanTextField
Inspect text and transform sensitive text. Configure using TextConfig.
Supported types: Code, Date,
DateTime, Decimal, HumanName, Id, LanguageCode, Markdown, Oid, String, Uri,
Uuid, Xhtml.
Corresponds to the JSON property cleanTextField
3639 3640 3641 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3639 def clean_text_field @clean_text_field end |
#crypto_hash_field ⇒ Google::Apis::HealthcareV1beta1::CryptoHashField
Replace field value with a hash of that value. Supported types: Code, Decimal, HumanName, Id, LanguageCode,
Markdown, Oid, String, Uri, Uuid, Xhtml.
Corresponds to the JSON property cryptoHashField
3646 3647 3648 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3646 def crypto_hash_field @crypto_hash_field end |
#date_shift_field ⇒ Google::Apis::HealthcareV1beta1::DateShiftField
Shift the date by a randomized number of days. See date shifting for more information.
Supported types: Date, DateTime.
Corresponds to the JSON property dateShiftField
3653 3654 3655 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3653 def date_shift_field @date_shift_field end |
#keep_field ⇒ Google::Apis::HealthcareV1beta1::KeepField
Keep field unchanged.
Corresponds to the JSON property keepField
3658 3659 3660 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3658 def keep_field @keep_field end |
#paths ⇒ Array<String>
List of paths to FHIR fields to redact. Each path is a period-separated list
where each component is either a field name or FHIR type name. All types begin with an upper case letter. For
example, the resource field Patient.Address.city, which uses a string type, can be
matched by Patient.Address.String. Partial matching is supported. For
example, Patient.Address.city can be matched by Address.city (with
Patient omitted). Partial matching and type matching can be combined, for
example Patient.Address.city can be matched by Address.String. For "choice"
types (those defined in the FHIR spec with the format field[x]), use two
separate components. For example, deceasedAge.unit is matched by Deceased.
Age.unit. The following types are supported: AdministrativeGenderCode,
Base64Binary, Boolean, Code, Date, DateTime, Decimal, HumanName, Id, Instant,
Integer, LanguageCode, Markdown, Oid, PositiveInt, String, UnsignedInt, Uri,
Uuid, Xhtml. The sub-type for HumanName (for example HumanName.given,
HumanName.family) can be omitted.
Corresponds to the JSON property paths
3678 3679 3680 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3678 def paths @paths end |
#remove_field ⇒ Google::Apis::HealthcareV1beta1::RemoveField
Remove field.
Corresponds to the JSON property removeField
3683 3684 3685 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3683 def remove_field @remove_field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3690 3691 3692 3693 3694 3695 3696 3697 3698 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3690 def update!(**args) @character_mask_field = args[:character_mask_field] if args.key?(:character_mask_field) @clean_text_field = args[:clean_text_field] if args.key?(:clean_text_field) @crypto_hash_field = args[:crypto_hash_field] if args.key?(:crypto_hash_field) @date_shift_field = args[:date_shift_field] if args.key?(:date_shift_field) @keep_field = args[:keep_field] if args.key?(:keep_field) @paths = args[:paths] if args.key?(:paths) @remove_field = args[:remove_field] if args.key?(:remove_field) end |