Class: Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirBigQueryDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The configuration for exporting to BigQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudHealthcareV1beta1FhirBigQueryDestination

Returns a new instance of GoogleCloudHealthcareV1beta1FhirBigQueryDestination.



3904
3905
3906
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_data_capture_configGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirChangeDataCaptureConfig

BigQuery Change Data Capture configuration. Corresponds to the JSON property changeDataCaptureConfig



3875
3876
3877
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3875

def change_data_capture_config
  @change_data_capture_config
end

#dataset_uriString

BigQuery URI to an existing dataset, up to 2000 characters long, in the format bq://projectId.bqDatasetId. Corresponds to the JSON property datasetUri

Returns:

  • (String)


3881
3882
3883
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3881

def dataset_uri
  @dataset_uri
end

#forceBoolean Also known as: force?

Use write_disposition instead. If write_disposition is specified, this parameter is ignored. force=false is equivalent to write_disposition= WRITE_EMPTY and force=true is equivalent to write_disposition=WRITE_TRUNCATE. Corresponds to the JSON property force

Returns:

  • (Boolean)


3888
3889
3890
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3888

def force
  @force
end

#schema_configGoogle::Apis::HealthcareV1beta1::SchemaConfig

Configuration for the FHIR BigQuery schema. Determines how the server generates the schema. Corresponds to the JSON property schemaConfig



3895
3896
3897
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3895

def schema_config
  @schema_config
end

#write_dispositionString

Determines if existing data in the destination dataset is overwritten, appended to, or not written if the tables contain data. If a write_disposition is specified, the force parameter is ignored. Corresponds to the JSON property writeDisposition

Returns:

  • (String)


3902
3903
3904
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3902

def write_disposition
  @write_disposition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3909
3910
3911
3912
3913
3914
3915
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 3909

def update!(**args)
  @change_data_capture_config = args[:change_data_capture_config] if args.key?(:change_data_capture_config)
  @dataset_uri = args[:dataset_uri] if args.key?(:dataset_uri)
  @force = args[:force] if args.key?(:force)
  @schema_config = args[:schema_config] if args.key?(:schema_config)
  @write_disposition = args[:write_disposition] if args.key?(:write_disposition)
end