Class: Google::Apis::HealthcareV1beta1::Hl7V2Store

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Represents an HL7v2 store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Hl7V2Store

Returns a new instance of Hl7V2Store.



4291
4292
4293
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

User-supplied key-value pairs used to organize HL7v2 stores. Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: \pLl\pLo 0,62 Label values are optional, must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE regular expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be associated with a given store. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4249
4250
4251
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4249

def labels
  @labels
end

#nameString

Identifier. Resource name of the HL7v2 store, of the form projects/ project_id/locations/location_id/datasets/dataset_id/hl7V2Stores/ hl7v2_store_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4256
4257
4258
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4256

def name
  @name
end

#notification_configGoogle::Apis::HealthcareV1beta1::NotificationConfig

Specifies where to send notifications upon changes to a data store. Corresponds to the JSON property notificationConfig



4261
4262
4263
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4261

def notification_config
  @notification_config
end

#notification_configsArray<Google::Apis::HealthcareV1beta1::Hl7V2NotificationConfig>

A list of notification configs. Each configuration uses a filter to determine whether to publish a message (both Ingest & Create) on the corresponding notification destination. Only the message name is sent as part of the notification. Supplied by the client. Corresponds to the JSON property notificationConfigs



4269
4270
4271
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4269

def notification_configs
  @notification_configs
end

#parser_configGoogle::Apis::HealthcareV1beta1::ParserConfig

The configuration for the parser. It determines how the server parses the messages. Corresponds to the JSON property parserConfig



4275
4276
4277
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4275

def parser_config
  @parser_config
end

#reject_duplicate_messageBoolean Also known as: reject_duplicate_message?

Determines whether to reject duplicate messages. A duplicate message is a message with the same raw bytes as a message that has already been ingested/ created in this HL7v2 store. The default value is false, meaning that the store accepts the duplicate messages and it also returns the same ACK message in the IngestMessageResponse as has been returned previously. Note that only one resource is created in the store. When this field is set to true, CreateMessage/IngestMessage requests with a duplicate message will be rejected by the store, and IngestMessageErrorDetail returns a NACK message upon rejection. Corresponds to the JSON property rejectDuplicateMessage

Returns:

  • (Boolean)


4288
4289
4290
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4288

def reject_duplicate_message
  @reject_duplicate_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4296
4297
4298
4299
4300
4301
4302
4303
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4296

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @notification_config = args[:notification_config] if args.key?(:notification_config)
  @notification_configs = args[:notification_configs] if args.key?(:notification_configs)
  @parser_config = args[:parser_config] if args.key?(:parser_config)
  @reject_duplicate_message = args[:reject_duplicate_message] if args.key?(:reject_duplicate_message)
end