Class: Google::Apis::HealthcareV1beta1::HttpBody
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::HttpBody
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Message that represents an arbitrary HTTP body. It should only be used for
payload formats that can't be represented as JSON, such as raw binary or an
HTML page. This message can be used both in streaming and non-streaming API
methods in the request as well as the response. It can be used as a top-level
request field, which is convenient if one wants to extract parameters from
either the URL or HTTP template into the request fields and also want access
to the raw HTTP body. Example: message GetResourceRequest // A unique
request id. string request_id = 1; // The raw HTTP body is bound to this field.
google.api.HttpBody http_body = 2; service ResourceService rpc
GetResource(GetResourceRequest) returns (google.api.HttpBody); rpc
UpdateResource(google.api.HttpBody) returns (google.protobuf.Empty); Example
with streaming methods: service CaldavService rpc GetCalendar(stream google.
api.HttpBody) returns (stream google.api.HttpBody); rpc UpdateCalendar(stream
google.api.HttpBody) returns (stream google.api.HttpBody); Use of this type
only changes how the request and response bodies are handled, all other
features will continue to work unchanged.
Instance Attribute Summary collapse
-
#content_type ⇒ String
The HTTP Content-Type header value specifying the content type of the body.
-
#data ⇒ String
The HTTP request/response body as raw binary.
-
#extensions ⇒ Array<Hash<String,Object>>
Application specific response metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpBody
constructor
A new instance of HttpBody.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpBody
Returns a new instance of HttpBody.
4400 4401 4402 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
The HTTP Content-Type header value specifying the content type of the body.
Corresponds to the JSON property contentType
4386 4387 4388 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4386 def content_type @content_type end |
#data ⇒ String
The HTTP request/response body as raw binary.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
4392 4393 4394 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4392 def data @data end |
#extensions ⇒ Array<Hash<String,Object>>
Application specific response metadata. Must be set in the first response for
streaming APIs.
Corresponds to the JSON property extensions
4398 4399 4400 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4398 def extensions @extensions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4405 4406 4407 4408 4409 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4405 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @data = args[:data] if args.key?(:data) @extensions = args[:extensions] if args.key?(:extensions) end |