Class: Google::Apis::HealthcareV1beta1::ImportDicomDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ImportDicomDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Imports data into the specified DICOM store. Returns an error if any of the files to import are not DICOM files. This API accepts duplicate DICOM instances by ignoring the newly-pushed instance. It does not overwrite.
Instance Attribute Summary collapse
-
#blob_storage_settings ⇒ Google::Apis::HealthcareV1beta1::BlobStorageSettings
Settings for data stored in Blob storage.
-
#gcs_source ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomGcsSource
Specifies the configuration for importing data from Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportDicomDataRequest
constructor
A new instance of ImportDicomDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportDicomDataRequest
Returns a new instance of ImportDicomDataRequest.
4436 4437 4438 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_storage_settings ⇒ Google::Apis::HealthcareV1beta1::BlobStorageSettings
Settings for data stored in Blob storage.
Corresponds to the JSON property blobStorageSettings
4429 4430 4431 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4429 def blob_storage_settings @blob_storage_settings end |
#gcs_source ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1DicomGcsSource
Specifies the configuration for importing data from Cloud Storage.
Corresponds to the JSON property gcsSource
4434 4435 4436 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4434 def gcs_source @gcs_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4441 4442 4443 4444 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4441 def update!(**args) @blob_storage_settings = args[:blob_storage_settings] if args.key?(:blob_storage_settings) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) end |