Class: Google::Apis::HealthcareV1beta1::ImportMessagesResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ImportMessagesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Final response of importing messages. This structure is included in the response to describe the detailed outcome. It is only included when the operation finishes successfully.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportMessagesResponse
constructor
A new instance of ImportMessagesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportMessagesResponse
Returns a new instance of ImportMessagesResponse.
4547 4548 4549 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4547 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4552 4553 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4552 def update!(**args) end |