Class: Google::Apis::HealthcareV1beta1::ImportResourcesHistoryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Request to import the history of resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportResourcesHistoryRequest

Returns a new instance of ImportResourcesHistoryRequest.



4620
4621
4622
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_structureString

The content structure in the source location. If not specified, the server treats the input source files as BUNDLE. Corresponds to the JSON property contentStructure

Returns:

  • (String)


4605
4606
4607
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4605

def content_structure
  @content_structure
end

#gcs_sourceGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsSource

Specifies the configuration for importing data from Cloud Storage. Corresponds to the JSON property gcsSource



4610
4611
4612
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4610

def gcs_source
  @gcs_source
end

#max_error_countFixnum

The maximum number of errors before the server cancels the operation. If not specified or set to 0, defaults to 100. -1 means no maximum, the server tries to process all input. Since the server executes the operation in parallel, it might not stop the operation after exactly this number of errors occur. Corresponds to the JSON property maxErrorCount

Returns:

  • (Fixnum)


4618
4619
4620
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4618

def max_error_count
  @max_error_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4625
4626
4627
4628
4629
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4625

def update!(**args)
  @content_structure = args[:content_structure] if args.key?(:content_structure)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @max_error_count = args[:max_error_count] if args.key?(:max_error_count)
end