Class: Google::Apis::HealthcareV1beta1::ImportResourcesHistoryRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ImportResourcesHistoryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Request to import the history of resources.
Instance Attribute Summary collapse
-
#content_structure ⇒ String
The content structure in the source location.
-
#gcs_source ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsSource
Specifies the configuration for importing data from Cloud Storage.
-
#max_error_count ⇒ Fixnum
The maximum number of errors before the server cancels the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportResourcesHistoryRequest
constructor
A new instance of ImportResourcesHistoryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportResourcesHistoryRequest
Returns a new instance of ImportResourcesHistoryRequest.
4579 4580 4581 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_structure ⇒ String
The content structure in the source location. If not specified, the server
treats the input source files as BUNDLE.
Corresponds to the JSON property contentStructure
4564 4565 4566 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4564 def content_structure @content_structure end |
#gcs_source ⇒ Google::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirGcsSource
Specifies the configuration for importing data from Cloud Storage.
Corresponds to the JSON property gcsSource
4569 4570 4571 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4569 def gcs_source @gcs_source end |
#max_error_count ⇒ Fixnum
The maximum number of errors before the server cancels the operation. If not
specified or set to 0, defaults to 100. -1 means no maximum, the server tries
to process all input. Since the server executes the operation in parallel, it
might not stop the operation after exactly this number of errors occur.
Corresponds to the JSON property maxErrorCount
4577 4578 4579 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4577 def max_error_count @max_error_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4584 4585 4586 4587 4588 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4584 def update!(**args) @content_structure = args[:content_structure] if args.key?(:content_structure) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @max_error_count = args[:max_error_count] if args.key?(:max_error_count) end |