Class: Google::Apis::HealthcareV1beta1::ListDatasetsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Lists the available datasets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDatasetsResponse

Returns a new instance of ListDatasetsResponse.



4906
4907
4908
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetsArray<Google::Apis::HealthcareV1beta1::Dataset>

The first page of datasets. Corresponds to the JSON property datasets



4898
4899
4900
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4898

def datasets
  @datasets
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4904
4905
4906
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4904

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4911
4912
4913
4914
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 4911

def update!(**args)
  @datasets = args[:datasets] if args.key?(:datasets)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end