Class: Google::Apis::HealthcareV1beta1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
OperationMetadata provides information about the operation execution. Returned in the long-running operation's metadata field.
Instance Attribute Summary collapse
-
#api_method_name ⇒ String
The name of the API method that initiated the operation.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Specifies if cancellation was requested for the operation.
-
#counter ⇒ Google::Apis::HealthcareV1beta1::ProgressCounter
ProgressCounter provides counters to describe an operation's progress.
-
#create_time ⇒ String
The time at which the operation was created by the API.
-
#end_time ⇒ String
The time at which execution workloads were completed.
-
#logs_url ⇒ String
A link to audit and error logs in the log viewer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
5387 5388 5389 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_method_name ⇒ String
The name of the API method that initiated the operation.
Corresponds to the JSON property apiMethodName
5354 5355 5356 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5354 def api_method_name @api_method_name end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Specifies if cancellation was requested for the operation.
Corresponds to the JSON property cancelRequested
5359 5360 5361 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5359 def cancel_requested @cancel_requested end |
#counter ⇒ Google::Apis::HealthcareV1beta1::ProgressCounter
ProgressCounter provides counters to describe an operation's progress.
Corresponds to the JSON property counter
5365 5366 5367 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5365 def counter @counter end |
#create_time ⇒ String
The time at which the operation was created by the API.
Corresponds to the JSON property createTime
5370 5371 5372 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5370 def create_time @create_time end |
#end_time ⇒ String
The time at which execution workloads were completed. Some tasks will complete
after this time such as logging audit logs.
Corresponds to the JSON property endTime
5376 5377 5378 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5376 def end_time @end_time end |
#logs_url ⇒ String
A link to audit and error logs in the log viewer. Error logs are generated
only by some operations, listed at Viewing error logs in Cloud Logging. The end_time specified
in this URL may not match the end time on the metadata because logs are
written asynchronously from execution.
Corresponds to the JSON property logsUrl
5385 5386 5387 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5385 def logs_url @logs_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5392 5393 5394 5395 5396 5397 5398 5399 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5392 def update!(**args) @api_method_name = args[:api_method_name] if args.key?(:api_method_name) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @counter = args[:counter] if args.key?(:counter) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @logs_url = args[:logs_url] if args.key?(:logs_url) end |