Class: Google::Apis::HealthcareV1beta1::Options
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::Options
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Specifies additional options to apply to the base profile.
Instance Attribute Summary collapse
-
#clean_descriptors ⇒ Google::Apis::HealthcareV1beta1::CleanDescriptorsOption
This option is based on the DICOM Standard's Clean Descriptors Option, and the
CleanTextActionis applied to all the specified fields. -
#clean_image ⇒ Google::Apis::HealthcareV1beta1::ImageConfig
Specifies how to handle de-identification of image pixels.
- #primary_ids ⇒ String
Instance Method Summary collapse
-
#initialize(**args) ⇒ Options
constructor
A new instance of Options.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Options
Returns a new instance of Options.
5533 5534 5535 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clean_descriptors ⇒ Google::Apis::HealthcareV1beta1::CleanDescriptorsOption
This option is based on the DICOM Standard's Clean Descriptors Option, and
the CleanText Action is applied to all the specified fields. When cleaning
text, the process attempts to transform phrases matching any of the tags
marked for removal (action codes D, Z, X, and U) in the Basic Profile. These
contextual phrases are replaced with the token "[CTX]". This option uses an
additional infoType during inspection.
Corresponds to the JSON property cleanDescriptors
5519 5520 5521 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5519 def clean_descriptors @clean_descriptors end |
#clean_image ⇒ Google::Apis::HealthcareV1beta1::ImageConfig
Specifies how to handle de-identification of image pixels.
Corresponds to the JSON property cleanImage
5524 5525 5526 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5524 def clean_image @clean_image end |
#primary_ids ⇒ String
Set Action for StudyInstanceUID, SeriesInstanceUID, SOPInstanceUID,
and MediaStorageSOPInstanceUID.
Corresponds to the JSON property primaryIds
5531 5532 5533 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5531 def primary_ids @primary_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5538 5539 5540 5541 5542 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5538 def update!(**args) @clean_descriptors = args[:clean_descriptors] if args.key?(:clean_descriptors) @clean_image = args[:clean_image] if args.key?(:clean_image) @primary_ids = args[:primary_ids] if args.key?(:primary_ids) end |