Class: Google::Apis::HealthcareV1beta1::Options

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Specifies additional options to apply to the base profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Options

Returns a new instance of Options.



5430
5431
5432
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clean_descriptorsGoogle::Apis::HealthcareV1beta1::CleanDescriptorsOption

This option is based on the DICOM Standard's Clean Descriptors Option, and the CleanText Action is applied to all the specified fields. When cleaning text, the process attempts to transform phrases matching any of the tags marked for removal (action codes D, Z, X, and U) in the Basic Profile. These contextual phrases are replaced with the token "[CTX]". This option uses an additional infoType during inspection. Corresponds to the JSON property cleanDescriptors



5416
5417
5418
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5416

def clean_descriptors
  @clean_descriptors
end

#clean_imageGoogle::Apis::HealthcareV1beta1::ImageConfig

Specifies how to handle de-identification of image pixels. Corresponds to the JSON property cleanImage



5421
5422
5423
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5421

def clean_image
  @clean_image
end

#primary_idsString

Set Action for StudyInstanceUID, SeriesInstanceUID, SOPInstanceUID, and MediaStorageSOPInstanceUID. Corresponds to the JSON property primaryIds

Returns:

  • (String)


5428
5429
5430
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5428

def primary_ids
  @primary_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5435
5436
5437
5438
5439
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5435

def update!(**args)
  @clean_descriptors = args[:clean_descriptors] if args.key?(:clean_descriptors)
  @clean_image = args[:clean_image] if args.key?(:clean_image)
  @primary_ids = args[:primary_ids] if args.key?(:primary_ids)
end