Class: Google::Apis::HealthcareV1beta1::ParserConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The configuration for the parser. It determines how the server parses the messages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParserConfig

Returns a new instance of ParserConfig.



5491
5492
5493
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_null_headerBoolean Also known as: allow_null_header?

Determines whether messages with no header are allowed. Corresponds to the JSON property allowNullHeader

Returns:

  • (Boolean)


5469
5470
5471
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5469

def allow_null_header
  @allow_null_header
end

#schemaGoogle::Apis::HealthcareV1beta1::SchemaPackage

A schema package contains a set of schemas and type definitions. Corresponds to the JSON property schema



5475
5476
5477
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5475

def schema
  @schema
end

#segment_terminatorString

Byte(s) to use as the segment terminator. If this is unset, '\r' is used as segment terminator, matching the HL7 version 2 specification. Corresponds to the JSON property segmentTerminator NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5482
5483
5484
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5482

def segment_terminator
  @segment_terminator
end

#versionString

Immutable. Determines the version of both the default parser to be used when schema is not given, as well as the schematized parser used when schema is specified. This field is immutable after HL7v2 store creation. Corresponds to the JSON property version

Returns:

  • (String)


5489
5490
5491
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5489

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5496
5497
5498
5499
5500
5501
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5496

def update!(**args)
  @allow_null_header = args[:allow_null_header] if args.key?(:allow_null_header)
  @schema = args[:schema] if args.key?(:schema)
  @segment_terminator = args[:segment_terminator] if args.key?(:segment_terminator)
  @version = args[:version] if args.key?(:version)
end