Class: Google::Apis::HealthcareV1beta1::ProgressCounter
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ProgressCounter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
ProgressCounter provides counters to describe an operation's progress.
Instance Attribute Summary collapse
-
#failure ⇒ Fixnum
The number of units that failed in the operation.
-
#pending ⇒ Fixnum
The number of units that are pending in the operation.
-
#secondary_failure ⇒ Fixnum
The number of secondary units that failed in the operation.
-
#secondary_success ⇒ Fixnum
The number of secondary units that succeeded in the operation.
-
#success ⇒ Fixnum
The number of units that succeeded in the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProgressCounter
constructor
A new instance of ProgressCounter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProgressCounter
Returns a new instance of ProgressCounter.
5777 5778 5779 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure ⇒ Fixnum
The number of units that failed in the operation.
Corresponds to the JSON property failure
5755 5756 5757 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5755 def failure @failure end |
#pending ⇒ Fixnum
The number of units that are pending in the operation.
Corresponds to the JSON property pending
5760 5761 5762 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5760 def pending @pending end |
#secondary_failure ⇒ Fixnum
The number of secondary units that failed in the operation.
Corresponds to the JSON property secondaryFailure
5765 5766 5767 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5765 def secondary_failure @secondary_failure end |
#secondary_success ⇒ Fixnum
The number of secondary units that succeeded in the operation.
Corresponds to the JSON property secondarySuccess
5770 5771 5772 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5770 def secondary_success @secondary_success end |
#success ⇒ Fixnum
The number of units that succeeded in the operation.
Corresponds to the JSON property success
5775 5776 5777 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5775 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5782 5783 5784 5785 5786 5787 5788 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5782 def update!(**args) @failure = args[:failure] if args.key?(:failure) @pending = args[:pending] if args.key?(:pending) @secondary_failure = args[:secondary_failure] if args.key?(:secondary_failure) @secondary_success = args[:secondary_success] if args.key?(:secondary_success) @success = args[:success] if args.key?(:success) end |