Class: Google::Apis::HealthcareV1beta1::ProgressCounter
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::ProgressCounter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
ProgressCounter provides counters to describe an operation's progress.
Instance Attribute Summary collapse
-
#failure ⇒ Fixnum
The number of units that failed in the operation.
-
#pending ⇒ Fixnum
The number of units that are pending in the operation.
-
#secondary_failure ⇒ Fixnum
The number of secondary units that failed in the operation.
-
#secondary_success ⇒ Fixnum
The number of secondary units that succeeded in the operation.
-
#success ⇒ Fixnum
The number of units that succeeded in the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProgressCounter
constructor
A new instance of ProgressCounter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProgressCounter
Returns a new instance of ProgressCounter.
5736 5737 5738 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure ⇒ Fixnum
The number of units that failed in the operation.
Corresponds to the JSON property failure
5714 5715 5716 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5714 def failure @failure end |
#pending ⇒ Fixnum
The number of units that are pending in the operation.
Corresponds to the JSON property pending
5719 5720 5721 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5719 def pending @pending end |
#secondary_failure ⇒ Fixnum
The number of secondary units that failed in the operation.
Corresponds to the JSON property secondaryFailure
5724 5725 5726 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5724 def secondary_failure @secondary_failure end |
#secondary_success ⇒ Fixnum
The number of secondary units that succeeded in the operation.
Corresponds to the JSON property secondarySuccess
5729 5730 5731 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5729 def secondary_success @secondary_success end |
#success ⇒ Fixnum
The number of units that succeeded in the operation.
Corresponds to the JSON property success
5734 5735 5736 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5734 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5741 def update!(**args) @failure = args[:failure] if args.key?(:failure) @pending = args[:pending] if args.key?(:pending) @secondary_failure = args[:secondary_failure] if args.key?(:secondary_failure) @secondary_success = args[:secondary_success] if args.key?(:secondary_success) @success = args[:success] if args.key?(:success) end |