Class: Google::Apis::HealthcareV1beta1::ProgressCounter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

ProgressCounter provides counters to describe an operation's progress.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProgressCounter

Returns a new instance of ProgressCounter.



5674
5675
5676
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failureFixnum

The number of units that failed in the operation. Corresponds to the JSON property failure

Returns:

  • (Fixnum)


5652
5653
5654
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5652

def failure
  @failure
end

#pendingFixnum

The number of units that are pending in the operation. Corresponds to the JSON property pending

Returns:

  • (Fixnum)


5657
5658
5659
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5657

def pending
  @pending
end

#secondary_failureFixnum

The number of secondary units that failed in the operation. Corresponds to the JSON property secondaryFailure

Returns:

  • (Fixnum)


5662
5663
5664
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5662

def secondary_failure
  @secondary_failure
end

#secondary_successFixnum

The number of secondary units that succeeded in the operation. Corresponds to the JSON property secondarySuccess

Returns:

  • (Fixnum)


5667
5668
5669
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5667

def secondary_success
  @secondary_success
end

#successFixnum

The number of units that succeeded in the operation. Corresponds to the JSON property success

Returns:

  • (Fixnum)


5672
5673
5674
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5672

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5679
5680
5681
5682
5683
5684
5685
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5679

def update!(**args)
  @failure = args[:failure] if args.key?(:failure)
  @pending = args[:pending] if args.key?(:pending)
  @secondary_failure = args[:secondary_failure] if args.key?(:secondary_failure)
  @secondary_success = args[:secondary_success] if args.key?(:secondary_success)
  @success = args[:success] if args.key?(:success)
end