Class: Google::Apis::HealthcareV1beta1::Result

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

The consent evaluation result for a single data_id.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Result

Returns a new instance of Result.



5939
5940
5941
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The resource names of all evaluated Consents mapped to their evaluation. Corresponds to the JSON property consentDetails



5926
5927
5928
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5926

def consent_details
  @consent_details
end

#consentedBoolean Also known as: consented?

Whether the resource is consented for the given use. Corresponds to the JSON property consented

Returns:

  • (Boolean)


5931
5932
5933
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5931

def consented
  @consented
end

#data_idString

The unique identifier of the evaluated resource. Corresponds to the JSON property dataId

Returns:

  • (String)


5937
5938
5939
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5937

def data_id
  @data_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5944
5945
5946
5947
5948
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 5944

def update!(**args)
  @consent_details = args[:consent_details] if args.key?(:consent_details)
  @consented = args[:consented] if args.key?(:consented)
  @data_id = args[:data_id] if args.key?(:data_id)
end