Class: Google::Apis::HealthcareV1beta1::RollbackFhirResourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Request to roll back resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackFhirResourcesRequest

Returns a new instance of RollbackFhirResourcesRequest.



6053
6054
6055
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_typeString

Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type. Corresponds to the JSON property changeType

Returns:

  • (String)


6013
6014
6015
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6013

def change_type
  @change_type
end

#exclude_rollbacksBoolean Also known as: exclude_rollbacks?

Optional. Specifies whether to exclude earlier rollbacks. Corresponds to the JSON property excludeRollbacks

Returns:

  • (Boolean)


6018
6019
6020
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6018

def exclude_rollbacks
  @exclude_rollbacks
end

#filtering_fieldsGoogle::Apis::HealthcareV1beta1::RollbackFhirResourceFilteringFields

Filters to select resources that need to be rolled back. Corresponds to the JSON property filteringFields



6024
6025
6026
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6024

def filtering_fields
  @filtering_fields
end

#forceBoolean Also known as: force?

Optional. When enabled, changes will be reverted without explicit confirmation Corresponds to the JSON property force

Returns:

  • (Boolean)


6029
6030
6031
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6029

def force
  @force
end

#input_gcs_objectString

Optional. Cloud Storage object containing list of resourceType/resourceId lines, identifying resources to be reverted Corresponds to the JSON property inputGcsObject

Returns:

  • (String)


6036
6037
6038
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6036

def input_gcs_object
  @input_gcs_object
end

#result_gcs_bucketString

Required. Bucket to deposit result Corresponds to the JSON property resultGcsBucket

Returns:

  • (String)


6041
6042
6043
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6041

def result_gcs_bucket
  @result_gcs_bucket
end

#rollback_timeString

Required. Time point to rollback to. Corresponds to the JSON property rollbackTime

Returns:

  • (String)


6046
6047
6048
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6046

def rollback_time
  @rollback_time
end

#typeArray<String>

Optional. If specified, revert only resources of these types Corresponds to the JSON property type

Returns:

  • (Array<String>)


6051
6052
6053
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6051

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6058

def update!(**args)
  @change_type = args[:change_type] if args.key?(:change_type)
  @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks)
  @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields)
  @force = args[:force] if args.key?(:force)
  @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object)
  @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket)
  @rollback_time = args[:rollback_time] if args.key?(:rollback_time)
  @type = args[:type] if args.key?(:type)
end