Class: Google::Apis::HealthcareV1beta1::RollbackHl7V2MessagesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Point in time recovery rollback request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackHl7V2MessagesRequest

Returns a new instance of RollbackHl7V2MessagesRequest.



6256
6257
6258
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_typeString

Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type. Corresponds to the JSON property changeType

Returns:

  • (String)


6220
6221
6222
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6220

def change_type
  @change_type
end

#exclude_rollbacksBoolean Also known as: exclude_rollbacks?

Optional. Specifies whether to exclude earlier rollbacks. Corresponds to the JSON property excludeRollbacks

Returns:

  • (Boolean)


6225
6226
6227
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6225

def exclude_rollbacks
  @exclude_rollbacks
end

#filtering_fieldsGoogle::Apis::HealthcareV1beta1::RollbackHl7MessagesFilteringFields

Filtering fields for an HL7v2 rollback. Currently only supports a list of operation ids to roll back. Corresponds to the JSON property filteringFields



6232
6233
6234
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6232

def filtering_fields
  @filtering_fields
end

#forceBoolean Also known as: force?

Optional. When enabled, changes will be reverted without explicit confirmation. Corresponds to the JSON property force

Returns:

  • (Boolean)


6237
6238
6239
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6237

def force
  @force
end

#input_gcs_objectString

Optional. Cloud storage object containing list of resourceId lines, identifying resources to be reverted Corresponds to the JSON property inputGcsObject

Returns:

  • (String)


6244
6245
6246
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6244

def input_gcs_object
  @input_gcs_object
end

#result_gcs_bucketString

Required. Bucket to deposit result Corresponds to the JSON property resultGcsBucket

Returns:

  • (String)


6249
6250
6251
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6249

def result_gcs_bucket
  @result_gcs_bucket
end

#rollback_timeString

Required. Times point to rollback to. Corresponds to the JSON property rollbackTime

Returns:

  • (String)


6254
6255
6256
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6254

def rollback_time
  @rollback_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6261
6262
6263
6264
6265
6266
6267
6268
6269
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6261

def update!(**args)
  @change_type = args[:change_type] if args.key?(:change_type)
  @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks)
  @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields)
  @force = args[:force] if args.key?(:force)
  @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object)
  @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket)
  @rollback_time = args[:rollback_time] if args.key?(:rollback_time)
end