Class: Google::Apis::HealthcareV1beta1::RollbackHl7V2MessagesRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::RollbackHl7V2MessagesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Point in time recovery rollback request.
Instance Attribute Summary collapse
-
#change_type ⇒ String
Optional.
-
#exclude_rollbacks ⇒ Boolean
(also: #exclude_rollbacks?)
Optional.
-
#filtering_fields ⇒ Google::Apis::HealthcareV1beta1::RollbackHl7MessagesFilteringFields
Filtering fields for an HL7v2 rollback.
-
#force ⇒ Boolean
(also: #force?)
Optional.
-
#input_gcs_object ⇒ String
Optional.
-
#result_gcs_bucket ⇒ String
Required.
-
#rollback_time ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollbackHl7V2MessagesRequest
constructor
A new instance of RollbackHl7V2MessagesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollbackHl7V2MessagesRequest
Returns a new instance of RollbackHl7V2MessagesRequest.
6215 6216 6217 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#change_type ⇒ String
Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type.
Corresponds to the JSON property changeType
6179 6180 6181 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6179 def change_type @change_type end |
#exclude_rollbacks ⇒ Boolean Also known as: exclude_rollbacks?
Optional. Specifies whether to exclude earlier rollbacks.
Corresponds to the JSON property excludeRollbacks
6184 6185 6186 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6184 def exclude_rollbacks @exclude_rollbacks end |
#filtering_fields ⇒ Google::Apis::HealthcareV1beta1::RollbackHl7MessagesFilteringFields
Filtering fields for an HL7v2 rollback. Currently only supports a list of
operation ids to roll back.
Corresponds to the JSON property filteringFields
6191 6192 6193 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6191 def filtering_fields @filtering_fields end |
#force ⇒ Boolean Also known as: force?
Optional. When enabled, changes will be reverted without explicit confirmation.
Corresponds to the JSON property force
6196 6197 6198 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6196 def force @force end |
#input_gcs_object ⇒ String
Optional. Cloud storage object containing list of resourceId lines,
identifying resources to be reverted
Corresponds to the JSON property inputGcsObject
6203 6204 6205 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6203 def input_gcs_object @input_gcs_object end |
#result_gcs_bucket ⇒ String
Required. Bucket to deposit result
Corresponds to the JSON property resultGcsBucket
6208 6209 6210 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6208 def result_gcs_bucket @result_gcs_bucket end |
#rollback_time ⇒ String
Required. Times point to rollback to.
Corresponds to the JSON property rollbackTime
6213 6214 6215 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6213 def rollback_time @rollback_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6220 6221 6222 6223 6224 6225 6226 6227 6228 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6220 def update!(**args) @change_type = args[:change_type] if args.key?(:change_type) @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks) @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields) @force = args[:force] if args.key?(:force) @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object) @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket) @rollback_time = args[:rollback_time] if args.key?(:rollback_time) end |