Class: Google::Apis::HealthcareV1beta1::RollbackHl7V2MessagesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Point in time recovery rollback request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackHl7V2MessagesRequest

Returns a new instance of RollbackHl7V2MessagesRequest.



6153
6154
6155
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_typeString

Optional. CREATE/UPDATE/DELETE/ALL for reverting all txns of a certain type. Corresponds to the JSON property changeType

Returns:

  • (String)


6117
6118
6119
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6117

def change_type
  @change_type
end

#exclude_rollbacksBoolean Also known as: exclude_rollbacks?

Optional. Specifies whether to exclude earlier rollbacks. Corresponds to the JSON property excludeRollbacks

Returns:

  • (Boolean)


6122
6123
6124
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6122

def exclude_rollbacks
  @exclude_rollbacks
end

#filtering_fieldsGoogle::Apis::HealthcareV1beta1::RollbackHl7MessagesFilteringFields

Filtering fields for an HL7v2 rollback. Currently only supports a list of operation ids to roll back. Corresponds to the JSON property filteringFields



6129
6130
6131
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6129

def filtering_fields
  @filtering_fields
end

#forceBoolean Also known as: force?

Optional. When enabled, changes will be reverted without explicit confirmation. Corresponds to the JSON property force

Returns:

  • (Boolean)


6134
6135
6136
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6134

def force
  @force
end

#input_gcs_objectString

Optional. Cloud storage object containing list of resourceId lines, identifying resources to be reverted Corresponds to the JSON property inputGcsObject

Returns:

  • (String)


6141
6142
6143
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6141

def input_gcs_object
  @input_gcs_object
end

#result_gcs_bucketString

Required. Bucket to deposit result Corresponds to the JSON property resultGcsBucket

Returns:

  • (String)


6146
6147
6148
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6146

def result_gcs_bucket
  @result_gcs_bucket
end

#rollback_timeString

Required. Times point to rollback to. Corresponds to the JSON property rollbackTime

Returns:

  • (String)


6151
6152
6153
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6151

def rollback_time
  @rollback_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6158
6159
6160
6161
6162
6163
6164
6165
6166
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6158

def update!(**args)
  @change_type = args[:change_type] if args.key?(:change_type)
  @exclude_rollbacks = args[:exclude_rollbacks] if args.key?(:exclude_rollbacks)
  @filtering_fields = args[:filtering_fields] if args.key?(:filtering_fields)
  @force = args[:force] if args.key?(:force)
  @input_gcs_object = args[:input_gcs_object] if args.key?(:input_gcs_object)
  @result_gcs_bucket = args[:result_gcs_bucket] if args.key?(:result_gcs_bucket)
  @rollback_time = args[:rollback_time] if args.key?(:rollback_time)
end