Class: Google::Apis::HealthcareV1beta1::SchemaGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

An HL7v2 logical group construct.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaGroup

Returns a new instance of SchemaGroup.



6335
6336
6337
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#choiceBoolean Also known as: choice?

True indicates that this is a choice group, meaning that only one of its segments can exist in a given message. Corresponds to the JSON property choice

Returns:

  • (Boolean)


6311
6312
6313
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6311

def choice
  @choice
end

#max_occursFixnum

The maximum number of times this group can be repeated. 0 or -1 means unbounded. Corresponds to the JSON property maxOccurs

Returns:

  • (Fixnum)


6318
6319
6320
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6318

def max_occurs
  @max_occurs
end

#membersArray<Google::Apis::HealthcareV1beta1::GroupOrSegment>

Nested groups and/or segments. Corresponds to the JSON property members



6323
6324
6325
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6323

def members
  @members
end

#min_occursFixnum

The minimum number of times this group must be present/repeated. Corresponds to the JSON property minOccurs

Returns:

  • (Fixnum)


6328
6329
6330
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6328

def min_occurs
  @min_occurs
end

#nameString

The name of this group. For example, "ORDER_DETAIL". Corresponds to the JSON property name

Returns:

  • (String)


6333
6334
6335
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6333

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6340
6341
6342
6343
6344
6345
6346
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6340

def update!(**args)
  @choice = args[:choice] if args.key?(:choice)
  @max_occurs = args[:max_occurs] if args.key?(:max_occurs)
  @members = args[:members] if args.key?(:members)
  @min_occurs = args[:min_occurs] if args.key?(:min_occurs)
  @name = args[:name] if args.key?(:name)
end