Class: Google::Apis::HealthcareV1beta1::SchemaGroup
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::SchemaGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
An HL7v2 logical group construct.
Instance Attribute Summary collapse
-
#choice ⇒ Boolean
(also: #choice?)
True indicates that this is a choice group, meaning that only one of its segments can exist in a given message.
-
#max_occurs ⇒ Fixnum
The maximum number of times this group can be repeated.
-
#members ⇒ Array<Google::Apis::HealthcareV1beta1::GroupOrSegment>
Nested groups and/or segments.
-
#min_occurs ⇒ Fixnum
The minimum number of times this group must be present/repeated.
-
#name ⇒ String
The name of this group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchemaGroup
constructor
A new instance of SchemaGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchemaGroup
Returns a new instance of SchemaGroup.
6273 6274 6275 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6273 def initialize(**args) update!(**args) end |
Instance Attribute Details
#choice ⇒ Boolean Also known as: choice?
True indicates that this is a choice group, meaning that only one of its
segments can exist in a given message.
Corresponds to the JSON property choice
6249 6250 6251 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6249 def choice @choice end |
#max_occurs ⇒ Fixnum
The maximum number of times this group can be repeated. 0 or -1 means
unbounded.
Corresponds to the JSON property maxOccurs
6256 6257 6258 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6256 def max_occurs @max_occurs end |
#members ⇒ Array<Google::Apis::HealthcareV1beta1::GroupOrSegment>
Nested groups and/or segments.
Corresponds to the JSON property members
6261 6262 6263 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6261 def members @members end |
#min_occurs ⇒ Fixnum
The minimum number of times this group must be present/repeated.
Corresponds to the JSON property minOccurs
6266 6267 6268 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6266 def min_occurs @min_occurs end |
#name ⇒ String
The name of this group. For example, "ORDER_DETAIL".
Corresponds to the JSON property name
6271 6272 6273 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6271 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6278 6279 6280 6281 6282 6283 6284 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6278 def update!(**args) @choice = args[:choice] if args.key?(:choice) @max_occurs = args[:max_occurs] if args.key?(:max_occurs) @members = args[:members] if args.key?(:members) @min_occurs = args[:min_occurs] if args.key?(:min_occurs) @name = args[:name] if args.key?(:name) end |