Class: Google::Apis::HealthcareV1beta1::SchemaPackage
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::SchemaPackage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
A schema package contains a set of schemas and type definitions.
Instance Attribute Summary collapse
-
#ignore_min_occurs ⇒ Boolean
(also: #ignore_min_occurs?)
Flag to ignore all min_occurs restrictions in the schema.
-
#schemas ⇒ Array<Google::Apis::HealthcareV1beta1::Hl7SchemaConfig>
Schema configs that are layered based on their VersionSources that match the incoming message.
-
#schematized_parsing_type ⇒ String
Determines how messages that fail to parse are handled.
-
#types ⇒ Array<Google::Apis::HealthcareV1beta1::Hl7TypesConfig>
Schema type definitions that are layered based on their VersionSources that match the incoming message.
-
#unexpected_segment_handling ⇒ String
Determines how unexpected segments (segments not matched to the schema) are handled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchemaPackage
constructor
A new instance of SchemaPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchemaPackage
Returns a new instance of SchemaPackage.
6457 6458 6459 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ignore_min_occurs ⇒ Boolean Also known as: ignore_min_occurs?
Flag to ignore all min_occurs restrictions in the schema. This means that
incoming messages can omit any group, segment, field, component, or
subcomponent.
Corresponds to the JSON property ignoreMinOccurs
6427 6428 6429 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6427 def ignore_min_occurs @ignore_min_occurs end |
#schemas ⇒ Array<Google::Apis::HealthcareV1beta1::Hl7SchemaConfig>
Schema configs that are layered based on their VersionSources that match the
incoming message. Schema configs present in higher indices override those in
lower indices with the same message type and trigger event if their
VersionSources all match an incoming message.
Corresponds to the JSON property schemas
6436 6437 6438 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6436 def schemas @schemas end |
#schematized_parsing_type ⇒ String
Determines how messages that fail to parse are handled.
Corresponds to the JSON property schematizedParsingType
6441 6442 6443 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6441 def schematized_parsing_type @schematized_parsing_type end |
#types ⇒ Array<Google::Apis::HealthcareV1beta1::Hl7TypesConfig>
Schema type definitions that are layered based on their VersionSources that
match the incoming message. Type definitions present in higher indices
override those in lower indices with the same type name if their
VersionSources all match an incoming message.
Corresponds to the JSON property types
6449 6450 6451 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6449 def types @types end |
#unexpected_segment_handling ⇒ String
Determines how unexpected segments (segments not matched to the schema) are
handled.
Corresponds to the JSON property unexpectedSegmentHandling
6455 6456 6457 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6455 def unexpected_segment_handling @unexpected_segment_handling end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6462 6463 6464 6465 6466 6467 6468 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6462 def update!(**args) @ignore_min_occurs = args[:ignore_min_occurs] if args.key?(:ignore_min_occurs) @schemas = args[:schemas] if args.key?(:schemas) @schematized_parsing_type = args[:schematized_parsing_type] if args.key?(:schematized_parsing_type) @types = args[:types] if args.key?(:types) @unexpected_segment_handling = args[:unexpected_segment_handling] if args.key?(:unexpected_segment_handling) end |