Class: Google::Apis::HealthcareV1beta1::SchemaPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

A schema package contains a set of schemas and type definitions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaPackage

Returns a new instance of SchemaPackage.



6416
6417
6418
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ignore_min_occursBoolean Also known as: ignore_min_occurs?

Flag to ignore all min_occurs restrictions in the schema. This means that incoming messages can omit any group, segment, field, component, or subcomponent. Corresponds to the JSON property ignoreMinOccurs

Returns:

  • (Boolean)


6386
6387
6388
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6386

def ignore_min_occurs
  @ignore_min_occurs
end

#schemasArray<Google::Apis::HealthcareV1beta1::Hl7SchemaConfig>

Schema configs that are layered based on their VersionSources that match the incoming message. Schema configs present in higher indices override those in lower indices with the same message type and trigger event if their VersionSources all match an incoming message. Corresponds to the JSON property schemas



6395
6396
6397
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6395

def schemas
  @schemas
end

#schematized_parsing_typeString

Determines how messages that fail to parse are handled. Corresponds to the JSON property schematizedParsingType

Returns:

  • (String)


6400
6401
6402
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6400

def schematized_parsing_type
  @schematized_parsing_type
end

#typesArray<Google::Apis::HealthcareV1beta1::Hl7TypesConfig>

Schema type definitions that are layered based on their VersionSources that match the incoming message. Type definitions present in higher indices override those in lower indices with the same type name if their VersionSources all match an incoming message. Corresponds to the JSON property types



6408
6409
6410
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6408

def types
  @types
end

#unexpected_segment_handlingString

Determines how unexpected segments (segments not matched to the schema) are handled. Corresponds to the JSON property unexpectedSegmentHandling

Returns:

  • (String)


6414
6415
6416
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6414

def unexpected_segment_handling
  @unexpected_segment_handling
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6421
6422
6423
6424
6425
6426
6427
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6421

def update!(**args)
  @ignore_min_occurs = args[:ignore_min_occurs] if args.key?(:ignore_min_occurs)
  @schemas = args[:schemas] if args.key?(:schemas)
  @schematized_parsing_type = args[:schematized_parsing_type] if args.key?(:schematized_parsing_type)
  @types = args[:types] if args.key?(:types)
  @unexpected_segment_handling = args[:unexpected_segment_handling] if args.key?(:unexpected_segment_handling)
end