Class: Google::Apis::HealthcareV1beta1::SchemaPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

A schema package contains a set of schemas and type definitions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchemaPackage

Returns a new instance of SchemaPackage.



6354
6355
6356
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ignore_min_occursBoolean Also known as: ignore_min_occurs?

Flag to ignore all min_occurs restrictions in the schema. This means that incoming messages can omit any group, segment, field, component, or subcomponent. Corresponds to the JSON property ignoreMinOccurs

Returns:

  • (Boolean)


6324
6325
6326
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6324

def ignore_min_occurs
  @ignore_min_occurs
end

#schemasArray<Google::Apis::HealthcareV1beta1::Hl7SchemaConfig>

Schema configs that are layered based on their VersionSources that match the incoming message. Schema configs present in higher indices override those in lower indices with the same message type and trigger event if their VersionSources all match an incoming message. Corresponds to the JSON property schemas



6333
6334
6335
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6333

def schemas
  @schemas
end

#schematized_parsing_typeString

Determines how messages that fail to parse are handled. Corresponds to the JSON property schematizedParsingType

Returns:

  • (String)


6338
6339
6340
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6338

def schematized_parsing_type
  @schematized_parsing_type
end

#typesArray<Google::Apis::HealthcareV1beta1::Hl7TypesConfig>

Schema type definitions that are layered based on their VersionSources that match the incoming message. Type definitions present in higher indices override those in lower indices with the same type name if their VersionSources all match an incoming message. Corresponds to the JSON property types



6346
6347
6348
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6346

def types
  @types
end

#unexpected_segment_handlingString

Determines how unexpected segments (segments not matched to the schema) are handled. Corresponds to the JSON property unexpectedSegmentHandling

Returns:

  • (String)


6352
6353
6354
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6352

def unexpected_segment_handling
  @unexpected_segment_handling
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6359
6360
6361
6362
6363
6364
6365
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6359

def update!(**args)
  @ignore_min_occurs = args[:ignore_min_occurs] if args.key?(:ignore_min_occurs)
  @schemas = args[:schemas] if args.key?(:schemas)
  @schematized_parsing_type = args[:schematized_parsing_type] if args.key?(:schematized_parsing_type)
  @types = args[:types] if args.key?(:types)
  @unexpected_segment_handling = args[:unexpected_segment_handling] if args.key?(:unexpected_segment_handling)
end