Class: Google::Apis::HealthcareV1beta1::StorageInfo
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::StorageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
StorageInfo encapsulates all the storage info of a resource.
Instance Attribute Summary collapse
-
#blob_storage_info ⇒ Google::Apis::HealthcareV1beta1::BlobStorageInfo
BlobStorageInfo contains details about the data stored in Blob Storage for the referenced resource.
-
#referenced_resource ⇒ String
The resource whose storage info is returned.
-
#structured_storage_info ⇒ Google::Apis::HealthcareV1beta1::StructuredStorageInfo
StructuredStorageInfo contains details about the data stored in Structured Storage for the referenced resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageInfo
constructor
A new instance of StorageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageInfo
Returns a new instance of StorageInfo.
6748 6749 6750 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_storage_info ⇒ Google::Apis::HealthcareV1beta1::BlobStorageInfo
BlobStorageInfo contains details about the data stored in Blob Storage for the
referenced resource. Note: Storage class is only valid for DICOM and hence
will only be populated for DICOM resources.
Corresponds to the JSON property blobStorageInfo
6733 6734 6735 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6733 def blob_storage_info @blob_storage_info end |
#referenced_resource ⇒ String
The resource whose storage info is returned. For example: projects/projectID
/locations/locationID/datasets/datasetID/dicomStores/dicomStoreID/
dicomWeb/studies/studyUID/series/seriesUID/instances/instanceUID`
Corresponds to the JSON propertyreferencedResource`
6740 6741 6742 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6740 def referenced_resource @referenced_resource end |
#structured_storage_info ⇒ Google::Apis::HealthcareV1beta1::StructuredStorageInfo
StructuredStorageInfo contains details about the data stored in Structured
Storage for the referenced resource.
Corresponds to the JSON property structuredStorageInfo
6746 6747 6748 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6746 def structured_storage_info @structured_storage_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6753 6754 6755 6756 6757 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6753 def update!(**args) @blob_storage_info = args[:blob_storage_info] if args.key?(:blob_storage_info) @referenced_resource = args[:referenced_resource] if args.key?(:referenced_resource) @structured_storage_info = args[:structured_storage_info] if args.key?(:structured_storage_info) end |