Class: Google::Apis::HealthcareV1beta1::StreamConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Contains configuration for streaming FHIR export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamConfig

Returns a new instance of StreamConfig.



6844
6845
6846
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::HealthcareV1beta1::GoogleCloudHealthcareV1beta1FhirBigQueryDestination

The configuration for exporting to BigQuery. Corresponds to the JSON property bigqueryDestination



6829
6830
6831
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6829

def bigquery_destination
  @bigquery_destination
end

#deidentified_store_destinationGoogle::Apis::HealthcareV1beta1::DeidentifiedStoreDestination

Contains configuration for streaming de-identified FHIR export. Corresponds to the JSON property deidentifiedStoreDestination



6834
6835
6836
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6834

def deidentified_store_destination
  @deidentified_store_destination
end

#resource_typesArray<String>

Supply a FHIR resource type (such as "Patient" or "Observation"). See https:// www.hl7.org/fhir/valueset-resource-types.html for a list of all FHIR resource types. The server treats an empty list as an intent to stream all the supported resource types in this FHIR store. Corresponds to the JSON property resourceTypes

Returns:

  • (Array<String>)


6842
6843
6844
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6842

def resource_types
  @resource_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6849
6850
6851
6852
6853
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 6849

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @deidentified_store_destination = args[:deidentified_store_destination] if args.key?(:deidentified_store_destination)
  @resource_types = args[:resource_types] if args.key?(:resource_types)
end