Class: Google::Apis::HealthcareV1beta1::TimeRange
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::TimeRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Apply consents given by patients whose most recent consent changes are in the time range. Note that after identifying these patients, the server applies all Consent resources given by those patients, not just the Consent resources within the timestamp in the range.
Instance Attribute Summary collapse
-
#end ⇒ String
Optional.
-
#start ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeRange
constructor
A new instance of TimeRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeRange
Returns a new instance of TimeRange.
7090 7091 7092 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end ⇒ String
Optional. The latest consent change time, in format YYYY-MM-DDThh:mm:ss.sss+zz:
zz If not specified, the system uses the time when ApplyConsents was called.
Corresponds to the JSON property end
7082 7083 7084 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7082 def end @end end |
#start ⇒ String
Optional. The earliest consent change time, in format YYYY-MM-DDThh:mm:ss.sss+
zz:zz If not specified, the system uses the FHIR store creation time.
Corresponds to the JSON property start
7088 7089 7090 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7088 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7095 7096 7097 7098 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7095 def update!(**args) @end = args[:end] if args.key?(:end) @start = args[:start] if args.key?(:start) end |