Class: Google::Apis::HealthcareV1beta1::TimeRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb

Overview

Apply consents given by patients whose most recent consent changes are in the time range. Note that after identifying these patients, the server applies all Consent resources given by those patients, not just the Consent resources within the timestamp in the range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeRange

Returns a new instance of TimeRange.



7028
7029
7030
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

Optional. The latest consent change time, in format YYYY-MM-DDThh:mm:ss.sss+zz: zz If not specified, the system uses the time when ApplyConsents was called. Corresponds to the JSON property end

Returns:

  • (String)


7020
7021
7022
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7020

def end
  @end
end

#startString

Optional. The earliest consent change time, in format YYYY-MM-DDThh:mm:ss.sss+ zz:zz If not specified, the system uses the FHIR store creation time. Corresponds to the JSON property start

Returns:

  • (String)


7026
7027
7028
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7026

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7033
7034
7035
7036
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7033

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @start = args[:start] if args.key?(:start)
end