Class: Google::Apis::HealthcareV1beta1::UserDataMapping
- Inherits:
-
Object
- Object
- Google::Apis::HealthcareV1beta1::UserDataMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/healthcare_v1beta1/classes.rb,
lib/google/apis/healthcare_v1beta1/representations.rb,
lib/google/apis/healthcare_v1beta1/representations.rb
Overview
Maps a resource to the associated user and Attributes.
Instance Attribute Summary collapse
-
#archive_time ⇒ String
Output only.
-
#archived ⇒ Boolean
(also: #archived?)
Output only.
-
#data_id ⇒ String
Required.
-
#name ⇒ String
Resource name of the User data mapping, of the form
projects/project_id/ locations/location_id/datasets/dataset_id/consentStores/consent_store_id/ userDataMappings/user_data_mapping_id``. -
#resource_attributes ⇒ Array<Google::Apis::HealthcareV1beta1::Attribute>
Attributes of the resource.
-
#user_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserDataMapping
constructor
A new instance of UserDataMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserDataMapping
Returns a new instance of UserDataMapping.
7200 7201 7202 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_time ⇒ String
Output only. Indicates the time when this mapping was archived.
Corresponds to the JSON property archiveTime
7167 7168 7169 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7167 def archive_time @archive_time end |
#archived ⇒ Boolean Also known as: archived?
Output only. Indicates whether this mapping is archived.
Corresponds to the JSON property archived
7172 7173 7174 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7172 def archived @archived end |
#data_id ⇒ String
Required. A unique identifier for the mapped resource.
Corresponds to the JSON property dataId
7178 7179 7180 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7178 def data_id @data_id end |
#name ⇒ String
Resource name of the User data mapping, of the form projects/project_id/
locations/location_id/datasets/dataset_id/consentStores/consent_store_id/
userDataMappings/user_data_mapping_id`.
Corresponds to the JSON propertyname`
7185 7186 7187 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7185 def name @name end |
#resource_attributes ⇒ Array<Google::Apis::HealthcareV1beta1::Attribute>
Attributes of the resource. Only explicitly set attributes are displayed here.
Attribute definitions with defaults set implicitly apply to these User data
mappings. Attributes listed here must be single valued, that is, exactly one
value is specified for the field "values" in each Attribute.
Corresponds to the JSON property resourceAttributes
7193 7194 7195 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7193 def resource_attributes @resource_attributes end |
#user_id ⇒ String
Required. User's UUID provided by the client.
Corresponds to the JSON property userId
7198 7199 7200 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7198 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7205 7206 7207 7208 7209 7210 7211 7212 |
# File 'lib/google/apis/healthcare_v1beta1/classes.rb', line 7205 def update!(**args) @archive_time = args[:archive_time] if args.key?(:archive_time) @archived = args[:archived] if args.key?(:archived) @data_id = args[:data_id] if args.key?(:data_id) @name = args[:name] if args.key?(:name) @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes) @user_id = args[:user_id] if args.key?(:user_id) end |